# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DmarcReportMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'org_name': 'str',
        'email': 'str',
        'report_id': 'str',
        'domain': 'str',
        'adkim': 'str',
        'aspf': 'str',
        'policy': 'str',
        'subdomain_policy': 'str',
        'percentage': 'int',
        'date_range_begin': 'datetime',
        'date_range_end': 'datetime'
    }

    attribute_map = {
        'org_name': 'orgName',
        'email': 'email',
        'report_id': 'reportId',
        'domain': 'domain',
        'adkim': 'adkim',
        'aspf': 'aspf',
        'policy': 'policy',
        'subdomain_policy': 'subdomainPolicy',
        'percentage': 'percentage',
        'date_range_begin': 'dateRangeBegin',
        'date_range_end': 'dateRangeEnd'
    }

    def __init__(self, org_name=None, email=None, report_id=None, domain=None, adkim=None, aspf=None, policy=None, subdomain_policy=None, percentage=None, date_range_begin=None, date_range_end=None, local_vars_configuration=None):  # noqa: E501
        """DmarcReportMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._org_name = None
        self._email = None
        self._report_id = None
        self._domain = None
        self._adkim = None
        self._aspf = None
        self._policy = None
        self._subdomain_policy = None
        self._percentage = None
        self._date_range_begin = None
        self._date_range_end = None
        self.discriminator = None

        self.org_name = org_name
        self.email = email
        self.report_id = report_id
        self.domain = domain
        self.adkim = adkim
        self.aspf = aspf
        self.policy = policy
        self.subdomain_policy = subdomain_policy
        self.percentage = percentage
        self.date_range_begin = date_range_begin
        self.date_range_end = date_range_end

    @property
    def org_name(self):
        """Gets the org_name of this DmarcReportMetadata.  # noqa: E501


        :return: The org_name of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this DmarcReportMetadata.


        :param org_name: The org_name of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._org_name = org_name

    @property
    def email(self):
        """Gets the email of this DmarcReportMetadata.  # noqa: E501


        :return: The email of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this DmarcReportMetadata.


        :param email: The email of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def report_id(self):
        """Gets the report_id of this DmarcReportMetadata.  # noqa: E501


        :return: The report_id of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this DmarcReportMetadata.


        :param report_id: The report_id of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._report_id = report_id

    @property
    def domain(self):
        """Gets the domain of this DmarcReportMetadata.  # noqa: E501


        :return: The domain of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this DmarcReportMetadata.


        :param domain: The domain of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def adkim(self):
        """Gets the adkim of this DmarcReportMetadata.  # noqa: E501


        :return: The adkim of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._adkim

    @adkim.setter
    def adkim(self, adkim):
        """Sets the adkim of this DmarcReportMetadata.


        :param adkim: The adkim of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._adkim = adkim

    @property
    def aspf(self):
        """Gets the aspf of this DmarcReportMetadata.  # noqa: E501


        :return: The aspf of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._aspf

    @aspf.setter
    def aspf(self, aspf):
        """Sets the aspf of this DmarcReportMetadata.


        :param aspf: The aspf of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._aspf = aspf

    @property
    def policy(self):
        """Gets the policy of this DmarcReportMetadata.  # noqa: E501


        :return: The policy of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this DmarcReportMetadata.


        :param policy: The policy of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._policy = policy

    @property
    def subdomain_policy(self):
        """Gets the subdomain_policy of this DmarcReportMetadata.  # noqa: E501


        :return: The subdomain_policy of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._subdomain_policy

    @subdomain_policy.setter
    def subdomain_policy(self, subdomain_policy):
        """Sets the subdomain_policy of this DmarcReportMetadata.


        :param subdomain_policy: The subdomain_policy of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._subdomain_policy = subdomain_policy

    @property
    def percentage(self):
        """Gets the percentage of this DmarcReportMetadata.  # noqa: E501


        :return: The percentage of this DmarcReportMetadata.  # noqa: E501
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this DmarcReportMetadata.


        :param percentage: The percentage of this DmarcReportMetadata.  # noqa: E501
        :type: int
        """

        self._percentage = percentage

    @property
    def date_range_begin(self):
        """Gets the date_range_begin of this DmarcReportMetadata.  # noqa: E501


        :return: The date_range_begin of this DmarcReportMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._date_range_begin

    @date_range_begin.setter
    def date_range_begin(self, date_range_begin):
        """Sets the date_range_begin of this DmarcReportMetadata.


        :param date_range_begin: The date_range_begin of this DmarcReportMetadata.  # noqa: E501
        :type: datetime
        """

        self._date_range_begin = date_range_begin

    @property
    def date_range_end(self):
        """Gets the date_range_end of this DmarcReportMetadata.  # noqa: E501


        :return: The date_range_end of this DmarcReportMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._date_range_end

    @date_range_end.setter
    def date_range_end(self, date_range_end):
        """Sets the date_range_end of this DmarcReportMetadata.


        :param date_range_end: The date_range_end of this DmarcReportMetadata.  # noqa: E501
        :type: datetime
        """

        self._date_range_end = date_range_end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DmarcReportMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DmarcReportMetadata):
            return True

        return self.to_dict() != other.to_dict()
