# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformMappingDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'ai_transform_id': 'str',
        'match_options': 'AIMappingMatchOptions',
        'user_id': 'str',
        'name': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'ai_transform_id': 'aiTransformId',
        'match_options': 'matchOptions',
        'user_id': 'userId',
        'name': 'name',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, ai_transform_id=None, match_options=None, user_id=None, name=None, entity_id=None, entity_type=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """AITransformMappingDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ai_transform_id = None
        self._match_options = None
        self._user_id = None
        self._name = None
        self._entity_id = None
        self._entity_type = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.ai_transform_id = ai_transform_id
        self.match_options = match_options
        self.user_id = user_id
        if name is not None:
            self.name = name
        if entity_id is not None:
            self.entity_id = entity_id
        self.entity_type = entity_type
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this AITransformMappingDto.  # noqa: E501


        :return: The id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AITransformMappingDto.


        :param id: The id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this AITransformMappingDto.  # noqa: E501


        :return: The ai_transform_id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this AITransformMappingDto.


        :param ai_transform_id: The ai_transform_id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_id`, must not be `None`")  # noqa: E501

        self._ai_transform_id = ai_transform_id

    @property
    def match_options(self):
        """Gets the match_options of this AITransformMappingDto.  # noqa: E501


        :return: The match_options of this AITransformMappingDto.  # noqa: E501
        :rtype: AIMappingMatchOptions
        """
        return self._match_options

    @match_options.setter
    def match_options(self, match_options):
        """Sets the match_options of this AITransformMappingDto.


        :param match_options: The match_options of this AITransformMappingDto.  # noqa: E501
        :type: AIMappingMatchOptions
        """

        self._match_options = match_options

    @property
    def user_id(self):
        """Gets the user_id of this AITransformMappingDto.  # noqa: E501


        :return: The user_id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AITransformMappingDto.


        :param user_id: The user_id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this AITransformMappingDto.  # noqa: E501


        :return: The name of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AITransformMappingDto.


        :param name: The name of this AITransformMappingDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def entity_id(self):
        """Gets the entity_id of this AITransformMappingDto.  # noqa: E501


        :return: The entity_id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this AITransformMappingDto.


        :param entity_id: The entity_id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this AITransformMappingDto.  # noqa: E501


        :return: The entity_type of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this AITransformMappingDto.


        :param entity_type: The entity_type of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def created_at(self):
        """Gets the created_at of this AITransformMappingDto.  # noqa: E501


        :return: The created_at of this AITransformMappingDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AITransformMappingDto.


        :param created_at: The created_at of this AITransformMappingDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformMappingDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformMappingDto):
            return True

        return self.to_dict() != other.to_dict()
