# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneNumberReleaseProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'user_id': 'str',
        'phone_country': 'str',
        'created_at': 'datetime',
        'phone_number': 'str',
        'subscription_schedule': 'str',
        'plan_currency': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'user_id': 'userId',
        'phone_country': 'phoneCountry',
        'created_at': 'createdAt',
        'phone_number': 'phoneNumber',
        'subscription_schedule': 'subscriptionSchedule',
        'plan_currency': 'planCurrency'
    }

    def __init__(self, name=None, id=None, user_id=None, phone_country=None, created_at=None, phone_number=None, subscription_schedule=None, plan_currency=None, local_vars_configuration=None):  # noqa: E501
        """PhoneNumberReleaseProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._user_id = None
        self._phone_country = None
        self._created_at = None
        self._phone_number = None
        self._subscription_schedule = None
        self._plan_currency = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.id = id
        self.user_id = user_id
        self.phone_country = phone_country
        self.created_at = created_at
        if phone_number is not None:
            self.phone_number = phone_number
        if subscription_schedule is not None:
            self.subscription_schedule = subscription_schedule
        if plan_currency is not None:
            self.plan_currency = plan_currency

    @property
    def name(self):
        """Gets the name of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The name of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PhoneNumberReleaseProjection.


        :param name: The name of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The id of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneNumberReleaseProjection.


        :param id: The id of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The user_id of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhoneNumberReleaseProjection.


        :param user_id: The user_id of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The phone_country of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneNumberReleaseProjection.


        :param phone_country: The phone_country of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def created_at(self):
        """Gets the created_at of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The created_at of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneNumberReleaseProjection.


        :param created_at: The created_at of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The phone_number of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberReleaseProjection.


        :param phone_number: The phone_number of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def subscription_schedule(self):
        """Gets the subscription_schedule of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The subscription_schedule of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._subscription_schedule

    @subscription_schedule.setter
    def subscription_schedule(self, subscription_schedule):
        """Sets the subscription_schedule of this PhoneNumberReleaseProjection.


        :param subscription_schedule: The subscription_schedule of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        allowed_values = ["MONTHLY", "YEARLY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and subscription_schedule not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `subscription_schedule` ({0}), must be one of {1}"  # noqa: E501
                .format(subscription_schedule, allowed_values)
            )

        self._subscription_schedule = subscription_schedule

    @property
    def plan_currency(self):
        """Gets the plan_currency of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The plan_currency of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._plan_currency

    @plan_currency.setter
    def plan_currency(self, plan_currency):
        """Sets the plan_currency of this PhoneNumberReleaseProjection.


        :param plan_currency: The plan_currency of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        allowed_values = ["EUR", "USD", "JPY", "GBP", "AUD", "CAD", "CHF", "CNY", "INR", "NZD"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and plan_currency not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `plan_currency` ({0}), must be one of {1}"  # noqa: E501
                .format(plan_currency, allowed_values)
            )

        self._plan_currency = plan_currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberReleaseProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneNumberReleaseProjection):
            return True

        return self.to_dict() != other.to_dict()
