# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityFailurePhoneDimensionHotspotDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_country': 'str',
        'phone_variant': 'str',
        'failed_run_count': 'int',
        'total_run_count': 'int',
        'failure_rate_percentage': 'float'
    }

    attribute_map = {
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'failed_run_count': 'failedRunCount',
        'total_run_count': 'totalRunCount',
        'failure_rate_percentage': 'failureRatePercentage'
    }

    def __init__(self, phone_country=None, phone_variant=None, failed_run_count=None, total_run_count=None, failure_rate_percentage=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityFailurePhoneDimensionHotspotDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_country = None
        self._phone_variant = None
        self._failed_run_count = None
        self._total_run_count = None
        self._failure_rate_percentage = None
        self.discriminator = None

        self.phone_country = phone_country
        self.phone_variant = phone_variant
        self.failed_run_count = failed_run_count
        self.total_run_count = total_run_count
        self.failure_rate_percentage = failure_rate_percentage

    @property
    def phone_country(self):
        """Gets the phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param phone_country: The phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param phone_variant: The phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def failed_run_count(self):
        """Gets the failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_run_count

    @failed_run_count.setter
    def failed_run_count(self, failed_run_count):
        """Sets the failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param failed_run_count: The failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_run_count`, must not be `None`")  # noqa: E501

        self._failed_run_count = failed_run_count

    @property
    def total_run_count(self):
        """Gets the total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: int
        """
        return self._total_run_count

    @total_run_count.setter
    def total_run_count(self, total_run_count):
        """Sets the total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param total_run_count: The total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_run_count`, must not be `None`")  # noqa: E501

        self._total_run_count = total_run_count

    @property
    def failure_rate_percentage(self):
        """Gets the failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: float
        """
        return self._failure_rate_percentage

    @failure_rate_percentage.setter
    def failure_rate_percentage(self, failure_rate_percentage):
        """Sets the failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param failure_rate_percentage: The failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and failure_rate_percentage is None:  # noqa: E501
            raise ValueError("Invalid value for `failure_rate_percentage`, must not be `None`")  # noqa: E501

        self._failure_rate_percentage = failure_rate_percentage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityFailurePhoneDimensionHotspotDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityFailurePhoneDimensionHotspotDto):
            return True

        return self.to_dict() != other.to_dict()
