# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailSignature(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'body': 'str',
        'source': 'str',
        'marker': 'str',
        'detection_type': 'str'
    }

    attribute_map = {
        'body': 'body',
        'source': 'source',
        'marker': 'marker',
        'detection_type': 'detectionType'
    }

    def __init__(self, body=None, source=None, marker=None, detection_type=None, local_vars_configuration=None):  # noqa: E501
        """EmailSignature - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._body = None
        self._source = None
        self._marker = None
        self._detection_type = None
        self.discriminator = None

        self.body = body
        self.source = source
        self.marker = marker
        self.detection_type = detection_type

    @property
    def body(self):
        """Gets the body of this EmailSignature.  # noqa: E501

        Extracted signature text  # noqa: E501

        :return: The body of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this EmailSignature.

        Extracted signature text  # noqa: E501

        :param body: The body of this EmailSignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body is None:  # noqa: E501
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def source(self):
        """Gets the source of this EmailSignature.  # noqa: E501

        Source used for extraction. Examples: RAW_TEXT_PART, RAW_HTML_SELECTOR  # noqa: E501

        :return: The source of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this EmailSignature.

        Source used for extraction. Examples: RAW_TEXT_PART, RAW_HTML_SELECTOR  # noqa: E501

        :param source: The source of this EmailSignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def marker(self):
        """Gets the marker of this EmailSignature.  # noqa: E501

        Matched marker or selector that identified the signature  # noqa: E501

        :return: The marker of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._marker

    @marker.setter
    def marker(self, marker):
        """Sets the marker of this EmailSignature.

        Matched marker or selector that identified the signature  # noqa: E501

        :param marker: The marker of this EmailSignature.  # noqa: E501
        :type: str
        """

        self._marker = marker

    @property
    def detection_type(self):
        """Gets the detection_type of this EmailSignature.  # noqa: E501

        Detection strategy used. Examples: DELIMITER, MOBILE_FOOTER, VALEDICTION  # noqa: E501

        :return: The detection_type of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._detection_type

    @detection_type.setter
    def detection_type(self, detection_type):
        """Sets the detection_type of this EmailSignature.

        Detection strategy used. Examples: DELIMITER, MOBILE_FOOTER, VALEDICTION  # noqa: E501

        :param detection_type: The detection_type of this EmailSignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and detection_type is None:  # noqa: E501
            raise ValueError("Invalid value for `detection_type`, must not be `None`")  # noqa: E501

        self._detection_type = detection_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailSignature):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailSignature):
            return True

        return self.to_dict() != other.to_dict()
