# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhonePoolDetailDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'name': 'str',
        'description': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'member_count': 'int',
        'available_member_count': 'int',
        'leased_member_count': 'int',
        'members': 'list[PhonePoolMemberDto]'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'name': 'name',
        'description': 'description',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'member_count': 'memberCount',
        'available_member_count': 'availableMemberCount',
        'leased_member_count': 'leasedMemberCount',
        'members': 'members'
    }

    def __init__(self, id=None, user_id=None, name=None, description=None, created_at=None, updated_at=None, member_count=None, available_member_count=None, leased_member_count=None, members=None, local_vars_configuration=None):  # noqa: E501
        """PhonePoolDetailDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._name = None
        self._description = None
        self._created_at = None
        self._updated_at = None
        self._member_count = None
        self._available_member_count = None
        self._leased_member_count = None
        self._members = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.name = name
        if description is not None:
            self.description = description
        self.created_at = created_at
        self.updated_at = updated_at
        self.member_count = member_count
        self.available_member_count = available_member_count
        self.leased_member_count = leased_member_count
        self.members = members

    @property
    def id(self):
        """Gets the id of this PhonePoolDetailDto.  # noqa: E501


        :return: The id of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhonePoolDetailDto.


        :param id: The id of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhonePoolDetailDto.  # noqa: E501


        :return: The user_id of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhonePoolDetailDto.


        :param user_id: The user_id of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this PhonePoolDetailDto.  # noqa: E501


        :return: The name of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PhonePoolDetailDto.


        :param name: The name of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this PhonePoolDetailDto.  # noqa: E501


        :return: The description of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PhonePoolDetailDto.


        :param description: The description of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_at(self):
        """Gets the created_at of this PhonePoolDetailDto.  # noqa: E501


        :return: The created_at of this PhonePoolDetailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhonePoolDetailDto.


        :param created_at: The created_at of this PhonePoolDetailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhonePoolDetailDto.  # noqa: E501


        :return: The updated_at of this PhonePoolDetailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhonePoolDetailDto.


        :param updated_at: The updated_at of this PhonePoolDetailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def member_count(self):
        """Gets the member_count of this PhonePoolDetailDto.  # noqa: E501


        :return: The member_count of this PhonePoolDetailDto.  # noqa: E501
        :rtype: int
        """
        return self._member_count

    @member_count.setter
    def member_count(self, member_count):
        """Sets the member_count of this PhonePoolDetailDto.


        :param member_count: The member_count of this PhonePoolDetailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and member_count is None:  # noqa: E501
            raise ValueError("Invalid value for `member_count`, must not be `None`")  # noqa: E501

        self._member_count = member_count

    @property
    def available_member_count(self):
        """Gets the available_member_count of this PhonePoolDetailDto.  # noqa: E501


        :return: The available_member_count of this PhonePoolDetailDto.  # noqa: E501
        :rtype: int
        """
        return self._available_member_count

    @available_member_count.setter
    def available_member_count(self, available_member_count):
        """Sets the available_member_count of this PhonePoolDetailDto.


        :param available_member_count: The available_member_count of this PhonePoolDetailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and available_member_count is None:  # noqa: E501
            raise ValueError("Invalid value for `available_member_count`, must not be `None`")  # noqa: E501

        self._available_member_count = available_member_count

    @property
    def leased_member_count(self):
        """Gets the leased_member_count of this PhonePoolDetailDto.  # noqa: E501


        :return: The leased_member_count of this PhonePoolDetailDto.  # noqa: E501
        :rtype: int
        """
        return self._leased_member_count

    @leased_member_count.setter
    def leased_member_count(self, leased_member_count):
        """Sets the leased_member_count of this PhonePoolDetailDto.


        :param leased_member_count: The leased_member_count of this PhonePoolDetailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and leased_member_count is None:  # noqa: E501
            raise ValueError("Invalid value for `leased_member_count`, must not be `None`")  # noqa: E501

        self._leased_member_count = leased_member_count

    @property
    def members(self):
        """Gets the members of this PhonePoolDetailDto.  # noqa: E501


        :return: The members of this PhonePoolDetailDto.  # noqa: E501
        :rtype: list[PhonePoolMemberDto]
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this PhonePoolDetailDto.


        :param members: The members of this PhonePoolDetailDto.  # noqa: E501
        :type: list[PhonePoolMemberDto]
        """
        if self.local_vars_configuration.client_side_validation and members is None:  # noqa: E501
            raise ValueError("Invalid value for `members`, must not be `None`")  # noqa: E501

        self._members = members

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhonePoolDetailDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhonePoolDetailDto):
            return True

        return self.to_dict() != other.to_dict()
