# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneProvisioningJobDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'phone_country': 'str',
        'phone_variant': 'str',
        'status': 'str',
        'requested_count': 'int',
        'attempted_count': 'int',
        'succeeded_count': 'int',
        'failed_count': 'int',
        'unavailable_count': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'items': 'list[PhoneProvisioningJobItemDto]'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'status': 'status',
        'requested_count': 'requestedCount',
        'attempted_count': 'attemptedCount',
        'succeeded_count': 'succeededCount',
        'failed_count': 'failedCount',
        'unavailable_count': 'unavailableCount',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'items': 'items'
    }

    def __init__(self, id=None, user_id=None, phone_country=None, phone_variant=None, status=None, requested_count=None, attempted_count=None, succeeded_count=None, failed_count=None, unavailable_count=None, created_at=None, updated_at=None, items=None, local_vars_configuration=None):  # noqa: E501
        """PhoneProvisioningJobDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._phone_country = None
        self._phone_variant = None
        self._status = None
        self._requested_count = None
        self._attempted_count = None
        self._succeeded_count = None
        self._failed_count = None
        self._unavailable_count = None
        self._created_at = None
        self._updated_at = None
        self._items = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.phone_country = phone_country
        if phone_variant is not None:
            self.phone_variant = phone_variant
        self.status = status
        self.requested_count = requested_count
        self.attempted_count = attempted_count
        self.succeeded_count = succeeded_count
        self.failed_count = failed_count
        self.unavailable_count = unavailable_count
        self.created_at = created_at
        self.updated_at = updated_at
        self.items = items

    @property
    def id(self):
        """Gets the id of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The id of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneProvisioningJobDto.


        :param id: The id of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The user_id of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhoneProvisioningJobDto.


        :param user_id: The user_id of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The phone_country of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneProvisioningJobDto.


        :param phone_country: The phone_country of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The phone_variant of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this PhoneProvisioningJobDto.


        :param phone_variant: The phone_variant of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def status(self):
        """Gets the status of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The status of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PhoneProvisioningJobDto.


        :param status: The status of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["CREATED", "RUNNING", "COMPLETED", "PARTIAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def requested_count(self):
        """Gets the requested_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The requested_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._requested_count

    @requested_count.setter
    def requested_count(self, requested_count):
        """Sets the requested_count of this PhoneProvisioningJobDto.


        :param requested_count: The requested_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and requested_count is None:  # noqa: E501
            raise ValueError("Invalid value for `requested_count`, must not be `None`")  # noqa: E501

        self._requested_count = requested_count

    @property
    def attempted_count(self):
        """Gets the attempted_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The attempted_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._attempted_count

    @attempted_count.setter
    def attempted_count(self, attempted_count):
        """Sets the attempted_count of this PhoneProvisioningJobDto.


        :param attempted_count: The attempted_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attempted_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attempted_count`, must not be `None`")  # noqa: E501

        self._attempted_count = attempted_count

    @property
    def succeeded_count(self):
        """Gets the succeeded_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The succeeded_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._succeeded_count

    @succeeded_count.setter
    def succeeded_count(self, succeeded_count):
        """Sets the succeeded_count of this PhoneProvisioningJobDto.


        :param succeeded_count: The succeeded_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and succeeded_count is None:  # noqa: E501
            raise ValueError("Invalid value for `succeeded_count`, must not be `None`")  # noqa: E501

        self._succeeded_count = succeeded_count

    @property
    def failed_count(self):
        """Gets the failed_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The failed_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_count

    @failed_count.setter
    def failed_count(self, failed_count):
        """Sets the failed_count of this PhoneProvisioningJobDto.


        :param failed_count: The failed_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_count`, must not be `None`")  # noqa: E501

        self._failed_count = failed_count

    @property
    def unavailable_count(self):
        """Gets the unavailable_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The unavailable_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._unavailable_count

    @unavailable_count.setter
    def unavailable_count(self, unavailable_count):
        """Sets the unavailable_count of this PhoneProvisioningJobDto.


        :param unavailable_count: The unavailable_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and unavailable_count is None:  # noqa: E501
            raise ValueError("Invalid value for `unavailable_count`, must not be `None`")  # noqa: E501

        self._unavailable_count = unavailable_count

    @property
    def created_at(self):
        """Gets the created_at of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The created_at of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneProvisioningJobDto.


        :param created_at: The created_at of this PhoneProvisioningJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The updated_at of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhoneProvisioningJobDto.


        :param updated_at: The updated_at of this PhoneProvisioningJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def items(self):
        """Gets the items of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The items of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: list[PhoneProvisioningJobItemDto]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this PhoneProvisioningJobDto.


        :param items: The items of this PhoneProvisioningJobDto.  # noqa: E501
        :type: list[PhoneProvisioningJobItemDto]
        """
        if self.local_vars_configuration.client_side_validation and items is None:  # noqa: E501
            raise ValueError("Invalid value for `items`, must not be `None`")  # noqa: E501

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneProvisioningJobDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneProvisioningJobDto):
            return True

        return self.to_dict() != other.to_dict()
