# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'created_at': 'datetime',
        'conditions': 'list[str]',
        'instructions': 'list[str]',
        'output_schema': 'StructuredOutputSchema'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'created_at': 'createdAt',
        'conditions': 'conditions',
        'instructions': 'instructions',
        'output_schema': 'outputSchema'
    }

    def __init__(self, name=None, id=None, created_at=None, conditions=None, instructions=None, output_schema=None, local_vars_configuration=None):  # noqa: E501
        """AITransformProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._created_at = None
        self._conditions = None
        self._instructions = None
        self._output_schema = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.id = id
        self.created_at = created_at
        if conditions is not None:
            self.conditions = conditions
        if instructions is not None:
            self.instructions = instructions
        self.output_schema = output_schema

    @property
    def name(self):
        """Gets the name of this AITransformProjection.  # noqa: E501


        :return: The name of this AITransformProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AITransformProjection.


        :param name: The name of this AITransformProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this AITransformProjection.  # noqa: E501


        :return: The id of this AITransformProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AITransformProjection.


        :param id: The id of this AITransformProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this AITransformProjection.  # noqa: E501


        :return: The created_at of this AITransformProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AITransformProjection.


        :param created_at: The created_at of this AITransformProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def conditions(self):
        """Gets the conditions of this AITransformProjection.  # noqa: E501


        :return: The conditions of this AITransformProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this AITransformProjection.


        :param conditions: The conditions of this AITransformProjection.  # noqa: E501
        :type: list[str]
        """

        self._conditions = conditions

    @property
    def instructions(self):
        """Gets the instructions of this AITransformProjection.  # noqa: E501


        :return: The instructions of this AITransformProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this AITransformProjection.


        :param instructions: The instructions of this AITransformProjection.  # noqa: E501
        :type: list[str]
        """

        self._instructions = instructions

    @property
    def output_schema(self):
        """Gets the output_schema of this AITransformProjection.  # noqa: E501


        :return: The output_schema of this AITransformProjection.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """Sets the output_schema of this AITransformProjection.


        :param output_schema: The output_schema of this AITransformProjection.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._output_schema = output_schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformProjection):
            return True

        return self.to_dict() != other.to_dict()
