# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupPtrResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ip': 'str',
        'ptr_hostnames': 'list[str]',
        'forward_confirmed': 'bool',
        'forward_a_records': 'list[str]',
        'forward_aaaa_records': 'list[str]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'ip': 'ip',
        'ptr_hostnames': 'ptrHostnames',
        'forward_confirmed': 'forwardConfirmed',
        'forward_a_records': 'forwardARecords',
        'forward_aaaa_records': 'forwardAaaaRecords',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, ip=None, ptr_hostnames=None, forward_confirmed=None, forward_a_records=None, forward_aaaa_records=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """LookupPtrResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ip = None
        self._ptr_hostnames = None
        self._forward_confirmed = None
        self._forward_a_records = None
        self._forward_aaaa_records = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.ip = ip
        self.ptr_hostnames = ptr_hostnames
        self.forward_confirmed = forward_confirmed
        self.forward_a_records = forward_a_records
        self.forward_aaaa_records = forward_aaaa_records
        self.warnings = warnings
        self.errors = errors

    @property
    def ip(self):
        """Gets the ip of this LookupPtrResults.  # noqa: E501


        :return: The ip of this LookupPtrResults.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this LookupPtrResults.


        :param ip: The ip of this LookupPtrResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ip is None:  # noqa: E501
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def ptr_hostnames(self):
        """Gets the ptr_hostnames of this LookupPtrResults.  # noqa: E501


        :return: The ptr_hostnames of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._ptr_hostnames

    @ptr_hostnames.setter
    def ptr_hostnames(self, ptr_hostnames):
        """Sets the ptr_hostnames of this LookupPtrResults.


        :param ptr_hostnames: The ptr_hostnames of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and ptr_hostnames is None:  # noqa: E501
            raise ValueError("Invalid value for `ptr_hostnames`, must not be `None`")  # noqa: E501

        self._ptr_hostnames = ptr_hostnames

    @property
    def forward_confirmed(self):
        """Gets the forward_confirmed of this LookupPtrResults.  # noqa: E501


        :return: The forward_confirmed of this LookupPtrResults.  # noqa: E501
        :rtype: bool
        """
        return self._forward_confirmed

    @forward_confirmed.setter
    def forward_confirmed(self, forward_confirmed):
        """Sets the forward_confirmed of this LookupPtrResults.


        :param forward_confirmed: The forward_confirmed of this LookupPtrResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and forward_confirmed is None:  # noqa: E501
            raise ValueError("Invalid value for `forward_confirmed`, must not be `None`")  # noqa: E501

        self._forward_confirmed = forward_confirmed

    @property
    def forward_a_records(self):
        """Gets the forward_a_records of this LookupPtrResults.  # noqa: E501


        :return: The forward_a_records of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._forward_a_records

    @forward_a_records.setter
    def forward_a_records(self, forward_a_records):
        """Sets the forward_a_records of this LookupPtrResults.


        :param forward_a_records: The forward_a_records of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and forward_a_records is None:  # noqa: E501
            raise ValueError("Invalid value for `forward_a_records`, must not be `None`")  # noqa: E501

        self._forward_a_records = forward_a_records

    @property
    def forward_aaaa_records(self):
        """Gets the forward_aaaa_records of this LookupPtrResults.  # noqa: E501


        :return: The forward_aaaa_records of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._forward_aaaa_records

    @forward_aaaa_records.setter
    def forward_aaaa_records(self, forward_aaaa_records):
        """Sets the forward_aaaa_records of this LookupPtrResults.


        :param forward_aaaa_records: The forward_aaaa_records of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and forward_aaaa_records is None:  # noqa: E501
            raise ValueError("Invalid value for `forward_aaaa_records`, must not be `None`")  # noqa: E501

        self._forward_aaaa_records = forward_aaaa_records

    @property
    def warnings(self):
        """Gets the warnings of this LookupPtrResults.  # noqa: E501


        :return: The warnings of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupPtrResults.


        :param warnings: The warnings of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this LookupPtrResults.  # noqa: E501


        :return: The errors of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupPtrResults.


        :param errors: The errors of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupPtrResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupPtrResults):
            return True

        return self.to_dict() != other.to_dict()
