# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorSummaryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'monitor': 'DomainMonitorDto',
        'latest_run': 'DomainMonitorRunDto',
        'insights': 'DomainMonitorInsightsDto',
        'auth_stack': 'CheckEmailAuthStackResults'
    }

    attribute_map = {
        'monitor': 'monitor',
        'latest_run': 'latestRun',
        'insights': 'insights',
        'auth_stack': 'authStack'
    }

    def __init__(self, monitor=None, latest_run=None, insights=None, auth_stack=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorSummaryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._monitor = None
        self._latest_run = None
        self._insights = None
        self._auth_stack = None
        self.discriminator = None

        self.monitor = monitor
        if latest_run is not None:
            self.latest_run = latest_run
        self.insights = insights
        self.auth_stack = auth_stack

    @property
    def monitor(self):
        """Gets the monitor of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The monitor of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: DomainMonitorDto
        """
        return self._monitor

    @monitor.setter
    def monitor(self, monitor):
        """Sets the monitor of this DomainMonitorSummaryDto.


        :param monitor: The monitor of this DomainMonitorSummaryDto.  # noqa: E501
        :type: DomainMonitorDto
        """
        if self.local_vars_configuration.client_side_validation and monitor is None:  # noqa: E501
            raise ValueError("Invalid value for `monitor`, must not be `None`")  # noqa: E501

        self._monitor = monitor

    @property
    def latest_run(self):
        """Gets the latest_run of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The latest_run of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: DomainMonitorRunDto
        """
        return self._latest_run

    @latest_run.setter
    def latest_run(self, latest_run):
        """Sets the latest_run of this DomainMonitorSummaryDto.


        :param latest_run: The latest_run of this DomainMonitorSummaryDto.  # noqa: E501
        :type: DomainMonitorRunDto
        """

        self._latest_run = latest_run

    @property
    def insights(self):
        """Gets the insights of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The insights of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: DomainMonitorInsightsDto
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this DomainMonitorSummaryDto.


        :param insights: The insights of this DomainMonitorSummaryDto.  # noqa: E501
        :type: DomainMonitorInsightsDto
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def auth_stack(self):
        """Gets the auth_stack of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The auth_stack of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: CheckEmailAuthStackResults
        """
        return self._auth_stack

    @auth_stack.setter
    def auth_stack(self, auth_stack):
        """Sets the auth_stack of this DomainMonitorSummaryDto.


        :param auth_stack: The auth_stack of this DomainMonitorSummaryDto.  # noqa: E501
        :type: CheckEmailAuthStackResults
        """
        if self.local_vars_configuration.client_side_validation and auth_stack is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_stack`, must not be `None`")  # noqa: E501

        self._auth_stack = auth_stack

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorSummaryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorSummaryDto):
            return True

        return self.to_dict() != other.to_dict()
