# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeRunDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'probe_id': 'str',
        'user_id': 'str',
        'status': 'str',
        'source': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'checked_links': 'int',
        'checked_images': 'int',
        'link_issue_count': 'int',
        'image_issue_count': 'int',
        'compatibility_warning_count': 'int',
        'compatibility_not_supported_count': 'int',
        'compatibility_unknown_count': 'int',
        'html_error_count': 'int',
        'html_warning_count': 'int',
        'html_info_count': 'int',
        'reputation_failure_count': 'int',
        'attachment_mention_issue_count': 'int',
        'insights': 'list[str]',
        'error_message': 'str',
        'from_address': 'str',
        'recipient': 'str',
        'subject': 'str',
        'message_id': 'str',
        'source_message_id': 'str',
        'processing_ms': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'probe_id': 'probeId',
        'user_id': 'userId',
        'status': 'status',
        'source': 'source',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'checked_links': 'checkedLinks',
        'checked_images': 'checkedImages',
        'link_issue_count': 'linkIssueCount',
        'image_issue_count': 'imageIssueCount',
        'compatibility_warning_count': 'compatibilityWarningCount',
        'compatibility_not_supported_count': 'compatibilityNotSupportedCount',
        'compatibility_unknown_count': 'compatibilityUnknownCount',
        'html_error_count': 'htmlErrorCount',
        'html_warning_count': 'htmlWarningCount',
        'html_info_count': 'htmlInfoCount',
        'reputation_failure_count': 'reputationFailureCount',
        'attachment_mention_issue_count': 'attachmentMentionIssueCount',
        'insights': 'insights',
        'error_message': 'errorMessage',
        'from_address': 'fromAddress',
        'recipient': 'recipient',
        'subject': 'subject',
        'message_id': 'messageId',
        'source_message_id': 'sourceMessageId',
        'processing_ms': 'processingMs',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, probe_id=None, user_id=None, status=None, source=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, checked_links=None, checked_images=None, link_issue_count=None, image_issue_count=None, compatibility_warning_count=None, compatibility_not_supported_count=None, compatibility_unknown_count=None, html_error_count=None, html_warning_count=None, html_info_count=None, reputation_failure_count=None, attachment_mention_issue_count=None, insights=None, error_message=None, from_address=None, recipient=None, subject=None, message_id=None, source_message_id=None, processing_ms=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeRunDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._probe_id = None
        self._user_id = None
        self._status = None
        self._source = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._checked_links = None
        self._checked_images = None
        self._link_issue_count = None
        self._image_issue_count = None
        self._compatibility_warning_count = None
        self._compatibility_not_supported_count = None
        self._compatibility_unknown_count = None
        self._html_error_count = None
        self._html_warning_count = None
        self._html_info_count = None
        self._reputation_failure_count = None
        self._attachment_mention_issue_count = None
        self._insights = None
        self._error_message = None
        self._from_address = None
        self._recipient = None
        self._subject = None
        self._message_id = None
        self._source_message_id = None
        self._processing_ms = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.probe_id = probe_id
        self.user_id = user_id
        self.status = status
        self.source = source
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.checked_links = checked_links
        self.checked_images = checked_images
        self.link_issue_count = link_issue_count
        self.image_issue_count = image_issue_count
        self.compatibility_warning_count = compatibility_warning_count
        self.compatibility_not_supported_count = compatibility_not_supported_count
        self.compatibility_unknown_count = compatibility_unknown_count
        self.html_error_count = html_error_count
        self.html_warning_count = html_warning_count
        self.html_info_count = html_info_count
        self.reputation_failure_count = reputation_failure_count
        self.attachment_mention_issue_count = attachment_mention_issue_count
        self.insights = insights
        if error_message is not None:
            self.error_message = error_message
        if from_address is not None:
            self.from_address = from_address
        if recipient is not None:
            self.recipient = recipient
        if subject is not None:
            self.subject = subject
        if message_id is not None:
            self.message_id = message_id
        if source_message_id is not None:
            self.source_message_id = source_message_id
        if processing_ms is not None:
            self.processing_ms = processing_ms
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this CampaignProbeRunDto.  # noqa: E501


        :return: The id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CampaignProbeRunDto.


        :param id: The id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def probe_id(self):
        """Gets the probe_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The probe_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this CampaignProbeRunDto.


        :param probe_id: The probe_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and probe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `probe_id`, must not be `None`")  # noqa: E501

        self._probe_id = probe_id

    @property
    def user_id(self):
        """Gets the user_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The user_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this CampaignProbeRunDto.


        :param user_id: The user_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def status(self):
        """Gets the status of this CampaignProbeRunDto.  # noqa: E501


        :return: The status of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CampaignProbeRunDto.


        :param status: The status of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def source(self):
        """Gets the source of this CampaignProbeRunDto.  # noqa: E501


        :return: The source of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this CampaignProbeRunDto.


        :param source: The source of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = ["DIRECT_API", "SES_MONITOR", "USER_SCHEDULE", "CRON", "SCHEDULER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def health_score(self):
        """Gets the health_score of this CampaignProbeRunDto.  # noqa: E501


        :return: The health_score of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CampaignProbeRunDto.


        :param health_score: The health_score of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CampaignProbeRunDto.  # noqa: E501


        :return: The total_checks of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CampaignProbeRunDto.


        :param total_checks: The total_checks of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CampaignProbeRunDto.  # noqa: E501


        :return: The passing_checks of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CampaignProbeRunDto.


        :param passing_checks: The passing_checks of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CampaignProbeRunDto.  # noqa: E501


        :return: The failing_checks of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CampaignProbeRunDto.


        :param failing_checks: The failing_checks of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def checked_links(self):
        """Gets the checked_links of this CampaignProbeRunDto.  # noqa: E501


        :return: The checked_links of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._checked_links

    @checked_links.setter
    def checked_links(self, checked_links):
        """Sets the checked_links of this CampaignProbeRunDto.


        :param checked_links: The checked_links of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_links is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_links`, must not be `None`")  # noqa: E501

        self._checked_links = checked_links

    @property
    def checked_images(self):
        """Gets the checked_images of this CampaignProbeRunDto.  # noqa: E501


        :return: The checked_images of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._checked_images

    @checked_images.setter
    def checked_images(self, checked_images):
        """Sets the checked_images of this CampaignProbeRunDto.


        :param checked_images: The checked_images of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_images is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_images`, must not be `None`")  # noqa: E501

        self._checked_images = checked_images

    @property
    def link_issue_count(self):
        """Gets the link_issue_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The link_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_count

    @link_issue_count.setter
    def link_issue_count(self, link_issue_count):
        """Sets the link_issue_count of this CampaignProbeRunDto.


        :param link_issue_count: The link_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_count`, must not be `None`")  # noqa: E501

        self._link_issue_count = link_issue_count

    @property
    def image_issue_count(self):
        """Gets the image_issue_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The image_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_count

    @image_issue_count.setter
    def image_issue_count(self, image_issue_count):
        """Sets the image_issue_count of this CampaignProbeRunDto.


        :param image_issue_count: The image_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_count`, must not be `None`")  # noqa: E501

        self._image_issue_count = image_issue_count

    @property
    def compatibility_warning_count(self):
        """Gets the compatibility_warning_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The compatibility_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_count

    @compatibility_warning_count.setter
    def compatibility_warning_count(self, compatibility_warning_count):
        """Sets the compatibility_warning_count of this CampaignProbeRunDto.


        :param compatibility_warning_count: The compatibility_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_count`, must not be `None`")  # noqa: E501

        self._compatibility_warning_count = compatibility_warning_count

    @property
    def compatibility_not_supported_count(self):
        """Gets the compatibility_not_supported_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The compatibility_not_supported_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_count

    @compatibility_not_supported_count.setter
    def compatibility_not_supported_count(self, compatibility_not_supported_count):
        """Sets the compatibility_not_supported_count of this CampaignProbeRunDto.


        :param compatibility_not_supported_count: The compatibility_not_supported_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_count`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_count = compatibility_not_supported_count

    @property
    def compatibility_unknown_count(self):
        """Gets the compatibility_unknown_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The compatibility_unknown_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_unknown_count

    @compatibility_unknown_count.setter
    def compatibility_unknown_count(self, compatibility_unknown_count):
        """Sets the compatibility_unknown_count of this CampaignProbeRunDto.


        :param compatibility_unknown_count: The compatibility_unknown_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_unknown_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_unknown_count`, must not be `None`")  # noqa: E501

        self._compatibility_unknown_count = compatibility_unknown_count

    @property
    def html_error_count(self):
        """Gets the html_error_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The html_error_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._html_error_count

    @html_error_count.setter
    def html_error_count(self, html_error_count):
        """Sets the html_error_count of this CampaignProbeRunDto.


        :param html_error_count: The html_error_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_count`, must not be `None`")  # noqa: E501

        self._html_error_count = html_error_count

    @property
    def html_warning_count(self):
        """Gets the html_warning_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The html_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_count

    @html_warning_count.setter
    def html_warning_count(self, html_warning_count):
        """Sets the html_warning_count of this CampaignProbeRunDto.


        :param html_warning_count: The html_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_count`, must not be `None`")  # noqa: E501

        self._html_warning_count = html_warning_count

    @property
    def html_info_count(self):
        """Gets the html_info_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The html_info_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._html_info_count

    @html_info_count.setter
    def html_info_count(self, html_info_count):
        """Sets the html_info_count of this CampaignProbeRunDto.


        :param html_info_count: The html_info_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_info_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_info_count`, must not be `None`")  # noqa: E501

        self._html_info_count = html_info_count

    @property
    def reputation_failure_count(self):
        """Gets the reputation_failure_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The reputation_failure_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._reputation_failure_count

    @reputation_failure_count.setter
    def reputation_failure_count(self, reputation_failure_count):
        """Sets the reputation_failure_count of this CampaignProbeRunDto.


        :param reputation_failure_count: The reputation_failure_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and reputation_failure_count is None:  # noqa: E501
            raise ValueError("Invalid value for `reputation_failure_count`, must not be `None`")  # noqa: E501

        self._reputation_failure_count = reputation_failure_count

    @property
    def attachment_mention_issue_count(self):
        """Gets the attachment_mention_issue_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The attachment_mention_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_count

    @attachment_mention_issue_count.setter
    def attachment_mention_issue_count(self, attachment_mention_issue_count):
        """Sets the attachment_mention_issue_count of this CampaignProbeRunDto.


        :param attachment_mention_issue_count: The attachment_mention_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_count`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_count = attachment_mention_issue_count

    @property
    def insights(self):
        """Gets the insights of this CampaignProbeRunDto.  # noqa: E501


        :return: The insights of this CampaignProbeRunDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CampaignProbeRunDto.


        :param insights: The insights of this CampaignProbeRunDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this CampaignProbeRunDto.  # noqa: E501


        :return: The error_message of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this CampaignProbeRunDto.


        :param error_message: The error_message of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def from_address(self):
        """Gets the from_address of this CampaignProbeRunDto.  # noqa: E501


        :return: The from_address of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this CampaignProbeRunDto.


        :param from_address: The from_address of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._from_address = from_address

    @property
    def recipient(self):
        """Gets the recipient of this CampaignProbeRunDto.  # noqa: E501


        :return: The recipient of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this CampaignProbeRunDto.


        :param recipient: The recipient of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def subject(self):
        """Gets the subject of this CampaignProbeRunDto.  # noqa: E501


        :return: The subject of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this CampaignProbeRunDto.


        :param subject: The subject of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def message_id(self):
        """Gets the message_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The message_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this CampaignProbeRunDto.


        :param message_id: The message_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def source_message_id(self):
        """Gets the source_message_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The source_message_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """Sets the source_message_id of this CampaignProbeRunDto.


        :param source_message_id: The source_message_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def processing_ms(self):
        """Gets the processing_ms of this CampaignProbeRunDto.  # noqa: E501


        :return: The processing_ms of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._processing_ms

    @processing_ms.setter
    def processing_ms(self, processing_ms):
        """Sets the processing_ms of this CampaignProbeRunDto.


        :param processing_ms: The processing_ms of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """

        self._processing_ms = processing_ms

    @property
    def created_at(self):
        """Gets the created_at of this CampaignProbeRunDto.  # noqa: E501


        :return: The created_at of this CampaignProbeRunDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CampaignProbeRunDto.


        :param created_at: The created_at of this CampaignProbeRunDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CampaignProbeRunDto.  # noqa: E501


        :return: The updated_at of this CampaignProbeRunDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CampaignProbeRunDto.


        :param updated_at: The updated_at of this CampaignProbeRunDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeRunDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeRunDto):
            return True

        return self.to_dict() != other.to_dict()
