# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckEmailAuthStackResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'spf': 'LookupSpfDomainResults',
        'dmarc': 'LookupDmarcDomainResults',
        'dkim': 'LookupDkimDomainResults',
        'bimi': 'LookupBimiDomainResults',
        'mx': 'LookupMxRecordsResults',
        'mta_sts': 'LookupMtaStsDomainResults',
        'tls_reporting': 'LookupTlsReportingDomainResults',
        'insights': 'list[str]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'domain': 'domain',
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'spf': 'spf',
        'dmarc': 'dmarc',
        'dkim': 'dkim',
        'bimi': 'bimi',
        'mx': 'mx',
        'mta_sts': 'mtaSts',
        'tls_reporting': 'tlsReporting',
        'insights': 'insights',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, domain=None, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, spf=None, dmarc=None, dkim=None, bimi=None, mx=None, mta_sts=None, tls_reporting=None, insights=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """CheckEmailAuthStackResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._spf = None
        self._dmarc = None
        self._dkim = None
        self._bimi = None
        self._mx = None
        self._mta_sts = None
        self._tls_reporting = None
        self._insights = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.domain = domain
        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.spf = spf
        self.dmarc = dmarc
        self.dkim = dkim
        self.bimi = bimi
        self.mx = mx
        self.mta_sts = mta_sts
        self.tls_reporting = tls_reporting
        self.insights = insights
        self.warnings = warnings
        self.errors = errors

    @property
    def domain(self):
        """Gets the domain of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The domain of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CheckEmailAuthStackResults.


        :param domain: The domain of this CheckEmailAuthStackResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def status(self):
        """Gets the status of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The status of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckEmailAuthStackResults.


        :param status: The status of this CheckEmailAuthStackResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "DEGRADED", "CRITICAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The health_score of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CheckEmailAuthStackResults.


        :param health_score: The health_score of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The total_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CheckEmailAuthStackResults.


        :param total_checks: The total_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The passing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CheckEmailAuthStackResults.


        :param passing_checks: The passing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The failing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CheckEmailAuthStackResults.


        :param failing_checks: The failing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def spf(self):
        """Gets the spf of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The spf of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupSpfDomainResults
        """
        return self._spf

    @spf.setter
    def spf(self, spf):
        """Sets the spf of this CheckEmailAuthStackResults.


        :param spf: The spf of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupSpfDomainResults
        """
        if self.local_vars_configuration.client_side_validation and spf is None:  # noqa: E501
            raise ValueError("Invalid value for `spf`, must not be `None`")  # noqa: E501

        self._spf = spf

    @property
    def dmarc(self):
        """Gets the dmarc of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The dmarc of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupDmarcDomainResults
        """
        return self._dmarc

    @dmarc.setter
    def dmarc(self, dmarc):
        """Sets the dmarc of this CheckEmailAuthStackResults.


        :param dmarc: The dmarc of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupDmarcDomainResults
        """
        if self.local_vars_configuration.client_side_validation and dmarc is None:  # noqa: E501
            raise ValueError("Invalid value for `dmarc`, must not be `None`")  # noqa: E501

        self._dmarc = dmarc

    @property
    def dkim(self):
        """Gets the dkim of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The dkim of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupDkimDomainResults
        """
        return self._dkim

    @dkim.setter
    def dkim(self, dkim):
        """Sets the dkim of this CheckEmailAuthStackResults.


        :param dkim: The dkim of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupDkimDomainResults
        """
        if self.local_vars_configuration.client_side_validation and dkim is None:  # noqa: E501
            raise ValueError("Invalid value for `dkim`, must not be `None`")  # noqa: E501

        self._dkim = dkim

    @property
    def bimi(self):
        """Gets the bimi of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The bimi of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupBimiDomainResults
        """
        return self._bimi

    @bimi.setter
    def bimi(self, bimi):
        """Sets the bimi of this CheckEmailAuthStackResults.


        :param bimi: The bimi of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupBimiDomainResults
        """
        if self.local_vars_configuration.client_side_validation and bimi is None:  # noqa: E501
            raise ValueError("Invalid value for `bimi`, must not be `None`")  # noqa: E501

        self._bimi = bimi

    @property
    def mx(self):
        """Gets the mx of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The mx of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupMxRecordsResults
        """
        return self._mx

    @mx.setter
    def mx(self, mx):
        """Sets the mx of this CheckEmailAuthStackResults.


        :param mx: The mx of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupMxRecordsResults
        """
        if self.local_vars_configuration.client_side_validation and mx is None:  # noqa: E501
            raise ValueError("Invalid value for `mx`, must not be `None`")  # noqa: E501

        self._mx = mx

    @property
    def mta_sts(self):
        """Gets the mta_sts of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The mta_sts of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupMtaStsDomainResults
        """
        return self._mta_sts

    @mta_sts.setter
    def mta_sts(self, mta_sts):
        """Sets the mta_sts of this CheckEmailAuthStackResults.


        :param mta_sts: The mta_sts of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupMtaStsDomainResults
        """
        if self.local_vars_configuration.client_side_validation and mta_sts is None:  # noqa: E501
            raise ValueError("Invalid value for `mta_sts`, must not be `None`")  # noqa: E501

        self._mta_sts = mta_sts

    @property
    def tls_reporting(self):
        """Gets the tls_reporting of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The tls_reporting of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupTlsReportingDomainResults
        """
        return self._tls_reporting

    @tls_reporting.setter
    def tls_reporting(self, tls_reporting):
        """Sets the tls_reporting of this CheckEmailAuthStackResults.


        :param tls_reporting: The tls_reporting of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupTlsReportingDomainResults
        """
        if self.local_vars_configuration.client_side_validation and tls_reporting is None:  # noqa: E501
            raise ValueError("Invalid value for `tls_reporting`, must not be `None`")  # noqa: E501

        self._tls_reporting = tls_reporting

    @property
    def insights(self):
        """Gets the insights of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The insights of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CheckEmailAuthStackResults.


        :param insights: The insights of this CheckEmailAuthStackResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def warnings(self):
        """Gets the warnings of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The warnings of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this CheckEmailAuthStackResults.


        :param warnings: The warnings of this CheckEmailAuthStackResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The errors of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this CheckEmailAuthStackResults.


        :param errors: The errors of this CheckEmailAuthStackResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckEmailAuthStackResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckEmailAuthStackResults):
            return True

        return self.to_dict() != other.to_dict()
