# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExtractCodesResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'found': 'bool',
        'code': 'str',
        'method_used': 'str',
        'candidates': 'list[CodeCandidate]',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'found': 'found',
        'code': 'code',
        'method_used': 'methodUsed',
        'candidates': 'candidates',
        'warnings': 'warnings'
    }

    def __init__(self, found=None, code=None, method_used=None, candidates=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """ExtractCodesResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._found = None
        self._code = None
        self._method_used = None
        self._candidates = None
        self._warnings = None
        self.discriminator = None

        self.found = found
        self.code = code
        self.method_used = method_used
        self.candidates = candidates
        self.warnings = warnings

    @property
    def found(self):
        """Gets the found of this ExtractCodesResult.  # noqa: E501

        True if at least one code candidate was found  # noqa: E501

        :return: The found of this ExtractCodesResult.  # noqa: E501
        :rtype: bool
        """
        return self._found

    @found.setter
    def found(self, found):
        """Sets the found of this ExtractCodesResult.

        True if at least one code candidate was found  # noqa: E501

        :param found: The found of this ExtractCodesResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and found is None:  # noqa: E501
            raise ValueError("Invalid value for `found`, must not be `None`")  # noqa: E501

        self._found = found

    @property
    def code(self):
        """Gets the code of this ExtractCodesResult.  # noqa: E501

        Best candidate code when found  # noqa: E501

        :return: The code of this ExtractCodesResult.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ExtractCodesResult.

        Best candidate code when found  # noqa: E501

        :param code: The code of this ExtractCodesResult.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def method_used(self):
        """Gets the method_used of this ExtractCodesResult.  # noqa: E501

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :return: The method_used of this ExtractCodesResult.  # noqa: E501
        :rtype: str
        """
        return self._method_used

    @method_used.setter
    def method_used(self, method_used):
        """Sets the method_used of this ExtractCodesResult.

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :param method_used: The method_used of this ExtractCodesResult.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"AUTO", "PATTERN", "LLM", "OCR", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method_used not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method_used` ({0}), must be one of {1}"  # noqa: E501
                .format(method_used, allowed_values)
            )

        self._method_used = method_used

    @property
    def candidates(self):
        """Gets the candidates of this ExtractCodesResult.  # noqa: E501

        Ranked code candidates  # noqa: E501

        :return: The candidates of this ExtractCodesResult.  # noqa: E501
        :rtype: list[CodeCandidate]
        """
        return self._candidates

    @candidates.setter
    def candidates(self, candidates):
        """Sets the candidates of this ExtractCodesResult.

        Ranked code candidates  # noqa: E501

        :param candidates: The candidates of this ExtractCodesResult.  # noqa: E501
        :type: list[CodeCandidate]
        """
        if self.local_vars_configuration.client_side_validation and candidates is None:  # noqa: E501
            raise ValueError("Invalid value for `candidates`, must not be `None`")  # noqa: E501

        self._candidates = candidates

    @property
    def warnings(self):
        """Gets the warnings of this ExtractCodesResult.  # noqa: E501

        Warnings or fallback notes explaining extraction behavior for debugging and QA.  # noqa: E501

        :return: The warnings of this ExtractCodesResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this ExtractCodesResult.

        Warnings or fallback notes explaining extraction behavior for debugging and QA.  # noqa: E501

        :param warnings: The warnings of this ExtractCodesResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractCodesResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExtractCodesResult):
            return True

        return self.to_dict() != other.to_dict()
