# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PlusAddressProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'inbox_id': 'str',
        'updated_at': 'datetime',
        'created_at': 'datetime',
        'plus_address': 'str',
        'full_address': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'inbox_id': 'inboxId',
        'updated_at': 'updatedAt',
        'created_at': 'createdAt',
        'plus_address': 'plusAddress',
        'full_address': 'fullAddress'
    }

    def __init__(self, id=None, user_id=None, inbox_id=None, updated_at=None, created_at=None, plus_address=None, full_address=None, local_vars_configuration=None):  # noqa: E501
        """PlusAddressProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._inbox_id = None
        self._updated_at = None
        self._created_at = None
        self._plus_address = None
        self._full_address = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.inbox_id = inbox_id
        self.updated_at = updated_at
        self.created_at = created_at
        self.plus_address = plus_address
        self.full_address = full_address

    @property
    def id(self):
        """Gets the id of this PlusAddressProjection.  # noqa: E501


        :return: The id of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlusAddressProjection.


        :param id: The id of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PlusAddressProjection.  # noqa: E501


        :return: The user_id of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PlusAddressProjection.


        :param user_id: The user_id of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this PlusAddressProjection.  # noqa: E501


        :return: The inbox_id of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this PlusAddressProjection.


        :param inbox_id: The inbox_id of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and inbox_id is None:  # noqa: E501
            raise ValueError("Invalid value for `inbox_id`, must not be `None`")  # noqa: E501

        self._inbox_id = inbox_id

    @property
    def updated_at(self):
        """Gets the updated_at of this PlusAddressProjection.  # noqa: E501


        :return: The updated_at of this PlusAddressProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PlusAddressProjection.


        :param updated_at: The updated_at of this PlusAddressProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this PlusAddressProjection.  # noqa: E501


        :return: The created_at of this PlusAddressProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PlusAddressProjection.


        :param created_at: The created_at of this PlusAddressProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def plus_address(self):
        """Gets the plus_address of this PlusAddressProjection.  # noqa: E501


        :return: The plus_address of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._plus_address

    @plus_address.setter
    def plus_address(self, plus_address):
        """Sets the plus_address of this PlusAddressProjection.


        :param plus_address: The plus_address of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and plus_address is None:  # noqa: E501
            raise ValueError("Invalid value for `plus_address`, must not be `None`")  # noqa: E501

        self._plus_address = plus_address

    @property
    def full_address(self):
        """Gets the full_address of this PlusAddressProjection.  # noqa: E501


        :return: The full_address of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._full_address

    @full_address.setter
    def full_address(self, full_address):
        """Sets the full_address of this PlusAddressProjection.


        :param full_address: The full_address of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and full_address is None:  # noqa: E501
            raise ValueError("Invalid value for `full_address`, must not be `None`")  # noqa: E501

        self._full_address = full_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlusAddressProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlusAddressProjection):
            return True

        return self.to_dict() != other.to_dict()
