# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityExpectationResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'expectation_index': 'int',
        'expectation_name': 'str',
        'min_count': 'int',
        'actual_count': 'int',
        'passed': 'bool',
        '_from': 'str',
        'to': 'str',
        'subject': 'str'
    }

    attribute_map = {
        'expectation_index': 'expectationIndex',
        'expectation_name': 'expectationName',
        'min_count': 'minCount',
        'actual_count': 'actualCount',
        'passed': 'passed',
        '_from': 'from',
        'to': 'to',
        'subject': 'subject'
    }

    def __init__(self, expectation_index=None, expectation_name=None, min_count=None, actual_count=None, passed=None, _from=None, to=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityExpectationResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._expectation_index = None
        self._expectation_name = None
        self._min_count = None
        self._actual_count = None
        self._passed = None
        self.__from = None
        self._to = None
        self._subject = None
        self.discriminator = None

        self.expectation_index = expectation_index
        self.expectation_name = expectation_name
        self.min_count = min_count
        self.actual_count = actual_count
        self.passed = passed
        self._from = _from
        self.to = to
        self.subject = subject

    @property
    def expectation_index(self):
        """Gets the expectation_index of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The expectation_index of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: int
        """
        return self._expectation_index

    @expectation_index.setter
    def expectation_index(self, expectation_index):
        """Sets the expectation_index of this DeliverabilityExpectationResultDto.


        :param expectation_index: The expectation_index of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and expectation_index is None:  # noqa: E501
            raise ValueError("Invalid value for `expectation_index`, must not be `None`")  # noqa: E501

        self._expectation_index = expectation_index

    @property
    def expectation_name(self):
        """Gets the expectation_name of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The expectation_name of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self._expectation_name

    @expectation_name.setter
    def expectation_name(self, expectation_name):
        """Sets the expectation_name of this DeliverabilityExpectationResultDto.


        :param expectation_name: The expectation_name of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self._expectation_name = expectation_name

    @property
    def min_count(self):
        """Gets the min_count of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The min_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this DeliverabilityExpectationResultDto.


        :param min_count: The min_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and min_count is None:  # noqa: E501
            raise ValueError("Invalid value for `min_count`, must not be `None`")  # noqa: E501

        self._min_count = min_count

    @property
    def actual_count(self):
        """Gets the actual_count of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The actual_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: int
        """
        return self._actual_count

    @actual_count.setter
    def actual_count(self, actual_count):
        """Sets the actual_count of this DeliverabilityExpectationResultDto.


        :param actual_count: The actual_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and actual_count is None:  # noqa: E501
            raise ValueError("Invalid value for `actual_count`, must not be `None`")  # noqa: E501

        self._actual_count = actual_count

    @property
    def passed(self):
        """Gets the passed of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The passed of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: bool
        """
        return self._passed

    @passed.setter
    def passed(self, passed):
        """Sets the passed of this DeliverabilityExpectationResultDto.


        :param passed: The passed of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and passed is None:  # noqa: E501
            raise ValueError("Invalid value for `passed`, must not be `None`")  # noqa: E501

        self._passed = passed

    @property
    def _from(self):
        """Gets the _from of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The _from of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this DeliverabilityExpectationResultDto.


        :param _from: The _from of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The to of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this DeliverabilityExpectationResultDto.


        :param to: The to of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def subject(self):
        """Gets the subject of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The subject of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DeliverabilityExpectationResultDto.


        :param subject: The subject of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityExpectationResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityExpectationResultDto):
            return True

        return self.to_dict() != other.to_dict()
