# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookNewAITransformResultPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_id': 'str',
        'webhook_id': 'str',
        'event_name': 'str',
        'webhook_name': 'str',
        'ai_transform_result_id': 'str',
        'user_id': 'str',
        'ai_transform_id': 'str',
        'ai_transform_mapping_id': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'result': 'str'
    }

    attribute_map = {
        'message_id': 'messageId',
        'webhook_id': 'webhookId',
        'event_name': 'eventName',
        'webhook_name': 'webhookName',
        'ai_transform_result_id': 'aiTransformResultId',
        'user_id': 'userId',
        'ai_transform_id': 'aiTransformId',
        'ai_transform_mapping_id': 'aiTransformMappingId',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'result': 'result'
    }

    def __init__(self, message_id=None, webhook_id=None, event_name=None, webhook_name=None, ai_transform_result_id=None, user_id=None, ai_transform_id=None, ai_transform_mapping_id=None, entity_id=None, entity_type=None, result=None, local_vars_configuration=None):  # noqa: E501
        """WebhookNewAITransformResultPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message_id = None
        self._webhook_id = None
        self._event_name = None
        self._webhook_name = None
        self._ai_transform_result_id = None
        self._user_id = None
        self._ai_transform_id = None
        self._ai_transform_mapping_id = None
        self._entity_id = None
        self._entity_type = None
        self._result = None
        self.discriminator = None

        self.message_id = message_id
        self.webhook_id = webhook_id
        self.event_name = event_name
        self.webhook_name = webhook_name
        self.ai_transform_result_id = ai_transform_result_id
        self.user_id = user_id
        self.ai_transform_id = ai_transform_id
        self.ai_transform_mapping_id = ai_transform_mapping_id
        self.entity_id = entity_id
        self.entity_type = entity_type
        self.result = result

    @property
    def message_id(self):
        """Gets the message_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :return: The message_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this WebhookNewAITransformResultPayload.

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :param message_id: The message_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of webhook entity being triggered  # noqa: E501

        :return: The webhook_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookNewAITransformResultPayload.

        ID of webhook entity being triggered  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_id is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_id`, must not be `None`")  # noqa: E501

        self._webhook_id = webhook_id

    @property
    def event_name(self):
        """Gets the event_name of this WebhookNewAITransformResultPayload.  # noqa: E501

        Name of the event type webhook is being triggered for.  # noqa: E501

        :return: The event_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookNewAITransformResultPayload.

        Name of the event type webhook is being triggered for.  # noqa: E501

        :param event_name: The event_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_RECEIVED", "NEW_AI_TRANSFORM_RESULT", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def webhook_name(self):
        """Gets the webhook_name of this WebhookNewAITransformResultPayload.  # noqa: E501

        Name of the webhook being triggered  # noqa: E501

        :return: The webhook_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_name

    @webhook_name.setter
    def webhook_name(self, webhook_name):
        """Sets the webhook_name of this WebhookNewAITransformResultPayload.

        Name of the webhook being triggered  # noqa: E501

        :param webhook_name: The webhook_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._webhook_name = webhook_name

    @property
    def ai_transform_result_id(self):
        """Gets the ai_transform_result_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        AI Transform ID of event  # noqa: E501

        :return: The ai_transform_result_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_result_id

    @ai_transform_result_id.setter
    def ai_transform_result_id(self, ai_transform_result_id):
        """Sets the ai_transform_result_id of this WebhookNewAITransformResultPayload.

        AI Transform ID of event  # noqa: E501

        :param ai_transform_result_id: The ai_transform_result_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_result_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_result_id`, must not be `None`")  # noqa: E501

        self._ai_transform_result_id = ai_transform_result_id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        User ID of event  # noqa: E501

        :return: The user_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookNewAITransformResultPayload.

        User ID of event  # noqa: E501

        :param user_id: The user_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of AI Transform  # noqa: E501

        :return: The ai_transform_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this WebhookNewAITransformResultPayload.

        ID of AI Transform  # noqa: E501

        :param ai_transform_id: The ai_transform_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_id`, must not be `None`")  # noqa: E501

        self._ai_transform_id = ai_transform_id

    @property
    def ai_transform_mapping_id(self):
        """Gets the ai_transform_mapping_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of AI Transform mapping  # noqa: E501

        :return: The ai_transform_mapping_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_mapping_id

    @ai_transform_mapping_id.setter
    def ai_transform_mapping_id(self, ai_transform_mapping_id):
        """Sets the ai_transform_mapping_id of this WebhookNewAITransformResultPayload.

        ID of AI Transform mapping  # noqa: E501

        :param ai_transform_mapping_id: The ai_transform_mapping_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._ai_transform_mapping_id = ai_transform_mapping_id

    @property
    def entity_id(self):
        """Gets the entity_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of entity that triggered the transformation  # noqa: E501

        :return: The entity_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this WebhookNewAITransformResultPayload.

        ID of entity that triggered the transformation  # noqa: E501

        :param entity_id: The entity_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this WebhookNewAITransformResultPayload.  # noqa: E501

        Entity type that triggered the transformation  # noqa: E501

        :return: The entity_type of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this WebhookNewAITransformResultPayload.

        Entity type that triggered the transformation  # noqa: E501

        :param entity_type: The entity_type of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def result(self):
        """Gets the result of this WebhookNewAITransformResultPayload.  # noqa: E501

        JSON string result of the AI transformation  # noqa: E501

        :return: The result of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this WebhookNewAITransformResultPayload.

        JSON string result of the AI transformation  # noqa: E501

        :param result: The result of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookNewAITransformResultPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookNewAITransformResultPayload):
            return True

        return self.to_dict() != other.to_dict()
