# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'domain': 'str',
        'name': 'str',
        'interval_seconds': 'int',
        'enabled': 'bool',
        'scheduling_enabled': 'bool',
        'last_status': 'str',
        'health_score': 'int',
        'last_run_at': 'datetime',
        'next_run_at': 'datetime',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'domain': 'domain',
        'name': 'name',
        'interval_seconds': 'intervalSeconds',
        'enabled': 'enabled',
        'scheduling_enabled': 'schedulingEnabled',
        'last_status': 'lastStatus',
        'health_score': 'healthScore',
        'last_run_at': 'lastRunAt',
        'next_run_at': 'nextRunAt',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, domain=None, name=None, interval_seconds=None, enabled=None, scheduling_enabled=None, last_status=None, health_score=None, last_run_at=None, next_run_at=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._domain = None
        self._name = None
        self._interval_seconds = None
        self._enabled = None
        self._scheduling_enabled = None
        self._last_status = None
        self._health_score = None
        self._last_run_at = None
        self._next_run_at = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.domain = domain
        if name is not None:
            self.name = name
        if interval_seconds is not None:
            self.interval_seconds = interval_seconds
        self.enabled = enabled
        self.scheduling_enabled = scheduling_enabled
        if last_status is not None:
            self.last_status = last_status
        if health_score is not None:
            self.health_score = health_score
        if last_run_at is not None:
            self.last_run_at = last_run_at
        if next_run_at is not None:
            self.next_run_at = next_run_at
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DomainMonitorDto.  # noqa: E501


        :return: The id of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DomainMonitorDto.


        :param id: The id of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this DomainMonitorDto.  # noqa: E501


        :return: The user_id of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DomainMonitorDto.


        :param user_id: The user_id of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def domain(self):
        """Gets the domain of this DomainMonitorDto.  # noqa: E501


        :return: The domain of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this DomainMonitorDto.


        :param domain: The domain of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def name(self):
        """Gets the name of this DomainMonitorDto.  # noqa: E501


        :return: The name of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DomainMonitorDto.


        :param name: The name of this DomainMonitorDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def interval_seconds(self):
        """Gets the interval_seconds of this DomainMonitorDto.  # noqa: E501


        :return: The interval_seconds of this DomainMonitorDto.  # noqa: E501
        :rtype: int
        """
        return self._interval_seconds

    @interval_seconds.setter
    def interval_seconds(self, interval_seconds):
        """Sets the interval_seconds of this DomainMonitorDto.


        :param interval_seconds: The interval_seconds of this DomainMonitorDto.  # noqa: E501
        :type: int
        """

        self._interval_seconds = interval_seconds

    @property
    def enabled(self):
        """Gets the enabled of this DomainMonitorDto.  # noqa: E501


        :return: The enabled of this DomainMonitorDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DomainMonitorDto.


        :param enabled: The enabled of this DomainMonitorDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def scheduling_enabled(self):
        """Gets the scheduling_enabled of this DomainMonitorDto.  # noqa: E501


        :return: The scheduling_enabled of this DomainMonitorDto.  # noqa: E501
        :rtype: bool
        """
        return self._scheduling_enabled

    @scheduling_enabled.setter
    def scheduling_enabled(self, scheduling_enabled):
        """Sets the scheduling_enabled of this DomainMonitorDto.


        :param scheduling_enabled: The scheduling_enabled of this DomainMonitorDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and scheduling_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `scheduling_enabled`, must not be `None`")  # noqa: E501

        self._scheduling_enabled = scheduling_enabled

    @property
    def last_status(self):
        """Gets the last_status of this DomainMonitorDto.  # noqa: E501


        :return: The last_status of this DomainMonitorDto.  # noqa: E501
        :rtype: str
        """
        return self._last_status

    @last_status.setter
    def last_status(self, last_status):
        """Sets the last_status of this DomainMonitorDto.


        :param last_status: The last_status of this DomainMonitorDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["HEALTHY", "DEGRADED", "CRITICAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and last_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `last_status` ({0}), must be one of {1}"  # noqa: E501
                .format(last_status, allowed_values)
            )

        self._last_status = last_status

    @property
    def health_score(self):
        """Gets the health_score of this DomainMonitorDto.  # noqa: E501


        :return: The health_score of this DomainMonitorDto.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this DomainMonitorDto.


        :param health_score: The health_score of this DomainMonitorDto.  # noqa: E501
        :type: int
        """

        self._health_score = health_score

    @property
    def last_run_at(self):
        """Gets the last_run_at of this DomainMonitorDto.  # noqa: E501


        :return: The last_run_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_run_at

    @last_run_at.setter
    def last_run_at(self, last_run_at):
        """Sets the last_run_at of this DomainMonitorDto.


        :param last_run_at: The last_run_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """

        self._last_run_at = last_run_at

    @property
    def next_run_at(self):
        """Gets the next_run_at of this DomainMonitorDto.  # noqa: E501


        :return: The next_run_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._next_run_at

    @next_run_at.setter
    def next_run_at(self, next_run_at):
        """Sets the next_run_at of this DomainMonitorDto.


        :param next_run_at: The next_run_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """

        self._next_run_at = next_run_at

    @property
    def created_at(self):
        """Gets the created_at of this DomainMonitorDto.  # noqa: E501


        :return: The created_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DomainMonitorDto.


        :param created_at: The created_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DomainMonitorDto.  # noqa: E501


        :return: The updated_at of this DomainMonitorDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DomainMonitorDto.


        :param updated_at: The updated_at of this DomainMonitorDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorDto):
            return True

        return self.to_dict() != other.to_dict()
