# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.missed_sms_controller_api import MissedSmsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestMissedSmsControllerApi(unittest.TestCase):
    """MissedSmsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.missed_sms_controller_api.MissedSmsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_missed_sms_messages(self):
        """Test case for get_all_missed_sms_messages

        Get all missed SMS messages in paginated format  # noqa: E501
        """
        pass

    def test_get_missed_sms_count(self):
        """Test case for get_missed_sms_count

        Get missed SMS count  # noqa: E501
        """
        pass

    def test_get_missed_sms_message(self):
        """Test case for get_missed_sms_message

        Get missed SMS content  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
