# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateBimiRecordOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'version': 'str',
        'logo_url': 'str',
        'vmc_url': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'version': 'version',
        'logo_url': 'logoUrl',
        'vmc_url': 'vmcUrl'
    }

    def __init__(self, domain=None, version=None, logo_url=None, vmc_url=None, local_vars_configuration=None):  # noqa: E501
        """GenerateBimiRecordOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._version = None
        self._logo_url = None
        self._vmc_url = None
        self.discriminator = None

        self.domain = domain
        self.version = version
        self.logo_url = logo_url
        if vmc_url is not None:
            self.vmc_url = vmc_url

    @property
    def domain(self):
        """Gets the domain of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The domain of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this GenerateBimiRecordOptions.


        :param domain: The domain of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def version(self):
        """Gets the version of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The version of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this GenerateBimiRecordOptions.


        :param version: The version of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501
        allowed_values = ["BIMI1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and version not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `version` ({0}), must be one of {1}"  # noqa: E501
                .format(version, allowed_values)
            )

        self._version = version

    @property
    def logo_url(self):
        """Gets the logo_url of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The logo_url of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """Sets the logo_url of this GenerateBimiRecordOptions.


        :param logo_url: The logo_url of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and logo_url is None:  # noqa: E501
            raise ValueError("Invalid value for `logo_url`, must not be `None`")  # noqa: E501

        self._logo_url = logo_url

    @property
    def vmc_url(self):
        """Gets the vmc_url of this GenerateBimiRecordOptions.  # noqa: E501


        :return: The vmc_url of this GenerateBimiRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._vmc_url

    @vmc_url.setter
    def vmc_url(self, vmc_url):
        """Sets the vmc_url of this GenerateBimiRecordOptions.


        :param vmc_url: The vmc_url of this GenerateBimiRecordOptions.  # noqa: E501
        :type: str
        """

        self._vmc_url = vmc_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateBimiRecordOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateBimiRecordOptions):
            return True

        return self.to_dict() != other.to_dict()
