# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateCampaignProbeOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'enabled': 'bool',
        'interval_seconds': 'int',
        'scheduling_enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'enabled': 'enabled',
        'interval_seconds': 'intervalSeconds',
        'scheduling_enabled': 'schedulingEnabled'
    }

    def __init__(self, name=None, enabled=None, interval_seconds=None, scheduling_enabled=None, local_vars_configuration=None):  # noqa: E501
        """CreateCampaignProbeOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._enabled = None
        self._interval_seconds = None
        self._scheduling_enabled = None
        self.discriminator = None

        self.name = name
        self.enabled = enabled
        self.interval_seconds = interval_seconds
        self.scheduling_enabled = scheduling_enabled

    @property
    def name(self):
        """Gets the name of this CreateCampaignProbeOptions.  # noqa: E501

        Optional display name  # noqa: E501

        :return: The name of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateCampaignProbeOptions.

        Optional display name  # noqa: E501

        :param name: The name of this CreateCampaignProbeOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 200):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def enabled(self):
        """Gets the enabled of this CreateCampaignProbeOptions.  # noqa: E501

        Whether SES monitor ingestion is enabled for this probe  # noqa: E501

        :return: The enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateCampaignProbeOptions.

        Whether SES monitor ingestion is enabled for this probe  # noqa: E501

        :param enabled: The enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def interval_seconds(self):
        """Gets the interval_seconds of this CreateCampaignProbeOptions.  # noqa: E501

        Scheduled run interval in seconds  # noqa: E501

        :return: The interval_seconds of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: int
        """
        return self._interval_seconds

    @interval_seconds.setter
    def interval_seconds(self, interval_seconds):
        """Sets the interval_seconds of this CreateCampaignProbeOptions.

        Scheduled run interval in seconds  # noqa: E501

        :param interval_seconds: The interval_seconds of this CreateCampaignProbeOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                interval_seconds is not None and interval_seconds > 604800):  # noqa: E501
            raise ValueError("Invalid value for `interval_seconds`, must be a value less than or equal to `604800`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                interval_seconds is not None and interval_seconds < 60):  # noqa: E501
            raise ValueError("Invalid value for `interval_seconds`, must be a value greater than or equal to `60`")  # noqa: E501

        self._interval_seconds = interval_seconds

    @property
    def scheduling_enabled(self):
        """Gets the scheduling_enabled of this CreateCampaignProbeOptions.  # noqa: E501

        Whether scheduled campaign probe runs are enabled. Direct run-now remains available.  # noqa: E501

        :return: The scheduling_enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :rtype: bool
        """
        return self._scheduling_enabled

    @scheduling_enabled.setter
    def scheduling_enabled(self, scheduling_enabled):
        """Sets the scheduling_enabled of this CreateCampaignProbeOptions.

        Whether scheduled campaign probe runs are enabled. Direct run-now remains available.  # noqa: E501

        :param scheduling_enabled: The scheduling_enabled of this CreateCampaignProbeOptions.  # noqa: E501
        :type: bool
        """

        self._scheduling_enabled = scheduling_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateCampaignProbeOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateCampaignProbeOptions):
            return True

        return self.to_dict() != other.to_dict()
