# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxAutomationMatchOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'operator': 'str',
        'matches': 'list[InboxAutomationMatchOption]',
        'groups': 'list[InboxAutomationMatchOptions]'
    }

    attribute_map = {
        'operator': 'operator',
        'matches': 'matches',
        'groups': 'groups'
    }

    def __init__(self, operator=None, matches=None, groups=None, local_vars_configuration=None):  # noqa: E501
        """InboxAutomationMatchOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._operator = None
        self._matches = None
        self._groups = None
        self.discriminator = None

        self.operator = operator
        self.matches = matches
        self.groups = groups

    @property
    def operator(self):
        """Gets the operator of this InboxAutomationMatchOptions.  # noqa: E501

        Boolean operator used to combine inbox automation match rules.  # noqa: E501

        :return: The operator of this InboxAutomationMatchOptions.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this InboxAutomationMatchOptions.

        Boolean operator used to combine inbox automation match rules.  # noqa: E501

        :param operator: The operator of this InboxAutomationMatchOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["AND", "OR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    @property
    def matches(self):
        """Gets the matches of this InboxAutomationMatchOptions.  # noqa: E501

        Leaf match rules in this group.  # noqa: E501

        :return: The matches of this InboxAutomationMatchOptions.  # noqa: E501
        :rtype: list[InboxAutomationMatchOption]
        """
        return self._matches

    @matches.setter
    def matches(self, matches):
        """Sets the matches of this InboxAutomationMatchOptions.

        Leaf match rules in this group.  # noqa: E501

        :param matches: The matches of this InboxAutomationMatchOptions.  # noqa: E501
        :type: list[InboxAutomationMatchOption]
        """

        self._matches = matches

    @property
    def groups(self):
        """Gets the groups of this InboxAutomationMatchOptions.  # noqa: E501

        Nested child groups.  # noqa: E501

        :return: The groups of this InboxAutomationMatchOptions.  # noqa: E501
        :rtype: list[InboxAutomationMatchOptions]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this InboxAutomationMatchOptions.

        Nested child groups.  # noqa: E501

        :param groups: The groups of this InboxAutomationMatchOptions.  # noqa: E501
        :type: list[InboxAutomationMatchOptions]
        """

        self._groups = groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxAutomationMatchOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxAutomationMatchOptions):
            return True

        return self.to_dict() != other.to_dict()
