# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DmarcReportSourceSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_ip': 'str',
        'count': 'int',
        'disposition': 'str',
        'dkim_aligned': 'bool',
        'spf_aligned': 'bool',
        'header_from': 'str'
    }

    attribute_map = {
        'source_ip': 'sourceIp',
        'count': 'count',
        'disposition': 'disposition',
        'dkim_aligned': 'dkimAligned',
        'spf_aligned': 'spfAligned',
        'header_from': 'headerFrom'
    }

    def __init__(self, source_ip=None, count=None, disposition=None, dkim_aligned=None, spf_aligned=None, header_from=None, local_vars_configuration=None):  # noqa: E501
        """DmarcReportSourceSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source_ip = None
        self._count = None
        self._disposition = None
        self._dkim_aligned = None
        self._spf_aligned = None
        self._header_from = None
        self.discriminator = None

        self.source_ip = source_ip
        self.count = count
        self.disposition = disposition
        self.dkim_aligned = dkim_aligned
        self.spf_aligned = spf_aligned
        self.header_from = header_from

    @property
    def source_ip(self):
        """Gets the source_ip of this DmarcReportSourceSummary.  # noqa: E501


        :return: The source_ip of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: str
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, source_ip):
        """Sets the source_ip of this DmarcReportSourceSummary.


        :param source_ip: The source_ip of this DmarcReportSourceSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source_ip is None:  # noqa: E501
            raise ValueError("Invalid value for `source_ip`, must not be `None`")  # noqa: E501

        self._source_ip = source_ip

    @property
    def count(self):
        """Gets the count of this DmarcReportSourceSummary.  # noqa: E501


        :return: The count of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this DmarcReportSourceSummary.


        :param count: The count of this DmarcReportSourceSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and count is None:  # noqa: E501
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def disposition(self):
        """Gets the disposition of this DmarcReportSourceSummary.  # noqa: E501


        :return: The disposition of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: str
        """
        return self._disposition

    @disposition.setter
    def disposition(self, disposition):
        """Sets the disposition of this DmarcReportSourceSummary.


        :param disposition: The disposition of this DmarcReportSourceSummary.  # noqa: E501
        :type: str
        """

        self._disposition = disposition

    @property
    def dkim_aligned(self):
        """Gets the dkim_aligned of this DmarcReportSourceSummary.  # noqa: E501


        :return: The dkim_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: bool
        """
        return self._dkim_aligned

    @dkim_aligned.setter
    def dkim_aligned(self, dkim_aligned):
        """Sets the dkim_aligned of this DmarcReportSourceSummary.


        :param dkim_aligned: The dkim_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and dkim_aligned is None:  # noqa: E501
            raise ValueError("Invalid value for `dkim_aligned`, must not be `None`")  # noqa: E501

        self._dkim_aligned = dkim_aligned

    @property
    def spf_aligned(self):
        """Gets the spf_aligned of this DmarcReportSourceSummary.  # noqa: E501


        :return: The spf_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: bool
        """
        return self._spf_aligned

    @spf_aligned.setter
    def spf_aligned(self, spf_aligned):
        """Sets the spf_aligned of this DmarcReportSourceSummary.


        :param spf_aligned: The spf_aligned of this DmarcReportSourceSummary.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and spf_aligned is None:  # noqa: E501
            raise ValueError("Invalid value for `spf_aligned`, must not be `None`")  # noqa: E501

        self._spf_aligned = spf_aligned

    @property
    def header_from(self):
        """Gets the header_from of this DmarcReportSourceSummary.  # noqa: E501


        :return: The header_from of this DmarcReportSourceSummary.  # noqa: E501
        :rtype: str
        """
        return self._header_from

    @header_from.setter
    def header_from(self, header_from):
        """Sets the header_from of this DmarcReportSourceSummary.


        :param header_from: The header_from of this DmarcReportSourceSummary.  # noqa: E501
        :type: str
        """

        self._header_from = header_from

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DmarcReportSourceSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DmarcReportSourceSummary):
            return True

        return self.to_dict() != other.to_dict()
