# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySimulationJobEventDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'event_type': 'str',
        'send_index': 'int',
        'entity_id': 'str',
        'target_label': 'str',
        'expectation_name': 'str',
        'attempt': 'int',
        'message': 'str',
        'error': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'event_type': 'eventType',
        'send_index': 'sendIndex',
        'entity_id': 'entityId',
        'target_label': 'targetLabel',
        'expectation_name': 'expectationName',
        'attempt': 'attempt',
        'message': 'message',
        'error': 'error',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, event_type=None, send_index=None, entity_id=None, target_label=None, expectation_name=None, attempt=None, message=None, error=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySimulationJobEventDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._event_type = None
        self._send_index = None
        self._entity_id = None
        self._target_label = None
        self._expectation_name = None
        self._attempt = None
        self._message = None
        self._error = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.event_type = event_type
        self.send_index = send_index
        self.entity_id = entity_id
        self.target_label = target_label
        self.expectation_name = expectation_name
        self.attempt = attempt
        self.message = message
        self.error = error
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeliverabilitySimulationJobEventDto.


        :param id: The id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def event_type(self):
        """Gets the event_type of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The event_type of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this DeliverabilitySimulationJobEventDto.


        :param event_type: The event_type of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_type is None:  # noqa: E501
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501
        allowed_values = ["JOB_CREATED", "JOB_STARTED", "JOB_PAUSED", "JOB_RESUMED", "JOB_CANCELLED", "JOB_COMPLETED", "JOB_FAILED", "SEND_SUCCESS", "SEND_FAILURE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def send_index(self):
        """Gets the send_index of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The send_index of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: int
        """
        return self._send_index

    @send_index.setter
    def send_index(self, send_index):
        """Sets the send_index of this DeliverabilitySimulationJobEventDto.


        :param send_index: The send_index of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: int
        """

        self._send_index = send_index

    @property
    def entity_id(self):
        """Gets the entity_id of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The entity_id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this DeliverabilitySimulationJobEventDto.


        :param entity_id: The entity_id of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def target_label(self):
        """Gets the target_label of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The target_label of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._target_label

    @target_label.setter
    def target_label(self, target_label):
        """Sets the target_label of this DeliverabilitySimulationJobEventDto.


        :param target_label: The target_label of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._target_label = target_label

    @property
    def expectation_name(self):
        """Gets the expectation_name of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The expectation_name of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._expectation_name

    @expectation_name.setter
    def expectation_name(self, expectation_name):
        """Sets the expectation_name of this DeliverabilitySimulationJobEventDto.


        :param expectation_name: The expectation_name of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._expectation_name = expectation_name

    @property
    def attempt(self):
        """Gets the attempt of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The attempt of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: int
        """
        return self._attempt

    @attempt.setter
    def attempt(self, attempt):
        """Sets the attempt of this DeliverabilitySimulationJobEventDto.


        :param attempt: The attempt of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: int
        """

        self._attempt = attempt

    @property
    def message(self):
        """Gets the message of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The message of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DeliverabilitySimulationJobEventDto.


        :param message: The message of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def error(self):
        """Gets the error of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The error of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this DeliverabilitySimulationJobEventDto.


        :param error: The error of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def created_at(self):
        """Gets the created_at of this DeliverabilitySimulationJobEventDto.  # noqa: E501


        :return: The created_at of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DeliverabilitySimulationJobEventDto.


        :param created_at: The created_at of this DeliverabilitySimulationJobEventDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySimulationJobEventDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySimulationJobEventDto):
            return True

        return self.to_dict() != other.to_dict()
