# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainRegionInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain_name': 'str',
        'verified': 'bool',
        'domain_type': 'str',
        'account_region': 'str',
        'creation_enabled': 'bool',
        'sending_enabled': 'bool',
        'active': 'bool'
    }

    attribute_map = {
        'domain_name': 'domainName',
        'verified': 'verified',
        'domain_type': 'domainType',
        'account_region': 'accountRegion',
        'creation_enabled': 'creationEnabled',
        'sending_enabled': 'sendingEnabled',
        'active': 'active'
    }

    def __init__(self, domain_name=None, verified=None, domain_type=None, account_region=None, creation_enabled=None, sending_enabled=None, active=None, local_vars_configuration=None):  # noqa: E501
        """DomainRegionInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain_name = None
        self._verified = None
        self._domain_type = None
        self._account_region = None
        self._creation_enabled = None
        self._sending_enabled = None
        self._active = None
        self.discriminator = None

        self.domain_name = domain_name
        self.verified = verified
        self.domain_type = domain_type
        self.account_region = account_region
        self.creation_enabled = creation_enabled
        self.sending_enabled = sending_enabled
        self.active = active

    @property
    def domain_name(self):
        """Gets the domain_name of this DomainRegionInformation.  # noqa: E501


        :return: The domain_name of this DomainRegionInformation.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this DomainRegionInformation.


        :param domain_name: The domain_name of this DomainRegionInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain_name is None:  # noqa: E501
            raise ValueError("Invalid value for `domain_name`, must not be `None`")  # noqa: E501

        self._domain_name = domain_name

    @property
    def verified(self):
        """Gets the verified of this DomainRegionInformation.  # noqa: E501


        :return: The verified of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._verified

    @verified.setter
    def verified(self, verified):
        """Sets the verified of this DomainRegionInformation.


        :param verified: The verified of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and verified is None:  # noqa: E501
            raise ValueError("Invalid value for `verified`, must not be `None`")  # noqa: E501

        self._verified = verified

    @property
    def domain_type(self):
        """Gets the domain_type of this DomainRegionInformation.  # noqa: E501

        Type of domain. Dictates type of inbox that can be created with domain. HTTP means inboxes are processed using SES while SMTP inboxes use a custom SMTP mail server. SMTP does not support sending so use HTTP for sending emails.  # noqa: E501

        :return: The domain_type of this DomainRegionInformation.  # noqa: E501
        :rtype: str
        """
        return self._domain_type

    @domain_type.setter
    def domain_type(self, domain_type):
        """Sets the domain_type of this DomainRegionInformation.

        Type of domain. Dictates type of inbox that can be created with domain. HTTP means inboxes are processed using SES while SMTP inboxes use a custom SMTP mail server. SMTP does not support sending so use HTTP for sending emails.  # noqa: E501

        :param domain_type: The domain_type of this DomainRegionInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain_type is None:  # noqa: E501
            raise ValueError("Invalid value for `domain_type`, must not be `None`")  # noqa: E501
        allowed_values = ["HTTP_INBOX", "SMTP_DOMAIN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and domain_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `domain_type` ({0}), must be one of {1}"  # noqa: E501
                .format(domain_type, allowed_values)
            )

        self._domain_type = domain_type

    @property
    def account_region(self):
        """Gets the account_region of this DomainRegionInformation.  # noqa: E501


        :return: The account_region of this DomainRegionInformation.  # noqa: E501
        :rtype: str
        """
        return self._account_region

    @account_region.setter
    def account_region(self, account_region):
        """Sets the account_region of this DomainRegionInformation.


        :param account_region: The account_region of this DomainRegionInformation.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US_WEST_2_ACCOUNT_STAGING", "US_EAST_1_ACCOUNT_STAGING", "EU_WEST_1_ACCOUNT_STAGING", "US_WEST_2_ACCOUNT_SES_1", "EU_WEST_1_ACCOUNT_SES_1", "US_WEST_2_ACCOUNT_SES_2", "EU_WEST_1_ACCOUNT_SES_2", "US_WEST_2_ACCOUNT_BYTEWISE", "EU_WEST_1_ACCOUNT_BYTEWISE", "US_WEST_2", "EU_WEST_1", "US_EAST_1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account_region not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account_region` ({0}), must be one of {1}"  # noqa: E501
                .format(account_region, allowed_values)
            )

        self._account_region = account_region

    @property
    def creation_enabled(self):
        """Gets the creation_enabled of this DomainRegionInformation.  # noqa: E501


        :return: The creation_enabled of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._creation_enabled

    @creation_enabled.setter
    def creation_enabled(self, creation_enabled):
        """Sets the creation_enabled of this DomainRegionInformation.


        :param creation_enabled: The creation_enabled of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and creation_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `creation_enabled`, must not be `None`")  # noqa: E501

        self._creation_enabled = creation_enabled

    @property
    def sending_enabled(self):
        """Gets the sending_enabled of this DomainRegionInformation.  # noqa: E501


        :return: The sending_enabled of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._sending_enabled

    @sending_enabled.setter
    def sending_enabled(self, sending_enabled):
        """Sets the sending_enabled of this DomainRegionInformation.


        :param sending_enabled: The sending_enabled of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and sending_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `sending_enabled`, must not be `None`")  # noqa: E501

        self._sending_enabled = sending_enabled

    @property
    def active(self):
        """Gets the active of this DomainRegionInformation.  # noqa: E501


        :return: The active of this DomainRegionInformation.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this DomainRegionInformation.


        :param active: The active of this DomainRegionInformation.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and active is None:  # noqa: E501
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainRegionInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainRegionInformation):
            return True

        return self.to_dict() != other.to_dict()
