# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneSmsPrepaidCreditDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'phone_country': 'str',
        '_global': 'bool',
        'remaining_credits': 'int',
        'initial_credits': 'int',
        'sent_multiplier': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'phone_country': 'phoneCountry',
        '_global': 'global',
        'remaining_credits': 'remainingCredits',
        'initial_credits': 'initialCredits',
        'sent_multiplier': 'sentMultiplier',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, phone_country=None, _global=None, remaining_credits=None, initial_credits=None, sent_multiplier=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """PhoneSmsPrepaidCreditDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._phone_country = None
        self.__global = None
        self._remaining_credits = None
        self._initial_credits = None
        self._sent_multiplier = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.phone_country = phone_country
        self._global = _global
        self.remaining_credits = remaining_credits
        self.initial_credits = initial_credits
        self.sent_multiplier = sent_multiplier
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The id of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneSmsPrepaidCreditDto.


        :param id: The id of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneSmsPrepaidCreditDto.  # noqa: E501

        Null means the balance is global for the account rather than country-specific.  # noqa: E501

        :return: The phone_country of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneSmsPrepaidCreditDto.

        Null means the balance is global for the account rather than country-specific.  # noqa: E501

        :param phone_country: The phone_country of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def _global(self):
        """Gets the _global of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The _global of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: bool
        """
        return self.__global

    @_global.setter
    def _global(self, _global):
        """Sets the _global of this PhoneSmsPrepaidCreditDto.


        :param _global: The _global of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and _global is None:  # noqa: E501
            raise ValueError("Invalid value for `_global`, must not be `None`")  # noqa: E501

        self.__global = _global

    @property
    def remaining_credits(self):
        """Gets the remaining_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The remaining_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: int
        """
        return self._remaining_credits

    @remaining_credits.setter
    def remaining_credits(self, remaining_credits):
        """Sets the remaining_credits of this PhoneSmsPrepaidCreditDto.


        :param remaining_credits: The remaining_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and remaining_credits is None:  # noqa: E501
            raise ValueError("Invalid value for `remaining_credits`, must not be `None`")  # noqa: E501

        self._remaining_credits = remaining_credits

    @property
    def initial_credits(self):
        """Gets the initial_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The initial_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: int
        """
        return self._initial_credits

    @initial_credits.setter
    def initial_credits(self, initial_credits):
        """Sets the initial_credits of this PhoneSmsPrepaidCreditDto.


        :param initial_credits: The initial_credits of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and initial_credits is None:  # noqa: E501
            raise ValueError("Invalid value for `initial_credits`, must not be `None`")  # noqa: E501

        self._initial_credits = initial_credits

    @property
    def sent_multiplier(self):
        """Gets the sent_multiplier of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The sent_multiplier of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: int
        """
        return self._sent_multiplier

    @sent_multiplier.setter
    def sent_multiplier(self, sent_multiplier):
        """Sets the sent_multiplier of this PhoneSmsPrepaidCreditDto.


        :param sent_multiplier: The sent_multiplier of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and sent_multiplier is None:  # noqa: E501
            raise ValueError("Invalid value for `sent_multiplier`, must not be `None`")  # noqa: E501

        self._sent_multiplier = sent_multiplier

    @property
    def created_at(self):
        """Gets the created_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The created_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneSmsPrepaidCreditDto.


        :param created_at: The created_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501


        :return: The updated_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhoneSmsPrepaidCreditDto.


        :param updated_at: The updated_at of this PhoneSmsPrepaidCreditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneSmsPrepaidCreditDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneSmsPrepaidCreditDto):
            return True

        return self.to_dict() != other.to_dict()
