# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CancelDevicePreviewRunResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'run': 'DevicePreviewRunDto',
        'remote_cancel_attempted': 'bool',
        'remote_cancel_accepted': 'bool',
        'warning': 'str'
    }

    attribute_map = {
        'run': 'run',
        'remote_cancel_attempted': 'remoteCancelAttempted',
        'remote_cancel_accepted': 'remoteCancelAccepted',
        'warning': 'warning'
    }

    def __init__(self, run=None, remote_cancel_attempted=None, remote_cancel_accepted=None, warning=None, local_vars_configuration=None):  # noqa: E501
        """CancelDevicePreviewRunResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._run = None
        self._remote_cancel_attempted = None
        self._remote_cancel_accepted = None
        self._warning = None
        self.discriminator = None

        self.run = run
        self.remote_cancel_attempted = remote_cancel_attempted
        self.remote_cancel_accepted = remote_cancel_accepted
        if warning is not None:
            self.warning = warning

    @property
    def run(self):
        """Gets the run of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The run of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: DevicePreviewRunDto
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this CancelDevicePreviewRunResult.


        :param run: The run of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: DevicePreviewRunDto
        """
        if self.local_vars_configuration.client_side_validation and run is None:  # noqa: E501
            raise ValueError("Invalid value for `run`, must not be `None`")  # noqa: E501

        self._run = run

    @property
    def remote_cancel_attempted(self):
        """Gets the remote_cancel_attempted of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The remote_cancel_attempted of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: bool
        """
        return self._remote_cancel_attempted

    @remote_cancel_attempted.setter
    def remote_cancel_attempted(self, remote_cancel_attempted):
        """Sets the remote_cancel_attempted of this CancelDevicePreviewRunResult.


        :param remote_cancel_attempted: The remote_cancel_attempted of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and remote_cancel_attempted is None:  # noqa: E501
            raise ValueError("Invalid value for `remote_cancel_attempted`, must not be `None`")  # noqa: E501

        self._remote_cancel_attempted = remote_cancel_attempted

    @property
    def remote_cancel_accepted(self):
        """Gets the remote_cancel_accepted of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The remote_cancel_accepted of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: bool
        """
        return self._remote_cancel_accepted

    @remote_cancel_accepted.setter
    def remote_cancel_accepted(self, remote_cancel_accepted):
        """Sets the remote_cancel_accepted of this CancelDevicePreviewRunResult.


        :param remote_cancel_accepted: The remote_cancel_accepted of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and remote_cancel_accepted is None:  # noqa: E501
            raise ValueError("Invalid value for `remote_cancel_accepted`, must not be `None`")  # noqa: E501

        self._remote_cancel_accepted = remote_cancel_accepted

    @property
    def warning(self):
        """Gets the warning of this CancelDevicePreviewRunResult.  # noqa: E501


        :return: The warning of this CancelDevicePreviewRunResult.  # noqa: E501
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this CancelDevicePreviewRunResult.


        :param warning: The warning of this CancelDevicePreviewRunResult.  # noqa: E501
        :type: str
        """

        self._warning = warning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CancelDevicePreviewRunResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CancelDevicePreviewRunResult):
            return True

        return self.to_dict() != other.to_dict()
