# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mailslurp_client
from mailslurp_client.models.domain_monitor_summary_dto import DomainMonitorSummaryDto  # noqa: E501
from mailslurp_client.rest import ApiException

class TestDomainMonitorSummaryDto(unittest.TestCase):
    """DomainMonitorSummaryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DomainMonitorSummaryDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mailslurp_client.models.domain_monitor_summary_dto.DomainMonitorSummaryDto()  # noqa: E501
        if include_optional :
            return DomainMonitorSummaryDto(
                monitor = mailslurp_client.models.domain_monitor_dto.DomainMonitorDto(
                    id = '0', 
                    user_id = '0', 
                    domain = '0', 
                    name = '0', 
                    interval_seconds = 56, 
                    enabled = True, 
                    scheduling_enabled = True, 
                    last_status = 'HEALTHY', 
                    health_score = 56, 
                    last_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    next_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                latest_run = mailslurp_client.models.domain_monitor_run_dto.DomainMonitorRunDto(
                    id = '0', 
                    monitor_id = '0', 
                    user_id = '0', 
                    domain = '0', 
                    status = 'HEALTHY', 
                    trigger_source = 'API', 
                    health_score = 56, 
                    total_checks = 56, 
                    passing_checks = 56, 
                    failing_checks = 56, 
                    spf_ok = True, 
                    dmarc_ok = True, 
                    dmarc_enforced = True, 
                    mx_ok = True, 
                    insights = [
                        '0'
                        ], 
                    error_message = '0', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                insights = mailslurp_client.models.domain_monitor_insights_dto.DomainMonitorInsightsDto(
                    monitor_id = '0', 
                    since = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    total_runs = 56, 
                    healthy_runs = 56, 
                    degraded_runs = 56, 
                    critical_runs = 56, 
                    failed_runs = 56, 
                    success_rate = 1.337, 
                    average_health_score = 1.337, 
                    current_healthy_streak = 56, 
                    best_healthy_streak = 56, 
                    good_performance_signals = [
                        '0'
                        ], 
                    attention_signals = [
                        '0'
                        ], 
                    top_findings = [
                        '0'
                        ], 
                    latest_run = mailslurp_client.models.domain_monitor_run_dto.DomainMonitorRunDto(
                        id = '0', 
                        monitor_id = '0', 
                        user_id = '0', 
                        domain = '0', 
                        status = 'HEALTHY', 
                        trigger_source = 'API', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        spf_ok = True, 
                        dmarc_ok = True, 
                        dmarc_enforced = True, 
                        mx_ok = True, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                auth_stack = mailslurp_client.models.check_email_auth_stack_results.CheckEmailAuthStackResults(
                    domain = '0', 
                    status = 'HEALTHY', 
                    health_score = 56, 
                    total_checks = 56, 
                    passing_checks = 56, 
                    failing_checks = 56, 
                    spf = mailslurp_client.models.lookup_spf_domain_results.LookupSpfDomainResults(
                        valid = True, 
                        host = '0', 
                        record = '0', 
                        flattened_record = '0', 
                        lookup_count = 56, 
                        mechanisms = [
                            mailslurp_client.models.spf_mechanism_result.SpfMechanismResult(
                                kind = '0', 
                                value = '0', 
                                qualifier = '0', )
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    dmarc = mailslurp_client.models.lookup_dmarc_domain_results.LookupDmarcDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    dkim = mailslurp_client.models.lookup_dkim_domain_results.LookupDkimDomainResults(
                        valid = True, 
                        queried_name = '0', 
                        selector = '0', 
                        record = '0', 
                        algorithm = '0', 
                        key_length = 56, 
                        checked_names = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    bimi = mailslurp_client.models.lookup_bimi_domain_results.LookupBimiDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mx = mailslurp_client.models.lookup_mx_records_results.LookupMxRecordsResults(
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mta_sts = mailslurp_client.models.lookup_mta_sts_domain_results.LookupMtaStsDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        well_known_query = '0', 
                        well_known_present = True, 
                        well_known_value = '0', 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    tls_reporting = mailslurp_client.models.lookup_tls_reporting_domain_results.LookupTlsReportingDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    insights = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], )
            )
        else :
            return DomainMonitorSummaryDto(
                monitor = mailslurp_client.models.domain_monitor_dto.DomainMonitorDto(
                    id = '0', 
                    user_id = '0', 
                    domain = '0', 
                    name = '0', 
                    interval_seconds = 56, 
                    enabled = True, 
                    scheduling_enabled = True, 
                    last_status = 'HEALTHY', 
                    health_score = 56, 
                    last_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    next_run_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                insights = mailslurp_client.models.domain_monitor_insights_dto.DomainMonitorInsightsDto(
                    monitor_id = '0', 
                    since = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    total_runs = 56, 
                    healthy_runs = 56, 
                    degraded_runs = 56, 
                    critical_runs = 56, 
                    failed_runs = 56, 
                    success_rate = 1.337, 
                    average_health_score = 1.337, 
                    current_healthy_streak = 56, 
                    best_healthy_streak = 56, 
                    good_performance_signals = [
                        '0'
                        ], 
                    attention_signals = [
                        '0'
                        ], 
                    top_findings = [
                        '0'
                        ], 
                    latest_run = mailslurp_client.models.domain_monitor_run_dto.DomainMonitorRunDto(
                        id = '0', 
                        monitor_id = '0', 
                        user_id = '0', 
                        domain = '0', 
                        status = 'HEALTHY', 
                        trigger_source = 'API', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        spf_ok = True, 
                        dmarc_ok = True, 
                        dmarc_enforced = True, 
                        mx_ok = True, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                auth_stack = mailslurp_client.models.check_email_auth_stack_results.CheckEmailAuthStackResults(
                    domain = '0', 
                    status = 'HEALTHY', 
                    health_score = 56, 
                    total_checks = 56, 
                    passing_checks = 56, 
                    failing_checks = 56, 
                    spf = mailslurp_client.models.lookup_spf_domain_results.LookupSpfDomainResults(
                        valid = True, 
                        host = '0', 
                        record = '0', 
                        flattened_record = '0', 
                        lookup_count = 56, 
                        mechanisms = [
                            mailslurp_client.models.spf_mechanism_result.SpfMechanismResult(
                                kind = '0', 
                                value = '0', 
                                qualifier = '0', )
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    dmarc = mailslurp_client.models.lookup_dmarc_domain_results.LookupDmarcDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    dkim = mailslurp_client.models.lookup_dkim_domain_results.LookupDkimDomainResults(
                        valid = True, 
                        queried_name = '0', 
                        selector = '0', 
                        record = '0', 
                        algorithm = '0', 
                        key_length = 56, 
                        checked_names = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], 
                        errors = [
                            '0'
                            ], ), 
                    bimi = mailslurp_client.models.lookup_bimi_domain_results.LookupBimiDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mx = mailslurp_client.models.lookup_mx_records_results.LookupMxRecordsResults(
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    mta_sts = mailslurp_client.models.lookup_mta_sts_domain_results.LookupMtaStsDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        well_known_query = '0', 
                        well_known_present = True, 
                        well_known_value = '0', 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    tls_reporting = mailslurp_client.models.lookup_tls_reporting_domain_results.LookupTlsReportingDomainResults(
                        valid = True, 
                        query = mailslurp_client.models.dns_lookup_options.DNSLookupOptions(
                            hostname = '0', 
                            record_types = [
                                'A'
                                ], 
                            omit_final_dns_dot = True, ), 
                        records = [
                            mailslurp_client.models.dns_lookup_result.DNSLookupResult(
                                record_type = 'A', 
                                ttl = 56, 
                                record_entries = [
                                    '0'
                                    ], 
                                name = '0', )
                            ], 
                        errors = [
                            '0'
                            ], 
                        warnings = [
                            '0'
                            ], ), 
                    insights = [
                        '0'
                        ], 
                    warnings = [
                        '0'
                        ], 
                    errors = [
                        '0'
                        ], ),
        )

    def testDomainMonitorSummaryDto(self):
        """Test DomainMonitorSummaryDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
