# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.user_controller_api import UserControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestUserControllerApi(unittest.TestCase):
    """UserControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.user_controller_api.UserControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_or_update_inbox_retention_policy_for_account(self):
        """Test case for create_or_update_inbox_retention_policy_for_account

        """
        pass

    def test_delete_inbox_retention_policy_for_account(self):
        """Test case for delete_inbox_retention_policy_for_account

        """
        pass

    def test_get_entity_automations(self):
        """Test case for get_entity_automations

        """
        pass

    def test_get_entity_events(self):
        """Test case for get_entity_events

        """
        pass

    def test_get_entity_favorites(self):
        """Test case for get_entity_favorites

        """
        pass

    def test_get_inbox_retention_policy_for_account(self):
        """Test case for get_inbox_retention_policy_for_account

        """
        pass

    def test_get_json_property_as_string(self):
        """Test case for get_json_property_as_string

        """
        pass

    def test_get_user_info(self):
        """Test case for get_user_info

        """
        pass


if __name__ == '__main__':
    unittest.main()
