# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceTestsOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'check_random_local_part': 'bool',
        'check_free_provider': 'bool',
        'check_https_website': 'bool',
        'check_dns': 'bool',
        'check_domain_age_hint': 'bool'
    }

    attribute_map = {
        'check_random_local_part': 'checkRandomLocalPart',
        'check_free_provider': 'checkFreeProvider',
        'check_https_website': 'checkHttpsWebsite',
        'check_dns': 'checkDns',
        'check_domain_age_hint': 'checkDomainAgeHint'
    }

    def __init__(self, check_random_local_part=None, check_free_provider=None, check_https_website=None, check_dns=None, check_domain_age_hint=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceTestsOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._check_random_local_part = None
        self._check_free_provider = None
        self._check_https_website = None
        self._check_dns = None
        self._check_domain_age_hint = None
        self.discriminator = None

        self.check_random_local_part = check_random_local_part
        self.check_free_provider = check_free_provider
        self.check_https_website = check_https_website
        self.check_dns = check_dns
        self.check_domain_age_hint = check_domain_age_hint

    @property
    def check_random_local_part(self):
        """Gets the check_random_local_part of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check local-part randomness for email inputs.  # noqa: E501

        :return: The check_random_local_part of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_random_local_part

    @check_random_local_part.setter
    def check_random_local_part(self, check_random_local_part):
        """Sets the check_random_local_part of this EmailIntelligenceTestsOptions.

        Check local-part randomness for email inputs.  # noqa: E501

        :param check_random_local_part: The check_random_local_part of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_random_local_part = check_random_local_part

    @property
    def check_free_provider(self):
        """Gets the check_free_provider of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check if domain is a known free email provider.  # noqa: E501

        :return: The check_free_provider of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_free_provider

    @check_free_provider.setter
    def check_free_provider(self, check_free_provider):
        """Sets the check_free_provider of this EmailIntelligenceTestsOptions.

        Check if domain is a known free email provider.  # noqa: E501

        :param check_free_provider: The check_free_provider of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_free_provider = check_free_provider

    @property
    def check_https_website(self):
        """Gets the check_https_website of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check if the domain has a reachable HTTPS website.  # noqa: E501

        :return: The check_https_website of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_https_website

    @check_https_website.setter
    def check_https_website(self, check_https_website):
        """Sets the check_https_website of this EmailIntelligenceTestsOptions.

        Check if the domain has a reachable HTTPS website.  # noqa: E501

        :param check_https_website: The check_https_website of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_https_website = check_https_website

    @property
    def check_dns(self):
        """Gets the check_dns of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check DNS records (A, MX, SOA) for the domain.  # noqa: E501

        :return: The check_dns of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_dns

    @check_dns.setter
    def check_dns(self, check_dns):
        """Sets the check_dns of this EmailIntelligenceTestsOptions.

        Check DNS records (A, MX, SOA) for the domain.  # noqa: E501

        :param check_dns: The check_dns of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_dns = check_dns

    @property
    def check_domain_age_hint(self):
        """Gets the check_domain_age_hint of this EmailIntelligenceTestsOptions.  # noqa: E501

        Derive a domain age hint from DNS SOA serial when possible.  # noqa: E501

        :return: The check_domain_age_hint of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_domain_age_hint

    @check_domain_age_hint.setter
    def check_domain_age_hint(self, check_domain_age_hint):
        """Sets the check_domain_age_hint of this EmailIntelligenceTestsOptions.

        Derive a domain age hint from DNS SOA serial when possible.  # noqa: E501

        :param check_domain_age_hint: The check_domain_age_hint of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_domain_age_hint = check_domain_age_hint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceTestsOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceTestsOptions):
            return True

        return self.to_dict() != other.to_dict()
