# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.inbox_replier_controller_api import InboxReplierControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestInboxReplierControllerApi(unittest.TestCase):
    """InboxReplierControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.inbox_replier_controller_api.InboxReplierControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_new_inbox_replier(self):
        """Test case for create_new_inbox_replier

        Create an inbox replier  # noqa: E501
        """
        pass

    def test_delete_inbox_replier(self):
        """Test case for delete_inbox_replier

        Delete an inbox replier  # noqa: E501
        """
        pass

    def test_delete_inbox_repliers(self):
        """Test case for delete_inbox_repliers

        Delete inbox repliers  # noqa: E501
        """
        pass

    def test_get_all_inbox_replier_events(self):
        """Test case for get_all_inbox_replier_events

        Get inbox replier event list  # noqa: E501
        """
        pass

    def test_get_inbox_replier(self):
        """Test case for get_inbox_replier

        Get an inbox replier  # noqa: E501
        """
        pass

    def test_get_inbox_replier_events(self):
        """Test case for get_inbox_replier_events

        Get an inbox replier event list  # noqa: E501
        """
        pass

    def test_get_inbox_repliers(self):
        """Test case for get_inbox_repliers

        List inbox repliers  # noqa: E501
        """
        pass

    def test_update_inbox_replier(self):
        """Test case for update_inbox_replier

        Update an inbox replier  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
