# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DevicePreviewTargetDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'run_id': 'str',
        'provider': 'str',
        'client_profile': 'str',
        'device_type': 'str',
        'browser_family': 'str',
        'platform': 'str',
        'color_scheme': 'str',
        'status': 'str',
        'failure_code': 'str',
        'primary_screenshot_id': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'run_id': 'runId',
        'provider': 'provider',
        'client_profile': 'clientProfile',
        'device_type': 'deviceType',
        'browser_family': 'browserFamily',
        'platform': 'platform',
        'color_scheme': 'colorScheme',
        'status': 'status',
        'failure_code': 'failureCode',
        'primary_screenshot_id': 'primaryScreenshotId',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, run_id=None, provider=None, client_profile=None, device_type=None, browser_family=None, platform=None, color_scheme=None, status=None, failure_code=None, primary_screenshot_id=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DevicePreviewTargetDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._run_id = None
        self._provider = None
        self._client_profile = None
        self._device_type = None
        self._browser_family = None
        self._platform = None
        self._color_scheme = None
        self._status = None
        self._failure_code = None
        self._primary_screenshot_id = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.run_id = run_id
        if provider is not None:
            self.provider = provider
        if client_profile is not None:
            self.client_profile = client_profile
        if device_type is not None:
            self.device_type = device_type
        if browser_family is not None:
            self.browser_family = browser_family
        if platform is not None:
            self.platform = platform
        if color_scheme is not None:
            self.color_scheme = color_scheme
        if status is not None:
            self.status = status
        if failure_code is not None:
            self.failure_code = failure_code
        if primary_screenshot_id is not None:
            self.primary_screenshot_id = primary_screenshot_id
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DevicePreviewTargetDto.  # noqa: E501


        :return: The id of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DevicePreviewTargetDto.


        :param id: The id of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def run_id(self):
        """Gets the run_id of this DevicePreviewTargetDto.  # noqa: E501


        :return: The run_id of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this DevicePreviewTargetDto.


        :param run_id: The run_id of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and run_id is None:  # noqa: E501
            raise ValueError("Invalid value for `run_id`, must not be `None`")  # noqa: E501

        self._run_id = run_id

    @property
    def provider(self):
        """Gets the provider of this DevicePreviewTargetDto.  # noqa: E501


        :return: The provider of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this DevicePreviewTargetDto.


        :param provider: The provider of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._provider = provider

    @property
    def client_profile(self):
        """Gets the client_profile of this DevicePreviewTargetDto.  # noqa: E501


        :return: The client_profile of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._client_profile

    @client_profile.setter
    def client_profile(self, client_profile):
        """Sets the client_profile of this DevicePreviewTargetDto.


        :param client_profile: The client_profile of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._client_profile = client_profile

    @property
    def device_type(self):
        """Gets the device_type of this DevicePreviewTargetDto.  # noqa: E501


        :return: The device_type of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this DevicePreviewTargetDto.


        :param device_type: The device_type of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def browser_family(self):
        """Gets the browser_family of this DevicePreviewTargetDto.  # noqa: E501


        :return: The browser_family of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._browser_family

    @browser_family.setter
    def browser_family(self, browser_family):
        """Sets the browser_family of this DevicePreviewTargetDto.


        :param browser_family: The browser_family of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._browser_family = browser_family

    @property
    def platform(self):
        """Gets the platform of this DevicePreviewTargetDto.  # noqa: E501


        :return: The platform of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this DevicePreviewTargetDto.


        :param platform: The platform of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._platform = platform

    @property
    def color_scheme(self):
        """Gets the color_scheme of this DevicePreviewTargetDto.  # noqa: E501


        :return: The color_scheme of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._color_scheme

    @color_scheme.setter
    def color_scheme(self, color_scheme):
        """Sets the color_scheme of this DevicePreviewTargetDto.


        :param color_scheme: The color_scheme of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._color_scheme = color_scheme

    @property
    def status(self):
        """Gets the status of this DevicePreviewTargetDto.  # noqa: E501


        :return: The status of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DevicePreviewTargetDto.


        :param status: The status of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["WAITING", "READY_TO_CAPTURE", "CAPTURING", "READY", "FAILED", "NEEDS_INTERVENTION"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def failure_code(self):
        """Gets the failure_code of this DevicePreviewTargetDto.  # noqa: E501


        :return: The failure_code of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._failure_code

    @failure_code.setter
    def failure_code(self, failure_code):
        """Sets the failure_code of this DevicePreviewTargetDto.


        :param failure_code: The failure_code of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._failure_code = failure_code

    @property
    def primary_screenshot_id(self):
        """Gets the primary_screenshot_id of this DevicePreviewTargetDto.  # noqa: E501


        :return: The primary_screenshot_id of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._primary_screenshot_id

    @primary_screenshot_id.setter
    def primary_screenshot_id(self, primary_screenshot_id):
        """Sets the primary_screenshot_id of this DevicePreviewTargetDto.


        :param primary_screenshot_id: The primary_screenshot_id of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._primary_screenshot_id = primary_screenshot_id

    @property
    def created_at(self):
        """Gets the created_at of this DevicePreviewTargetDto.  # noqa: E501


        :return: The created_at of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DevicePreviewTargetDto.


        :param created_at: The created_at of this DevicePreviewTargetDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DevicePreviewTargetDto.  # noqa: E501


        :return: The updated_at of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DevicePreviewTargetDto.


        :param updated_at: The updated_at of this DevicePreviewTargetDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePreviewTargetDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePreviewTargetDto):
            return True

        return self.to_dict() != other.to_dict()
