# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.api_audit_log_controller_api import ApiAuditLogControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestApiAuditLogControllerApi(unittest.TestCase):
    """ApiAuditLogControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.api_audit_log_controller_api.ApiAuditLogControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_audit_log_by_event_id(self):
        """Test case for get_audit_log_by_event_id

        """
        pass

    def test_get_audit_logs(self):
        """Test case for get_audit_logs

        """
        pass

    def test_search_audit_logs(self):
        """Test case for search_audit_logs

        """
        pass


if __name__ == '__main__':
    unittest.main()
