# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TenantReputationFindingDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_region': 'str',
        'tenant_name': 'str',
        'tenant_arn': 'str',
        'type': 'str',
        'impact': 'str',
        'status': 'str',
        'description': 'str',
        'created_timestamp': 'datetime',
        'last_updated_timestamp': 'datetime'
    }

    attribute_map = {
        'account_region': 'accountRegion',
        'tenant_name': 'tenantName',
        'tenant_arn': 'tenantArn',
        'type': 'type',
        'impact': 'impact',
        'status': 'status',
        'description': 'description',
        'created_timestamp': 'createdTimestamp',
        'last_updated_timestamp': 'lastUpdatedTimestamp'
    }

    def __init__(self, account_region=None, tenant_name=None, tenant_arn=None, type=None, impact=None, status=None, description=None, created_timestamp=None, last_updated_timestamp=None, local_vars_configuration=None):  # noqa: E501
        """TenantReputationFindingDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_region = None
        self._tenant_name = None
        self._tenant_arn = None
        self._type = None
        self._impact = None
        self._status = None
        self._description = None
        self._created_timestamp = None
        self._last_updated_timestamp = None
        self.discriminator = None

        self.account_region = account_region
        self.tenant_name = tenant_name
        if tenant_arn is not None:
            self.tenant_arn = tenant_arn
        if type is not None:
            self.type = type
        if impact is not None:
            self.impact = impact
        if status is not None:
            self.status = status
        if description is not None:
            self.description = description
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if last_updated_timestamp is not None:
            self.last_updated_timestamp = last_updated_timestamp

    @property
    def account_region(self):
        """Gets the account_region of this TenantReputationFindingDto.  # noqa: E501


        :return: The account_region of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._account_region

    @account_region.setter
    def account_region(self, account_region):
        """Sets the account_region of this TenantReputationFindingDto.


        :param account_region: The account_region of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_region is None:  # noqa: E501
            raise ValueError("Invalid value for `account_region`, must not be `None`")  # noqa: E501
        allowed_values = ["US_WEST_2_ACCOUNT_STAGING", "US_EAST_1_ACCOUNT_STAGING", "EU_WEST_1_ACCOUNT_STAGING", "US_WEST_2_ACCOUNT_SES_1", "EU_WEST_1_ACCOUNT_SES_1", "US_WEST_2_ACCOUNT_SES_2", "EU_WEST_1_ACCOUNT_SES_2", "US_WEST_2_ACCOUNT_BYTEWISE", "EU_WEST_1_ACCOUNT_BYTEWISE", "US_WEST_2", "EU_WEST_1", "US_EAST_1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account_region not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account_region` ({0}), must be one of {1}"  # noqa: E501
                .format(account_region, allowed_values)
            )

        self._account_region = account_region

    @property
    def tenant_name(self):
        """Gets the tenant_name of this TenantReputationFindingDto.  # noqa: E501


        :return: The tenant_name of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this TenantReputationFindingDto.


        :param tenant_name: The tenant_name of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tenant_name is None:  # noqa: E501
            raise ValueError("Invalid value for `tenant_name`, must not be `None`")  # noqa: E501

        self._tenant_name = tenant_name

    @property
    def tenant_arn(self):
        """Gets the tenant_arn of this TenantReputationFindingDto.  # noqa: E501


        :return: The tenant_arn of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_arn

    @tenant_arn.setter
    def tenant_arn(self, tenant_arn):
        """Sets the tenant_arn of this TenantReputationFindingDto.


        :param tenant_arn: The tenant_arn of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._tenant_arn = tenant_arn

    @property
    def type(self):
        """Gets the type of this TenantReputationFindingDto.  # noqa: E501


        :return: The type of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TenantReputationFindingDto.


        :param type: The type of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def impact(self):
        """Gets the impact of this TenantReputationFindingDto.  # noqa: E501


        :return: The impact of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """Sets the impact of this TenantReputationFindingDto.


        :param impact: The impact of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._impact = impact

    @property
    def status(self):
        """Gets the status of this TenantReputationFindingDto.  # noqa: E501


        :return: The status of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TenantReputationFindingDto.


        :param status: The status of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def description(self):
        """Gets the description of this TenantReputationFindingDto.  # noqa: E501


        :return: The description of this TenantReputationFindingDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TenantReputationFindingDto.


        :param description: The description of this TenantReputationFindingDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this TenantReputationFindingDto.  # noqa: E501


        :return: The created_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this TenantReputationFindingDto.


        :param created_timestamp: The created_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :type: datetime
        """

        self._created_timestamp = created_timestamp

    @property
    def last_updated_timestamp(self):
        """Gets the last_updated_timestamp of this TenantReputationFindingDto.  # noqa: E501


        :return: The last_updated_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_timestamp

    @last_updated_timestamp.setter
    def last_updated_timestamp(self, last_updated_timestamp):
        """Sets the last_updated_timestamp of this TenantReputationFindingDto.


        :param last_updated_timestamp: The last_updated_timestamp of this TenantReputationFindingDto.  # noqa: E501
        :type: datetime
        """

        self._last_updated_timestamp = last_updated_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TenantReputationFindingDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TenantReputationFindingDto):
            return True

        return self.to_dict() != other.to_dict()
