# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorAlertSinkDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'monitor_id': 'str',
        'user_id': 'str',
        'type': 'str',
        'target': 'str',
        'severity_threshold': 'str',
        'enabled': 'bool',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'monitor_id': 'monitorId',
        'user_id': 'userId',
        'type': 'type',
        'target': 'target',
        'severity_threshold': 'severityThreshold',
        'enabled': 'enabled',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, monitor_id=None, user_id=None, type=None, target=None, severity_threshold=None, enabled=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorAlertSinkDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._monitor_id = None
        self._user_id = None
        self._type = None
        self._target = None
        self._severity_threshold = None
        self._enabled = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.monitor_id = monitor_id
        self.user_id = user_id
        self.type = type
        self.target = target
        self.severity_threshold = severity_threshold
        self.enabled = enabled
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DomainMonitorAlertSinkDto.


        :param id: The id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def monitor_id(self):
        """Gets the monitor_id of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The monitor_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._monitor_id

    @monitor_id.setter
    def monitor_id(self, monitor_id):
        """Sets the monitor_id of this DomainMonitorAlertSinkDto.


        :param monitor_id: The monitor_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and monitor_id is None:  # noqa: E501
            raise ValueError("Invalid value for `monitor_id`, must not be `None`")  # noqa: E501

        self._monitor_id = monitor_id

    @property
    def user_id(self):
        """Gets the user_id of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The user_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DomainMonitorAlertSinkDto.


        :param user_id: The user_id of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def type(self):
        """Gets the type of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The type of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DomainMonitorAlertSinkDto.


        :param type: The type of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL", "WEBHOOK", "SLACK", "TEAMS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def target(self):
        """Gets the target of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The target of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this DomainMonitorAlertSinkDto.


        :param target: The target of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target is None:  # noqa: E501
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    @property
    def severity_threshold(self):
        """Gets the severity_threshold of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The severity_threshold of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: str
        """
        return self._severity_threshold

    @severity_threshold.setter
    def severity_threshold(self, severity_threshold):
        """Sets the severity_threshold of this DomainMonitorAlertSinkDto.


        :param severity_threshold: The severity_threshold of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and severity_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `severity_threshold`, must not be `None`")  # noqa: E501
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and severity_threshold not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `severity_threshold` ({0}), must be one of {1}"  # noqa: E501
                .format(severity_threshold, allowed_values)
            )

        self._severity_threshold = severity_threshold

    @property
    def enabled(self):
        """Gets the enabled of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The enabled of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DomainMonitorAlertSinkDto.


        :param enabled: The enabled of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def created_at(self):
        """Gets the created_at of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The created_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DomainMonitorAlertSinkDto.


        :param created_at: The created_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DomainMonitorAlertSinkDto.  # noqa: E501


        :return: The updated_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DomainMonitorAlertSinkDto.


        :param updated_at: The updated_at of this DomainMonitorAlertSinkDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorAlertSinkDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorAlertSinkDto):
            return True

        return self.to_dict() != other.to_dict()
