# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.deliverability_test_controller_api import DeliverabilityTestControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestDeliverabilityTestControllerApi(unittest.TestCase):
    """DeliverabilityTestControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.deliverability_test_controller_api.DeliverabilityTestControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_deliverability_simulation_job(self):
        """Test case for cancel_deliverability_simulation_job

        Cancel deliverability simulation job  # noqa: E501
        """
        pass

    def test_create_deliverability_simulation_job(self):
        """Test case for create_deliverability_simulation_job

        Create deliverability simulation job  # noqa: E501
        """
        pass

    def test_create_deliverability_test(self):
        """Test case for create_deliverability_test

        Create deliverability/load test  # noqa: E501
        """
        pass

    def test_delete_deliverability_test(self):
        """Test case for delete_deliverability_test

        Delete deliverability/load test  # noqa: E501
        """
        pass

    def test_duplicate_deliverability_test(self):
        """Test case for duplicate_deliverability_test

        Duplicate deliverability/load test  # noqa: E501
        """
        pass

    def test_export_deliverability_test_report(self):
        """Test case for export_deliverability_test_report

        Export deliverability/load test report as PDF  # noqa: E501
        """
        pass

    def test_export_deliverability_test_results(self):
        """Test case for export_deliverability_test_results

        Export deliverability/load test entity results as CSV  # noqa: E501
        """
        pass

    def test_get_deliverability_analytics_series(self):
        """Test case for get_deliverability_analytics_series

        Get deliverability analytics time series  # noqa: E501
        """
        pass

    def test_get_deliverability_failure_hotspots(self):
        """Test case for get_deliverability_failure_hotspots

        Get deliverability failure hotspots  # noqa: E501
        """
        pass

    def test_get_deliverability_simulation_job(self):
        """Test case for get_deliverability_simulation_job

        Get deliverability simulation job  # noqa: E501
        """
        pass

    def test_get_deliverability_simulation_job_events(self):
        """Test case for get_deliverability_simulation_job_events

        Get deliverability simulation job events  # noqa: E501
        """
        pass

    def test_get_deliverability_test(self):
        """Test case for get_deliverability_test

        Get deliverability/load test  # noqa: E501
        """
        pass

    def test_get_deliverability_test_results(self):
        """Test case for get_deliverability_test_results

        Get deliverability/load test entity results  # noqa: E501
        """
        pass

    def test_get_deliverability_tests(self):
        """Test case for get_deliverability_tests

        List deliverability/load tests  # noqa: E501
        """
        pass

    def test_get_latest_deliverability_simulation_job(self):
        """Test case for get_latest_deliverability_simulation_job

        Get latest deliverability simulation job  # noqa: E501
        """
        pass

    def test_pause_deliverability_simulation_job(self):
        """Test case for pause_deliverability_simulation_job

        Pause deliverability simulation job  # noqa: E501
        """
        pass

    def test_pause_deliverability_test(self):
        """Test case for pause_deliverability_test

        Pause deliverability/load test  # noqa: E501
        """
        pass

    def test_poll_deliverability_test_status(self):
        """Test case for poll_deliverability_test_status

        Poll deliverability/load test status  # noqa: E501
        """
        pass

    def test_resume_deliverability_simulation_job(self):
        """Test case for resume_deliverability_simulation_job

        Resume deliverability simulation job  # noqa: E501
        """
        pass

    def test_start_deliverability_test(self):
        """Test case for start_deliverability_test

        Start or resume deliverability/load test  # noqa: E501
        """
        pass

    def test_stop_deliverability_test(self):
        """Test case for stop_deliverability_test

        Stop deliverability/load test  # noqa: E501
        """
        pass

    def test_update_deliverability_test(self):
        """Test case for update_deliverability_test

        Update deliverability/load test  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
