# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.email_audit_controller_api import EmailAuditControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestEmailAuditControllerApi(unittest.TestCase):
    """EmailAuditControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.email_audit_controller_api.EmailAuditControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_compare_email_audits(self):
        """Test case for compare_email_audits

        Compare two email audits  # noqa: E501
        """
        pass

    def test_create_email_audit(self):
        """Test case for create_email_audit

        Create email audit  # noqa: E501
        """
        pass

    def test_delete_email_audit(self):
        """Test case for delete_email_audit

        Delete email audit  # noqa: E501
        """
        pass

    def test_get_email_audit(self):
        """Test case for get_email_audit

        Get email audit  # noqa: E501
        """
        pass

    def test_get_email_audits(self):
        """Test case for get_email_audits

        List email audits  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
