# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateConnectorOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'email_address': 'str',
        'enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'email_address': 'emailAddress',
        'enabled': 'enabled'
    }

    def __init__(self, name=None, email_address=None, enabled=None, local_vars_configuration=None):  # noqa: E501
        """CreateConnectorOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._email_address = None
        self._enabled = None
        self.discriminator = None

        self.name = name
        self.email_address = email_address
        self.enabled = enabled

    @property
    def name(self):
        """Gets the name of this CreateConnectorOptions.  # noqa: E501

        Name of connector  # noqa: E501

        :return: The name of this CreateConnectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateConnectorOptions.

        Name of connector  # noqa: E501

        :param name: The name of this CreateConnectorOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def email_address(self):
        """Gets the email_address of this CreateConnectorOptions.  # noqa: E501

        Email address of external inbox  # noqa: E501

        :return: The email_address of this CreateConnectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this CreateConnectorOptions.

        Email address of external inbox  # noqa: E501

        :param email_address: The email_address of this CreateConnectorOptions.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def enabled(self):
        """Gets the enabled of this CreateConnectorOptions.  # noqa: E501

        Is connector enabled  # noqa: E501

        :return: The enabled of this CreateConnectorOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateConnectorOptions.

        Is connector enabled  # noqa: E501

        :param enabled: The enabled of this CreateConnectorOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConnectorOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateConnectorOptions):
            return True

        return self.to_dict() != other.to_dict()
