# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailAuditDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'email_id': 'str',
        'from_address': 'str',
        'recipient': 'str',
        'subject': 'str',
        'analysis': 'EmailAuditAnalysisResult',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'email_id': 'emailId',
        'from_address': 'fromAddress',
        'recipient': 'recipient',
        'subject': 'subject',
        'analysis': 'analysis',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, email_id=None, from_address=None, recipient=None, subject=None, analysis=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """EmailAuditDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._email_id = None
        self._from_address = None
        self._recipient = None
        self._subject = None
        self._analysis = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.email_id = email_id
        self.from_address = from_address
        self.recipient = recipient
        self.subject = subject
        self.analysis = analysis
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this EmailAuditDto.  # noqa: E501


        :return: The id of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmailAuditDto.


        :param id: The id of this EmailAuditDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this EmailAuditDto.  # noqa: E501


        :return: The user_id of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this EmailAuditDto.


        :param user_id: The user_id of this EmailAuditDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def email_id(self):
        """Gets the email_id of this EmailAuditDto.  # noqa: E501


        :return: The email_id of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this EmailAuditDto.


        :param email_id: The email_id of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def from_address(self):
        """Gets the from_address of this EmailAuditDto.  # noqa: E501


        :return: The from_address of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this EmailAuditDto.


        :param from_address: The from_address of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._from_address = from_address

    @property
    def recipient(self):
        """Gets the recipient of this EmailAuditDto.  # noqa: E501


        :return: The recipient of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this EmailAuditDto.


        :param recipient: The recipient of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def subject(self):
        """Gets the subject of this EmailAuditDto.  # noqa: E501


        :return: The subject of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailAuditDto.


        :param subject: The subject of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def analysis(self):
        """Gets the analysis of this EmailAuditDto.  # noqa: E501


        :return: The analysis of this EmailAuditDto.  # noqa: E501
        :rtype: EmailAuditAnalysisResult
        """
        return self._analysis

    @analysis.setter
    def analysis(self, analysis):
        """Sets the analysis of this EmailAuditDto.


        :param analysis: The analysis of this EmailAuditDto.  # noqa: E501
        :type: EmailAuditAnalysisResult
        """
        if self.local_vars_configuration.client_side_validation and analysis is None:  # noqa: E501
            raise ValueError("Invalid value for `analysis`, must not be `None`")  # noqa: E501

        self._analysis = analysis

    @property
    def created_at(self):
        """Gets the created_at of this EmailAuditDto.  # noqa: E501


        :return: The created_at of this EmailAuditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EmailAuditDto.


        :param created_at: The created_at of this EmailAuditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this EmailAuditDto.  # noqa: E501


        :return: The updated_at of this EmailAuditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this EmailAuditDto.


        :param updated_at: The updated_at of this EmailAuditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailAuditDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailAuditDto):
            return True

        return self.to_dict() != other.to_dict()
