# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.device_previews_controller_api import DevicePreviewsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestDevicePreviewsControllerApi(unittest.TestCase):
    """DevicePreviewsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.device_previews_controller_api.DevicePreviewsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_device_preview_run(self):
        """Test case for cancel_device_preview_run

        Cancel a running device preview run  # noqa: E501
        """
        pass

    def test_create_device_preview_feedback(self):
        """Test case for create_device_preview_feedback

        Create device preview feedback  # noqa: E501
        """
        pass

    def test_create_device_preview_run(self):
        """Test case for create_device_preview_run

        Create a new device preview run for an email  # noqa: E501
        """
        pass

    def test_delete_device_preview_run(self):
        """Test case for delete_device_preview_run

        Delete local device preview run data  # noqa: E501
        """
        pass

    def test_ensure_device_preview_run(self):
        """Test case for ensure_device_preview_run

        Return active run for email or create one when none exists  # noqa: E501
        """
        pass

    def test_get_device_preview_feedback(self):
        """Test case for get_device_preview_feedback

        Get a single device preview feedback item  # noqa: E501
        """
        pass

    def test_get_device_preview_feedback_items(self):
        """Test case for get_device_preview_feedback_items

        List device preview feedback  # noqa: E501
        """
        pass

    def test_get_device_preview_run(self):
        """Test case for get_device_preview_run

        Get device preview run status  # noqa: E501
        """
        pass

    def test_get_device_preview_run_provider_progress(self):
        """Test case for get_device_preview_run_provider_progress

        Get provider-level progress for a device preview run  # noqa: E501
        """
        pass

    def test_get_device_preview_run_results(self):
        """Test case for get_device_preview_run_results

        Get device preview run results  # noqa: E501
        """
        pass

    def test_get_device_preview_run_screenshot(self):
        """Test case for get_device_preview_run_screenshot

        Get a seeded device preview screenshot image  # noqa: E501
        """
        pass

    def test_get_device_preview_runs(self):
        """Test case for get_device_preview_runs

        List previous device preview runs for an email  # noqa: E501
        """
        pass

    def test_get_device_preview_runs_for_account(self):
        """Test case for get_device_preview_runs_for_account

        List previous device preview runs for account  # noqa: E501
        """
        pass

    def test_get_device_preview_runs_offset_paginated(self):
        """Test case for get_device_preview_runs_offset_paginated

        List previous device preview runs for an email in paginated form  # noqa: E501
        """
        pass

    def test_update_device_preview_feedback(self):
        """Test case for update_device_preview_feedback

        Update device preview feedback  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
