# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformResultProjectionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'ai_transform_id': 'str',
        'ai_transform_mapping_id': 'str',
        'user_id': 'str',
        'value': 'object',
        'entity_id': 'str',
        'entity_type': 'str',
        'sms_id': 'str',
        'email_id': 'str',
        'attachment_id': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'ai_transform_id': 'aiTransformId',
        'ai_transform_mapping_id': 'aiTransformMappingId',
        'user_id': 'userId',
        'value': 'value',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'sms_id': 'smsId',
        'email_id': 'emailId',
        'attachment_id': 'attachmentId',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, ai_transform_id=None, ai_transform_mapping_id=None, user_id=None, value=None, entity_id=None, entity_type=None, sms_id=None, email_id=None, attachment_id=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """AITransformResultProjectionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ai_transform_id = None
        self._ai_transform_mapping_id = None
        self._user_id = None
        self._value = None
        self._entity_id = None
        self._entity_type = None
        self._sms_id = None
        self._email_id = None
        self._attachment_id = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.ai_transform_id = ai_transform_id
        self.ai_transform_mapping_id = ai_transform_mapping_id
        self.user_id = user_id
        self.value = value
        self.entity_id = entity_id
        self.entity_type = entity_type
        self.sms_id = sms_id
        self.email_id = email_id
        self.attachment_id = attachment_id
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AITransformResultProjectionDto.


        :param id: The id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The ai_transform_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this AITransformResultProjectionDto.


        :param ai_transform_id: The ai_transform_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_id`, must not be `None`")  # noqa: E501

        self._ai_transform_id = ai_transform_id

    @property
    def ai_transform_mapping_id(self):
        """Gets the ai_transform_mapping_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The ai_transform_mapping_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_mapping_id

    @ai_transform_mapping_id.setter
    def ai_transform_mapping_id(self, ai_transform_mapping_id):
        """Sets the ai_transform_mapping_id of this AITransformResultProjectionDto.


        :param ai_transform_mapping_id: The ai_transform_mapping_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._ai_transform_mapping_id = ai_transform_mapping_id

    @property
    def user_id(self):
        """Gets the user_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The user_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AITransformResultProjectionDto.


        :param user_id: The user_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def value(self):
        """Gets the value of this AITransformResultProjectionDto.  # noqa: E501


        :return: The value of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this AITransformResultProjectionDto.


        :param value: The value of this AITransformResultProjectionDto.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def entity_id(self):
        """Gets the entity_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The entity_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this AITransformResultProjectionDto.


        :param entity_id: The entity_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this AITransformResultProjectionDto.  # noqa: E501


        :return: The entity_type of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this AITransformResultProjectionDto.


        :param entity_type: The entity_type of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def sms_id(self):
        """Gets the sms_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The sms_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._sms_id

    @sms_id.setter
    def sms_id(self, sms_id):
        """Sets the sms_id of this AITransformResultProjectionDto.


        :param sms_id: The sms_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._sms_id = sms_id

    @property
    def email_id(self):
        """Gets the email_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The email_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this AITransformResultProjectionDto.


        :param email_id: The email_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def attachment_id(self):
        """Gets the attachment_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The attachment_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this AITransformResultProjectionDto.


        :param attachment_id: The attachment_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def created_at(self):
        """Gets the created_at of this AITransformResultProjectionDto.  # noqa: E501


        :return: The created_at of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AITransformResultProjectionDto.


        :param created_at: The created_at of this AITransformResultProjectionDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformResultProjectionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformResultProjectionDto):
            return True

        return self.to_dict() != other.to_dict()
