# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupDkimDomainResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'valid': 'bool',
        'queried_name': 'str',
        'selector': 'str',
        'record': 'str',
        'algorithm': 'str',
        'key_length': 'int',
        'checked_names': 'list[str]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'valid': 'valid',
        'queried_name': 'queriedName',
        'selector': 'selector',
        'record': 'record',
        'algorithm': 'algorithm',
        'key_length': 'keyLength',
        'checked_names': 'checkedNames',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, valid=None, queried_name=None, selector=None, record=None, algorithm=None, key_length=None, checked_names=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """LookupDkimDomainResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._valid = None
        self._queried_name = None
        self._selector = None
        self._record = None
        self._algorithm = None
        self._key_length = None
        self._checked_names = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.valid = valid
        if queried_name is not None:
            self.queried_name = queried_name
        if selector is not None:
            self.selector = selector
        if record is not None:
            self.record = record
        if algorithm is not None:
            self.algorithm = algorithm
        if key_length is not None:
            self.key_length = key_length
        self.checked_names = checked_names
        self.warnings = warnings
        self.errors = errors

    @property
    def valid(self):
        """Gets the valid of this LookupDkimDomainResults.  # noqa: E501


        :return: The valid of this LookupDkimDomainResults.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this LookupDkimDomainResults.


        :param valid: The valid of this LookupDkimDomainResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and valid is None:  # noqa: E501
            raise ValueError("Invalid value for `valid`, must not be `None`")  # noqa: E501

        self._valid = valid

    @property
    def queried_name(self):
        """Gets the queried_name of this LookupDkimDomainResults.  # noqa: E501


        :return: The queried_name of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._queried_name

    @queried_name.setter
    def queried_name(self, queried_name):
        """Sets the queried_name of this LookupDkimDomainResults.


        :param queried_name: The queried_name of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._queried_name = queried_name

    @property
    def selector(self):
        """Gets the selector of this LookupDkimDomainResults.  # noqa: E501


        :return: The selector of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._selector

    @selector.setter
    def selector(self, selector):
        """Sets the selector of this LookupDkimDomainResults.


        :param selector: The selector of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._selector = selector

    @property
    def record(self):
        """Gets the record of this LookupDkimDomainResults.  # noqa: E501


        :return: The record of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this LookupDkimDomainResults.


        :param record: The record of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._record = record

    @property
    def algorithm(self):
        """Gets the algorithm of this LookupDkimDomainResults.  # noqa: E501


        :return: The algorithm of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this LookupDkimDomainResults.


        :param algorithm: The algorithm of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._algorithm = algorithm

    @property
    def key_length(self):
        """Gets the key_length of this LookupDkimDomainResults.  # noqa: E501


        :return: The key_length of this LookupDkimDomainResults.  # noqa: E501
        :rtype: int
        """
        return self._key_length

    @key_length.setter
    def key_length(self, key_length):
        """Sets the key_length of this LookupDkimDomainResults.


        :param key_length: The key_length of this LookupDkimDomainResults.  # noqa: E501
        :type: int
        """

        self._key_length = key_length

    @property
    def checked_names(self):
        """Gets the checked_names of this LookupDkimDomainResults.  # noqa: E501


        :return: The checked_names of this LookupDkimDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._checked_names

    @checked_names.setter
    def checked_names(self, checked_names):
        """Sets the checked_names of this LookupDkimDomainResults.


        :param checked_names: The checked_names of this LookupDkimDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and checked_names is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_names`, must not be `None`")  # noqa: E501

        self._checked_names = checked_names

    @property
    def warnings(self):
        """Gets the warnings of this LookupDkimDomainResults.  # noqa: E501


        :return: The warnings of this LookupDkimDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupDkimDomainResults.


        :param warnings: The warnings of this LookupDkimDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this LookupDkimDomainResults.  # noqa: E501


        :return: The errors of this LookupDkimDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupDkimDomainResults.


        :param errors: The errors of this LookupDkimDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupDkimDomainResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupDkimDomainResults):
            return True

        return self.to_dict() != other.to_dict()
