# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformCreateOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'conditions': 'list[str]',
        'instructions': 'list[str]',
        'output_schema': 'StructuredOutputSchema',
        'output_schema_id': 'str',
        'extract_prompt': 'str'
    }

    attribute_map = {
        'name': 'name',
        'conditions': 'conditions',
        'instructions': 'instructions',
        'output_schema': 'outputSchema',
        'output_schema_id': 'outputSchemaId',
        'extract_prompt': 'extractPrompt'
    }

    def __init__(self, name=None, conditions=None, instructions=None, output_schema=None, output_schema_id=None, extract_prompt=None, local_vars_configuration=None):  # noqa: E501
        """AITransformCreateOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._conditions = None
        self._instructions = None
        self._output_schema = None
        self._output_schema_id = None
        self._extract_prompt = None
        self.discriminator = None

        self.name = name
        self.conditions = conditions
        self.instructions = instructions
        self.output_schema = output_schema
        self.output_schema_id = output_schema_id
        self.extract_prompt = extract_prompt

    @property
    def name(self):
        """Gets the name of this AITransformCreateOptions.  # noqa: E501


        :return: The name of this AITransformCreateOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AITransformCreateOptions.


        :param name: The name of this AITransformCreateOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def conditions(self):
        """Gets the conditions of this AITransformCreateOptions.  # noqa: E501


        :return: The conditions of this AITransformCreateOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this AITransformCreateOptions.


        :param conditions: The conditions of this AITransformCreateOptions.  # noqa: E501
        :type: list[str]
        """

        self._conditions = conditions

    @property
    def instructions(self):
        """Gets the instructions of this AITransformCreateOptions.  # noqa: E501


        :return: The instructions of this AITransformCreateOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this AITransformCreateOptions.


        :param instructions: The instructions of this AITransformCreateOptions.  # noqa: E501
        :type: list[str]
        """

        self._instructions = instructions

    @property
    def output_schema(self):
        """Gets the output_schema of this AITransformCreateOptions.  # noqa: E501


        :return: The output_schema of this AITransformCreateOptions.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """Sets the output_schema of this AITransformCreateOptions.


        :param output_schema: The output_schema of this AITransformCreateOptions.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._output_schema = output_schema

    @property
    def output_schema_id(self):
        """Gets the output_schema_id of this AITransformCreateOptions.  # noqa: E501


        :return: The output_schema_id of this AITransformCreateOptions.  # noqa: E501
        :rtype: str
        """
        return self._output_schema_id

    @output_schema_id.setter
    def output_schema_id(self, output_schema_id):
        """Sets the output_schema_id of this AITransformCreateOptions.


        :param output_schema_id: The output_schema_id of this AITransformCreateOptions.  # noqa: E501
        :type: str
        """

        self._output_schema_id = output_schema_id

    @property
    def extract_prompt(self):
        """Gets the extract_prompt of this AITransformCreateOptions.  # noqa: E501


        :return: The extract_prompt of this AITransformCreateOptions.  # noqa: E501
        :rtype: str
        """
        return self._extract_prompt

    @extract_prompt.setter
    def extract_prompt(self, extract_prompt):
        """Sets the extract_prompt of this AITransformCreateOptions.


        :param extract_prompt: The extract_prompt of this AITransformCreateOptions.  # noqa: E501
        :type: str
        """

        self._extract_prompt = extract_prompt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformCreateOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformCreateOptions):
            return True

        return self.to_dict() != other.to_dict()
