# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AnalyzeEmailHeadersResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'summary': 'EmailHeaderAnalysisSummary',
        'received_path': 'list[EmailHeaderReceivedHop]',
        'parsed_headers': 'dict(str, list[str])',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'summary': 'summary',
        'received_path': 'receivedPath',
        'parsed_headers': 'parsedHeaders',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, summary=None, received_path=None, parsed_headers=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """AnalyzeEmailHeadersResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._summary = None
        self._received_path = None
        self._parsed_headers = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.summary = summary
        self.received_path = received_path
        self.parsed_headers = parsed_headers
        self.warnings = warnings
        self.errors = errors

    @property
    def summary(self):
        """Gets the summary of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The summary of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: EmailHeaderAnalysisSummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this AnalyzeEmailHeadersResults.


        :param summary: The summary of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: EmailHeaderAnalysisSummary
        """
        if self.local_vars_configuration.client_side_validation and summary is None:  # noqa: E501
            raise ValueError("Invalid value for `summary`, must not be `None`")  # noqa: E501

        self._summary = summary

    @property
    def received_path(self):
        """Gets the received_path of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The received_path of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: list[EmailHeaderReceivedHop]
        """
        return self._received_path

    @received_path.setter
    def received_path(self, received_path):
        """Sets the received_path of this AnalyzeEmailHeadersResults.


        :param received_path: The received_path of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: list[EmailHeaderReceivedHop]
        """
        if self.local_vars_configuration.client_side_validation and received_path is None:  # noqa: E501
            raise ValueError("Invalid value for `received_path`, must not be `None`")  # noqa: E501

        self._received_path = received_path

    @property
    def parsed_headers(self):
        """Gets the parsed_headers of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The parsed_headers of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._parsed_headers

    @parsed_headers.setter
    def parsed_headers(self, parsed_headers):
        """Sets the parsed_headers of this AnalyzeEmailHeadersResults.


        :param parsed_headers: The parsed_headers of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: dict(str, list[str])
        """
        if self.local_vars_configuration.client_side_validation and parsed_headers is None:  # noqa: E501
            raise ValueError("Invalid value for `parsed_headers`, must not be `None`")  # noqa: E501

        self._parsed_headers = parsed_headers

    @property
    def warnings(self):
        """Gets the warnings of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The warnings of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this AnalyzeEmailHeadersResults.


        :param warnings: The warnings of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The errors of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this AnalyzeEmailHeadersResults.


        :param errors: The errors of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyzeEmailHeadersResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnalyzeEmailHeadersResults):
            return True

        return self.to_dict() != other.to_dict()
