# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckEmailBlacklistOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'ip_address': 'str',
        'mx_host': 'str',
        'captcha_token': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'ip_address': 'ipAddress',
        'mx_host': 'mxHost',
        'captcha_token': 'captchaToken'
    }

    def __init__(self, domain=None, ip_address=None, mx_host=None, captcha_token=None, local_vars_configuration=None):  # noqa: E501
        """CheckEmailBlacklistOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._ip_address = None
        self._mx_host = None
        self._captcha_token = None
        self.discriminator = None

        self.domain = domain
        self.ip_address = ip_address
        self.mx_host = mx_host
        self.captcha_token = captcha_token

    @property
    def domain(self):
        """Gets the domain of this CheckEmailBlacklistOptions.  # noqa: E501

        Domain to expand into A and MX host IPv4 addresses  # noqa: E501

        :return: The domain of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CheckEmailBlacklistOptions.

        Domain to expand into A and MX host IPv4 addresses  # noqa: E501

        :param domain: The domain of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def ip_address(self):
        """Gets the ip_address of this CheckEmailBlacklistOptions.  # noqa: E501

        Specific IPv4 address to check directly  # noqa: E501

        :return: The ip_address of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this CheckEmailBlacklistOptions.

        Specific IPv4 address to check directly  # noqa: E501

        :param ip_address: The ip_address of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def mx_host(self):
        """Gets the mx_host of this CheckEmailBlacklistOptions.  # noqa: E501

        Specific MX host to resolve and check directly  # noqa: E501

        :return: The mx_host of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._mx_host

    @mx_host.setter
    def mx_host(self, mx_host):
        """Sets the mx_host of this CheckEmailBlacklistOptions.

        Specific MX host to resolve and check directly  # noqa: E501

        :param mx_host: The mx_host of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._mx_host = mx_host

    @property
    def captcha_token(self):
        """Gets the captcha_token of this CheckEmailBlacklistOptions.  # noqa: E501


        :return: The captcha_token of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._captcha_token

    @captcha_token.setter
    def captcha_token(self, captcha_token):
        """Sets the captcha_token of this CheckEmailBlacklistOptions.


        :param captcha_token: The captcha_token of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._captcha_token = captcha_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckEmailBlacklistOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckEmailBlacklistOptions):
            return True

        return self.to_dict() != other.to_dict()
