# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.domain_monitor_controller_api import DomainMonitorControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestDomainMonitorControllerApi(unittest.TestCase):
    """DomainMonitorControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.domain_monitor_controller_api.DomainMonitorControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_compare_domain_monitor_runs(self):
        """Test case for compare_domain_monitor_runs

        Compare two monitor runs  # noqa: E501
        """
        pass

    def test_create_domain_monitor(self):
        """Test case for create_domain_monitor

        Create domain monitor  # noqa: E501
        """
        pass

    def test_create_domain_monitor_alert_sink(self):
        """Test case for create_domain_monitor_alert_sink

        Create alert sink for monitor  # noqa: E501
        """
        pass

    def test_delete_domain_monitor(self):
        """Test case for delete_domain_monitor

        Delete domain monitor  # noqa: E501
        """
        pass

    def test_delete_domain_monitor_alert_sink(self):
        """Test case for delete_domain_monitor_alert_sink

        Delete monitor alert sink  # noqa: E501
        """
        pass

    def test_get_domain_monitor(self):
        """Test case for get_domain_monitor

        Get domain monitor  # noqa: E501
        """
        pass

    def test_get_domain_monitor_alert_sinks(self):
        """Test case for get_domain_monitor_alert_sinks

        List alert sinks for monitor  # noqa: E501
        """
        pass

    def test_get_domain_monitor_auth_stack(self):
        """Test case for get_domain_monitor_auth_stack

        Get current auth stack for monitor domain  # noqa: E501
        """
        pass

    def test_get_domain_monitor_insights(self):
        """Test case for get_domain_monitor_insights

        Get monitor insights  # noqa: E501
        """
        pass

    def test_get_domain_monitor_run(self):
        """Test case for get_domain_monitor_run

        Get monitor run  # noqa: E501
        """
        pass

    def test_get_domain_monitor_runs(self):
        """Test case for get_domain_monitor_runs

        List monitor runs  # noqa: E501
        """
        pass

    def test_get_domain_monitor_series(self):
        """Test case for get_domain_monitor_series

        Get monitor trend series  # noqa: E501
        """
        pass

    def test_get_domain_monitor_summary(self):
        """Test case for get_domain_monitor_summary

        Get domain monitor summary  # noqa: E501
        """
        pass

    def test_get_domain_monitors(self):
        """Test case for get_domain_monitors

        List domain monitors  # noqa: E501
        """
        pass

    def test_run_domain_monitor_now(self):
        """Test case for run_domain_monitor_now

        Run monitor now  # noqa: E501
        """
        pass

    def test_run_due_domain_monitors(self):
        """Test case for run_due_domain_monitors

        Run due monitors for user  # noqa: E501
        """
        pass

    def test_update_domain_monitor(self):
        """Test case for update_domain_monitor

        Update domain monitor  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
