# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneProvisioningJobItemDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'phone_number': 'str',
        'provider_label': 'str',
        'status': 'str',
        'line_type': 'str',
        'carrier_name': 'str',
        'mobile_country_code': 'str',
        'mobile_network_code': 'str',
        'phone_number_id': 'str',
        'failure_message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'phone_number': 'phoneNumber',
        'provider_label': 'providerLabel',
        'status': 'status',
        'line_type': 'lineType',
        'carrier_name': 'carrierName',
        'mobile_country_code': 'mobileCountryCode',
        'mobile_network_code': 'mobileNetworkCode',
        'phone_number_id': 'phoneNumberId',
        'failure_message': 'failureMessage'
    }

    def __init__(self, id=None, phone_number=None, provider_label=None, status=None, line_type=None, carrier_name=None, mobile_country_code=None, mobile_network_code=None, phone_number_id=None, failure_message=None, local_vars_configuration=None):  # noqa: E501
        """PhoneProvisioningJobItemDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._phone_number = None
        self._provider_label = None
        self._status = None
        self._line_type = None
        self._carrier_name = None
        self._mobile_country_code = None
        self._mobile_network_code = None
        self._phone_number_id = None
        self._failure_message = None
        self.discriminator = None

        self.id = id
        self.phone_number = phone_number
        if provider_label is not None:
            self.provider_label = provider_label
        self.status = status
        if line_type is not None:
            self.line_type = line_type
        if carrier_name is not None:
            self.carrier_name = carrier_name
        if mobile_country_code is not None:
            self.mobile_country_code = mobile_country_code
        if mobile_network_code is not None:
            self.mobile_network_code = mobile_network_code
        if phone_number_id is not None:
            self.phone_number_id = phone_number_id
        if failure_message is not None:
            self.failure_message = failure_message

    @property
    def id(self):
        """Gets the id of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneProvisioningJobItemDto.


        :param id: The id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The phone_number of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneProvisioningJobItemDto.


        :param phone_number: The phone_number of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def provider_label(self):
        """Gets the provider_label of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The provider_label of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._provider_label

    @provider_label.setter
    def provider_label(self, provider_label):
        """Sets the provider_label of this PhoneProvisioningJobItemDto.


        :param provider_label: The provider_label of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._provider_label = provider_label

    @property
    def status(self):
        """Gets the status of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The status of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PhoneProvisioningJobItemDto.


        :param status: The status of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "PROVISIONING", "PROVISIONED", "UNAVAILABLE", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def line_type(self):
        """Gets the line_type of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The line_type of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._line_type

    @line_type.setter
    def line_type(self, line_type):
        """Sets the line_type of this PhoneProvisioningJobItemDto.


        :param line_type: The line_type of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._line_type = line_type

    @property
    def carrier_name(self):
        """Gets the carrier_name of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The carrier_name of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """Sets the carrier_name of this PhoneProvisioningJobItemDto.


        :param carrier_name: The carrier_name of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._carrier_name = carrier_name

    @property
    def mobile_country_code(self):
        """Gets the mobile_country_code of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The mobile_country_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._mobile_country_code

    @mobile_country_code.setter
    def mobile_country_code(self, mobile_country_code):
        """Sets the mobile_country_code of this PhoneProvisioningJobItemDto.


        :param mobile_country_code: The mobile_country_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._mobile_country_code = mobile_country_code

    @property
    def mobile_network_code(self):
        """Gets the mobile_network_code of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The mobile_network_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._mobile_network_code

    @mobile_network_code.setter
    def mobile_network_code(self, mobile_network_code):
        """Sets the mobile_network_code of this PhoneProvisioningJobItemDto.


        :param mobile_network_code: The mobile_network_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._mobile_network_code = mobile_network_code

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The phone_number_id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this PhoneProvisioningJobItemDto.


        :param phone_number_id: The phone_number_id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._phone_number_id = phone_number_id

    @property
    def failure_message(self):
        """Gets the failure_message of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The failure_message of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._failure_message

    @failure_message.setter
    def failure_message(self, failure_message):
        """Sets the failure_message of this PhoneProvisioningJobItemDto.


        :param failure_message: The failure_message of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._failure_message = failure_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneProvisioningJobItemDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneProvisioningJobItemDto):
            return True

        return self.to_dict() != other.to_dict()
