# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailAuditAnalysisResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'detected_links': 'int',
        'checked_links': 'int',
        'detected_images': 'int',
        'checked_images': 'int',
        'link_issue_count': 'int',
        'image_issue_count': 'int',
        'spelling_issue_count': 'int',
        'broken_links': 'list[EmailAuditUrlIssue]',
        'broken_images': 'list[EmailAuditUrlIssue]',
        'spelling_issues': 'list[EmailAuditSpellingIssue]',
        'compatibility_warning_count': 'int',
        'compatibility_not_supported_count': 'int',
        'compatibility_unknown_count': 'int',
        'feature_support': 'EmailFeatureSupportResult',
        'html_error_count': 'int',
        'html_warning_count': 'int',
        'html_info_count': 'int',
        'html_validation': 'HTMLValidationResult',
        'reputation_failure_count': 'int',
        'attachment_mention_issue_count': 'int',
        'external_check_skipped_count': 'int',
        'insights': 'list[str]',
        'error_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'detected_links': 'detectedLinks',
        'checked_links': 'checkedLinks',
        'detected_images': 'detectedImages',
        'checked_images': 'checkedImages',
        'link_issue_count': 'linkIssueCount',
        'image_issue_count': 'imageIssueCount',
        'spelling_issue_count': 'spellingIssueCount',
        'broken_links': 'brokenLinks',
        'broken_images': 'brokenImages',
        'spelling_issues': 'spellingIssues',
        'compatibility_warning_count': 'compatibilityWarningCount',
        'compatibility_not_supported_count': 'compatibilityNotSupportedCount',
        'compatibility_unknown_count': 'compatibilityUnknownCount',
        'feature_support': 'featureSupport',
        'html_error_count': 'htmlErrorCount',
        'html_warning_count': 'htmlWarningCount',
        'html_info_count': 'htmlInfoCount',
        'html_validation': 'htmlValidation',
        'reputation_failure_count': 'reputationFailureCount',
        'attachment_mention_issue_count': 'attachmentMentionIssueCount',
        'external_check_skipped_count': 'externalCheckSkippedCount',
        'insights': 'insights',
        'error_message': 'errorMessage'
    }

    def __init__(self, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, detected_links=None, checked_links=None, detected_images=None, checked_images=None, link_issue_count=None, image_issue_count=None, spelling_issue_count=None, broken_links=None, broken_images=None, spelling_issues=None, compatibility_warning_count=None, compatibility_not_supported_count=None, compatibility_unknown_count=None, feature_support=None, html_error_count=None, html_warning_count=None, html_info_count=None, html_validation=None, reputation_failure_count=None, attachment_mention_issue_count=None, external_check_skipped_count=None, insights=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """EmailAuditAnalysisResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._detected_links = None
        self._checked_links = None
        self._detected_images = None
        self._checked_images = None
        self._link_issue_count = None
        self._image_issue_count = None
        self._spelling_issue_count = None
        self._broken_links = None
        self._broken_images = None
        self._spelling_issues = None
        self._compatibility_warning_count = None
        self._compatibility_not_supported_count = None
        self._compatibility_unknown_count = None
        self._feature_support = None
        self._html_error_count = None
        self._html_warning_count = None
        self._html_info_count = None
        self._html_validation = None
        self._reputation_failure_count = None
        self._attachment_mention_issue_count = None
        self._external_check_skipped_count = None
        self._insights = None
        self._error_message = None
        self.discriminator = None

        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.detected_links = detected_links
        self.checked_links = checked_links
        self.detected_images = detected_images
        self.checked_images = checked_images
        self.link_issue_count = link_issue_count
        self.image_issue_count = image_issue_count
        self.spelling_issue_count = spelling_issue_count
        self.broken_links = broken_links
        self.broken_images = broken_images
        self.spelling_issues = spelling_issues
        self.compatibility_warning_count = compatibility_warning_count
        self.compatibility_not_supported_count = compatibility_not_supported_count
        self.compatibility_unknown_count = compatibility_unknown_count
        if feature_support is not None:
            self.feature_support = feature_support
        self.html_error_count = html_error_count
        self.html_warning_count = html_warning_count
        self.html_info_count = html_info_count
        self.html_validation = html_validation
        self.reputation_failure_count = reputation_failure_count
        self.attachment_mention_issue_count = attachment_mention_issue_count
        self.external_check_skipped_count = external_check_skipped_count
        self.insights = insights
        self.error_message = error_message

    @property
    def status(self):
        """Gets the status of this EmailAuditAnalysisResult.  # noqa: E501

        Health status for a one-shot email audit  # noqa: E501

        :return: The status of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this EmailAuditAnalysisResult.

        Health status for a one-shot email audit  # noqa: E501

        :param status: The status of this EmailAuditAnalysisResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The health_score of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this EmailAuditAnalysisResult.


        :param health_score: The health_score of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The total_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this EmailAuditAnalysisResult.


        :param total_checks: The total_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The passing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this EmailAuditAnalysisResult.


        :param passing_checks: The passing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The failing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this EmailAuditAnalysisResult.


        :param failing_checks: The failing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def detected_links(self):
        """Gets the detected_links of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The detected_links of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._detected_links

    @detected_links.setter
    def detected_links(self, detected_links):
        """Sets the detected_links of this EmailAuditAnalysisResult.


        :param detected_links: The detected_links of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and detected_links is None:  # noqa: E501
            raise ValueError("Invalid value for `detected_links`, must not be `None`")  # noqa: E501

        self._detected_links = detected_links

    @property
    def checked_links(self):
        """Gets the checked_links of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The checked_links of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._checked_links

    @checked_links.setter
    def checked_links(self, checked_links):
        """Sets the checked_links of this EmailAuditAnalysisResult.


        :param checked_links: The checked_links of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_links is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_links`, must not be `None`")  # noqa: E501

        self._checked_links = checked_links

    @property
    def detected_images(self):
        """Gets the detected_images of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The detected_images of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._detected_images

    @detected_images.setter
    def detected_images(self, detected_images):
        """Sets the detected_images of this EmailAuditAnalysisResult.


        :param detected_images: The detected_images of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and detected_images is None:  # noqa: E501
            raise ValueError("Invalid value for `detected_images`, must not be `None`")  # noqa: E501

        self._detected_images = detected_images

    @property
    def checked_images(self):
        """Gets the checked_images of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The checked_images of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._checked_images

    @checked_images.setter
    def checked_images(self, checked_images):
        """Sets the checked_images of this EmailAuditAnalysisResult.


        :param checked_images: The checked_images of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_images is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_images`, must not be `None`")  # noqa: E501

        self._checked_images = checked_images

    @property
    def link_issue_count(self):
        """Gets the link_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The link_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_count

    @link_issue_count.setter
    def link_issue_count(self, link_issue_count):
        """Sets the link_issue_count of this EmailAuditAnalysisResult.


        :param link_issue_count: The link_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_count`, must not be `None`")  # noqa: E501

        self._link_issue_count = link_issue_count

    @property
    def image_issue_count(self):
        """Gets the image_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The image_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_count

    @image_issue_count.setter
    def image_issue_count(self, image_issue_count):
        """Sets the image_issue_count of this EmailAuditAnalysisResult.


        :param image_issue_count: The image_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_count`, must not be `None`")  # noqa: E501

        self._image_issue_count = image_issue_count

    @property
    def spelling_issue_count(self):
        """Gets the spelling_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The spelling_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._spelling_issue_count

    @spelling_issue_count.setter
    def spelling_issue_count(self, spelling_issue_count):
        """Sets the spelling_issue_count of this EmailAuditAnalysisResult.


        :param spelling_issue_count: The spelling_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and spelling_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `spelling_issue_count`, must not be `None`")  # noqa: E501

        self._spelling_issue_count = spelling_issue_count

    @property
    def broken_links(self):
        """Gets the broken_links of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The broken_links of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[EmailAuditUrlIssue]
        """
        return self._broken_links

    @broken_links.setter
    def broken_links(self, broken_links):
        """Sets the broken_links of this EmailAuditAnalysisResult.


        :param broken_links: The broken_links of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[EmailAuditUrlIssue]
        """
        if self.local_vars_configuration.client_side_validation and broken_links is None:  # noqa: E501
            raise ValueError("Invalid value for `broken_links`, must not be `None`")  # noqa: E501

        self._broken_links = broken_links

    @property
    def broken_images(self):
        """Gets the broken_images of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The broken_images of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[EmailAuditUrlIssue]
        """
        return self._broken_images

    @broken_images.setter
    def broken_images(self, broken_images):
        """Sets the broken_images of this EmailAuditAnalysisResult.


        :param broken_images: The broken_images of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[EmailAuditUrlIssue]
        """
        if self.local_vars_configuration.client_side_validation and broken_images is None:  # noqa: E501
            raise ValueError("Invalid value for `broken_images`, must not be `None`")  # noqa: E501

        self._broken_images = broken_images

    @property
    def spelling_issues(self):
        """Gets the spelling_issues of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The spelling_issues of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[EmailAuditSpellingIssue]
        """
        return self._spelling_issues

    @spelling_issues.setter
    def spelling_issues(self, spelling_issues):
        """Sets the spelling_issues of this EmailAuditAnalysisResult.


        :param spelling_issues: The spelling_issues of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[EmailAuditSpellingIssue]
        """
        if self.local_vars_configuration.client_side_validation and spelling_issues is None:  # noqa: E501
            raise ValueError("Invalid value for `spelling_issues`, must not be `None`")  # noqa: E501

        self._spelling_issues = spelling_issues

    @property
    def compatibility_warning_count(self):
        """Gets the compatibility_warning_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The compatibility_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_count

    @compatibility_warning_count.setter
    def compatibility_warning_count(self, compatibility_warning_count):
        """Sets the compatibility_warning_count of this EmailAuditAnalysisResult.


        :param compatibility_warning_count: The compatibility_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_count`, must not be `None`")  # noqa: E501

        self._compatibility_warning_count = compatibility_warning_count

    @property
    def compatibility_not_supported_count(self):
        """Gets the compatibility_not_supported_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The compatibility_not_supported_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_count

    @compatibility_not_supported_count.setter
    def compatibility_not_supported_count(self, compatibility_not_supported_count):
        """Sets the compatibility_not_supported_count of this EmailAuditAnalysisResult.


        :param compatibility_not_supported_count: The compatibility_not_supported_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_count`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_count = compatibility_not_supported_count

    @property
    def compatibility_unknown_count(self):
        """Gets the compatibility_unknown_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The compatibility_unknown_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_unknown_count

    @compatibility_unknown_count.setter
    def compatibility_unknown_count(self, compatibility_unknown_count):
        """Sets the compatibility_unknown_count of this EmailAuditAnalysisResult.


        :param compatibility_unknown_count: The compatibility_unknown_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_unknown_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_unknown_count`, must not be `None`")  # noqa: E501

        self._compatibility_unknown_count = compatibility_unknown_count

    @property
    def feature_support(self):
        """Gets the feature_support of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The feature_support of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: EmailFeatureSupportResult
        """
        return self._feature_support

    @feature_support.setter
    def feature_support(self, feature_support):
        """Sets the feature_support of this EmailAuditAnalysisResult.


        :param feature_support: The feature_support of this EmailAuditAnalysisResult.  # noqa: E501
        :type: EmailFeatureSupportResult
        """

        self._feature_support = feature_support

    @property
    def html_error_count(self):
        """Gets the html_error_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_error_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._html_error_count

    @html_error_count.setter
    def html_error_count(self, html_error_count):
        """Sets the html_error_count of this EmailAuditAnalysisResult.


        :param html_error_count: The html_error_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_count`, must not be `None`")  # noqa: E501

        self._html_error_count = html_error_count

    @property
    def html_warning_count(self):
        """Gets the html_warning_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_count

    @html_warning_count.setter
    def html_warning_count(self, html_warning_count):
        """Sets the html_warning_count of this EmailAuditAnalysisResult.


        :param html_warning_count: The html_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_count`, must not be `None`")  # noqa: E501

        self._html_warning_count = html_warning_count

    @property
    def html_info_count(self):
        """Gets the html_info_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_info_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._html_info_count

    @html_info_count.setter
    def html_info_count(self, html_info_count):
        """Sets the html_info_count of this EmailAuditAnalysisResult.


        :param html_info_count: The html_info_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_info_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_info_count`, must not be `None`")  # noqa: E501

        self._html_info_count = html_info_count

    @property
    def html_validation(self):
        """Gets the html_validation of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_validation of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: HTMLValidationResult
        """
        return self._html_validation

    @html_validation.setter
    def html_validation(self, html_validation):
        """Sets the html_validation of this EmailAuditAnalysisResult.


        :param html_validation: The html_validation of this EmailAuditAnalysisResult.  # noqa: E501
        :type: HTMLValidationResult
        """

        self._html_validation = html_validation

    @property
    def reputation_failure_count(self):
        """Gets the reputation_failure_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The reputation_failure_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._reputation_failure_count

    @reputation_failure_count.setter
    def reputation_failure_count(self, reputation_failure_count):
        """Sets the reputation_failure_count of this EmailAuditAnalysisResult.


        :param reputation_failure_count: The reputation_failure_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and reputation_failure_count is None:  # noqa: E501
            raise ValueError("Invalid value for `reputation_failure_count`, must not be `None`")  # noqa: E501

        self._reputation_failure_count = reputation_failure_count

    @property
    def attachment_mention_issue_count(self):
        """Gets the attachment_mention_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The attachment_mention_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_count

    @attachment_mention_issue_count.setter
    def attachment_mention_issue_count(self, attachment_mention_issue_count):
        """Sets the attachment_mention_issue_count of this EmailAuditAnalysisResult.


        :param attachment_mention_issue_count: The attachment_mention_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_count`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_count = attachment_mention_issue_count

    @property
    def external_check_skipped_count(self):
        """Gets the external_check_skipped_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The external_check_skipped_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._external_check_skipped_count

    @external_check_skipped_count.setter
    def external_check_skipped_count(self, external_check_skipped_count):
        """Sets the external_check_skipped_count of this EmailAuditAnalysisResult.


        :param external_check_skipped_count: The external_check_skipped_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and external_check_skipped_count is None:  # noqa: E501
            raise ValueError("Invalid value for `external_check_skipped_count`, must not be `None`")  # noqa: E501

        self._external_check_skipped_count = external_check_skipped_count

    @property
    def insights(self):
        """Gets the insights of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The insights of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this EmailAuditAnalysisResult.


        :param insights: The insights of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The error_message of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this EmailAuditAnalysisResult.


        :param error_message: The error_message of this EmailAuditAnalysisResult.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailAuditAnalysisResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailAuditAnalysisResult):
            return True

        return self.to_dict() != other.to_dict()
