# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AuditLogSearchOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'since': 'datetime',
        'before': 'datetime',
        'action': 'str',
        'user_id': 'str',
        'actor_user_id': 'str',
        'target_user_id': 'str',
        'resource_type': 'str',
        'resource_id': 'str',
        'outcome': 'str',
        'request_id': 'str',
        'ip_address': 'str',
        'event_id': 'str',
        'page_size': 'int',
        'cursor': 'str'
    }

    attribute_map = {
        'since': 'since',
        'before': 'before',
        'action': 'action',
        'user_id': 'userId',
        'actor_user_id': 'actorUserId',
        'target_user_id': 'targetUserId',
        'resource_type': 'resourceType',
        'resource_id': 'resourceId',
        'outcome': 'outcome',
        'request_id': 'requestId',
        'ip_address': 'ipAddress',
        'event_id': 'eventId',
        'page_size': 'pageSize',
        'cursor': 'cursor'
    }

    def __init__(self, since=None, before=None, action=None, user_id=None, actor_user_id=None, target_user_id=None, resource_type=None, resource_id=None, outcome=None, request_id=None, ip_address=None, event_id=None, page_size=None, cursor=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogSearchOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._since = None
        self._before = None
        self._action = None
        self._user_id = None
        self._actor_user_id = None
        self._target_user_id = None
        self._resource_type = None
        self._resource_id = None
        self._outcome = None
        self._request_id = None
        self._ip_address = None
        self._event_id = None
        self._page_size = None
        self._cursor = None
        self.discriminator = None

        if since is not None:
            self.since = since
        if before is not None:
            self.before = before
        if action is not None:
            self.action = action
        if user_id is not None:
            self.user_id = user_id
        if actor_user_id is not None:
            self.actor_user_id = actor_user_id
        if target_user_id is not None:
            self.target_user_id = target_user_id
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_id is not None:
            self.resource_id = resource_id
        if outcome is not None:
            self.outcome = outcome
        if request_id is not None:
            self.request_id = request_id
        if ip_address is not None:
            self.ip_address = ip_address
        if event_id is not None:
            self.event_id = event_id
        if page_size is not None:
            self.page_size = page_size
        if cursor is not None:
            self.cursor = cursor

    @property
    def since(self):
        """Gets the since of this AuditLogSearchOptions.  # noqa: E501


        :return: The since of this AuditLogSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this AuditLogSearchOptions.


        :param since: The since of this AuditLogSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this AuditLogSearchOptions.  # noqa: E501


        :return: The before of this AuditLogSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this AuditLogSearchOptions.


        :param before: The before of this AuditLogSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def action(self):
        """Gets the action of this AuditLogSearchOptions.  # noqa: E501


        :return: The action of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this AuditLogSearchOptions.


        :param action: The action of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def user_id(self):
        """Gets the user_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The user_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AuditLogSearchOptions.


        :param user_id: The user_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def actor_user_id(self):
        """Gets the actor_user_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The actor_user_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._actor_user_id

    @actor_user_id.setter
    def actor_user_id(self, actor_user_id):
        """Sets the actor_user_id of this AuditLogSearchOptions.


        :param actor_user_id: The actor_user_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._actor_user_id = actor_user_id

    @property
    def target_user_id(self):
        """Gets the target_user_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The target_user_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._target_user_id

    @target_user_id.setter
    def target_user_id(self, target_user_id):
        """Sets the target_user_id of this AuditLogSearchOptions.


        :param target_user_id: The target_user_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._target_user_id = target_user_id

    @property
    def resource_type(self):
        """Gets the resource_type of this AuditLogSearchOptions.  # noqa: E501


        :return: The resource_type of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AuditLogSearchOptions.


        :param resource_type: The resource_type of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def resource_id(self):
        """Gets the resource_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The resource_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this AuditLogSearchOptions.


        :param resource_id: The resource_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def outcome(self):
        """Gets the outcome of this AuditLogSearchOptions.  # noqa: E501


        :return: The outcome of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._outcome

    @outcome.setter
    def outcome(self, outcome):
        """Sets the outcome of this AuditLogSearchOptions.


        :param outcome: The outcome of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._outcome = outcome

    @property
    def request_id(self):
        """Gets the request_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The request_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AuditLogSearchOptions.


        :param request_id: The request_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def ip_address(self):
        """Gets the ip_address of this AuditLogSearchOptions.  # noqa: E501


        :return: The ip_address of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this AuditLogSearchOptions.


        :param ip_address: The ip_address of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def event_id(self):
        """Gets the event_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The event_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this AuditLogSearchOptions.


        :param event_id: The event_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._event_id = event_id

    @property
    def page_size(self):
        """Gets the page_size of this AuditLogSearchOptions.  # noqa: E501


        :return: The page_size of this AuditLogSearchOptions.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this AuditLogSearchOptions.


        :param page_size: The page_size of this AuditLogSearchOptions.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def cursor(self):
        """Gets the cursor of this AuditLogSearchOptions.  # noqa: E501


        :return: The cursor of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._cursor

    @cursor.setter
    def cursor(self, cursor):
        """Sets the cursor of this AuditLogSearchOptions.


        :param cursor: The cursor of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._cursor = cursor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogSearchOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogSearchOptions):
            return True

        return self.to_dict() != other.to_dict()
