# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.guest_portal_controller_api import GuestPortalControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestGuestPortalControllerApi(unittest.TestCase):
    """GuestPortalControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.guest_portal_controller_api.GuestPortalControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_guest_portal(self):
        """Test case for create_guest_portal

        Create a portal page for your customers or clients to log into email accounts and view emails.  # noqa: E501
        """
        pass

    def test_create_guest_portal_user(self):
        """Test case for create_guest_portal_user

        Create a portal guest user  # noqa: E501
        """
        pass

    def test_get_all_guest_portal_users(self):
        """Test case for get_all_guest_portal_users

        Get all guest users for portal  # noqa: E501
        """
        pass

    def test_get_guest_portal(self):
        """Test case for get_guest_portal

        Get a client email portal  # noqa: E501
        """
        pass

    def test_get_guest_portal_user(self):
        """Test case for get_guest_portal_user

        Get guest user for portal  # noqa: E501
        """
        pass

    def test_get_guest_portal_user_by_id(self):
        """Test case for get_guest_portal_user_by_id

        Get guest user  # noqa: E501
        """
        pass

    def test_get_guest_portal_users(self):
        """Test case for get_guest_portal_users

        Get all guest users for portal  # noqa: E501
        """
        pass

    def test_get_guest_portals(self):
        """Test case for get_guest_portals

        Get guest portals  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
