# coding: utf-8

# flake8: noqa
"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from mailslurp_client.models.ai_mapping_match_option import AIMappingMatchOption
from mailslurp_client.models.ai_mapping_match_options import AIMappingMatchOptions
from mailslurp_client.models.ai_transform_create_options import AITransformCreateOptions
from mailslurp_client.models.ai_transform_dto import AITransformDto
from mailslurp_client.models.ai_transform_mapping_dto import AITransformMappingDto
from mailslurp_client.models.ai_transform_mapping_match_result import AITransformMappingMatchResult
from mailslurp_client.models.ai_transform_mapping_projection import AITransformMappingProjection
from mailslurp_client.models.ai_transform_projection import AITransformProjection
from mailslurp_client.models.ai_transform_result_dto import AITransformResultDto
from mailslurp_client.models.ai_transform_result_projection_dto import AITransformResultProjectionDto
from mailslurp_client.models.abstract_webhook_payload import AbstractWebhookPayload
from mailslurp_client.models.account_bounce_block_dto import AccountBounceBlockDto
from mailslurp_client.models.acquire_phone_pool_lease_options import AcquirePhonePoolLeaseOptions
from mailslurp_client.models.add_phone_pool_numbers_options import AddPhonePoolNumbersOptions
from mailslurp_client.models.alias_dto import AliasDto
from mailslurp_client.models.alias_projection import AliasProjection
from mailslurp_client.models.alias_thread_projection import AliasThreadProjection
from mailslurp_client.models.analyze_dmarc_report_options import AnalyzeDmarcReportOptions
from mailslurp_client.models.analyze_dmarc_report_results import AnalyzeDmarcReportResults
from mailslurp_client.models.analyze_email_headers_options import AnalyzeEmailHeadersOptions
from mailslurp_client.models.analyze_email_headers_results import AnalyzeEmailHeadersResults
from mailslurp_client.models.attachment_entity_dto import AttachmentEntityDto
from mailslurp_client.models.attachment_meta_data import AttachmentMetaData
from mailslurp_client.models.attachment_projection import AttachmentProjection
from mailslurp_client.models.audit_log_event_dto import AuditLogEventDto
from mailslurp_client.models.audit_log_page_dto import AuditLogPageDto
from mailslurp_client.models.audit_log_search_options import AuditLogSearchOptions
from mailslurp_client.models.available_phone_number_dto import AvailablePhoneNumberDto
from mailslurp_client.models.available_phone_numbers_result import AvailablePhoneNumbersResult
from mailslurp_client.models.basic_auth_options import BasicAuthOptions
from mailslurp_client.models.bounce_projection import BounceProjection
from mailslurp_client.models.bounce_recipient_projection import BounceRecipientProjection
from mailslurp_client.models.bounced_email_dto import BouncedEmailDto
from mailslurp_client.models.bounced_recipient_dto import BouncedRecipientDto
from mailslurp_client.models.bulk_send_email_options import BulkSendEmailOptions
from mailslurp_client.models.campaign_probe_dto import CampaignProbeDto
from mailslurp_client.models.campaign_probe_insights_dto import CampaignProbeInsightsDto
from mailslurp_client.models.campaign_probe_run_comparison_dto import CampaignProbeRunComparisonDto
from mailslurp_client.models.campaign_probe_run_dto import CampaignProbeRunDto
from mailslurp_client.models.campaign_probe_run_due_result import CampaignProbeRunDueResult
from mailslurp_client.models.campaign_probe_run_now_result import CampaignProbeRunNowResult
from mailslurp_client.models.campaign_probe_series_dto import CampaignProbeSeriesDto
from mailslurp_client.models.campaign_probe_series_point_dto import CampaignProbeSeriesPointDto
from mailslurp_client.models.can_send_email_results import CanSendEmailResults
from mailslurp_client.models.cancel_device_preview_run_options import CancelDevicePreviewRunOptions
from mailslurp_client.models.cancel_device_preview_run_result import CancelDevicePreviewRunResult
from mailslurp_client.models.check_campaign_probe_options import CheckCampaignProbeOptions
from mailslurp_client.models.check_campaign_probe_results import CheckCampaignProbeResults
from mailslurp_client.models.check_dns_propagation_options import CheckDnsPropagationOptions
from mailslurp_client.models.check_dns_propagation_results import CheckDnsPropagationResults
from mailslurp_client.models.check_domain_monitor_options import CheckDomainMonitorOptions
from mailslurp_client.models.check_domain_monitor_results import CheckDomainMonitorResults
from mailslurp_client.models.check_email_audit_options import CheckEmailAuditOptions
from mailslurp_client.models.check_email_auth_stack_options import CheckEmailAuthStackOptions
from mailslurp_client.models.check_email_auth_stack_results import CheckEmailAuthStackResults
from mailslurp_client.models.check_email_blacklist_options import CheckEmailBlacklistOptions
from mailslurp_client.models.check_email_blacklist_results import CheckEmailBlacklistResults
from mailslurp_client.models.check_email_body_feature_support_results import CheckEmailBodyFeatureSupportResults
from mailslurp_client.models.check_email_body_results import CheckEmailBodyResults
from mailslurp_client.models.check_email_client_support_options import CheckEmailClientSupportOptions
from mailslurp_client.models.check_email_client_support_results import CheckEmailClientSupportResults
from mailslurp_client.models.check_email_features_client_support_options import CheckEmailFeaturesClientSupportOptions
from mailslurp_client.models.check_email_features_client_support_results import CheckEmailFeaturesClientSupportResults
from mailslurp_client.models.code_candidate import CodeCandidate
from mailslurp_client.models.complaint import Complaint
from mailslurp_client.models.condition_option import ConditionOption
from mailslurp_client.models.conditional_structured_content_result import ConditionalStructuredContentResult
from mailslurp_client.models.connector_dto import ConnectorDto
from mailslurp_client.models.connector_event_dto import ConnectorEventDto
from mailslurp_client.models.connector_event_projection import ConnectorEventProjection
from mailslurp_client.models.connector_imap_connection_dto import ConnectorImapConnectionDto
from mailslurp_client.models.connector_imap_connection_test_result import ConnectorImapConnectionTestResult
from mailslurp_client.models.connector_projection import ConnectorProjection
from mailslurp_client.models.connector_provider_settings_dto import ConnectorProviderSettingsDto
from mailslurp_client.models.connector_smtp_connection_dto import ConnectorSmtpConnectionDto
from mailslurp_client.models.connector_smtp_connection_test_result import ConnectorSmtpConnectionTestResult
from mailslurp_client.models.connector_sync_request_result import ConnectorSyncRequestResult
from mailslurp_client.models.connector_sync_result import ConnectorSyncResult
from mailslurp_client.models.connector_sync_settings_dto import ConnectorSyncSettingsDto
from mailslurp_client.models.consent_status_dto import ConsentStatusDto
from mailslurp_client.models.contact_dto import ContactDto
from mailslurp_client.models.contact_projection import ContactProjection
from mailslurp_client.models.content_match_options import ContentMatchOptions
from mailslurp_client.models.count_dto import CountDto
from mailslurp_client.models.create_ai_transformer_mapping_options import CreateAITransformerMappingOptions
from mailslurp_client.models.create_alias_options import CreateAliasOptions
from mailslurp_client.models.create_campaign_probe_options import CreateCampaignProbeOptions
from mailslurp_client.models.create_campaign_probe_run_options import CreateCampaignProbeRunOptions
from mailslurp_client.models.create_connector_imap_connection_options import CreateConnectorImapConnectionOptions
from mailslurp_client.models.create_connector_options import CreateConnectorOptions
from mailslurp_client.models.create_connector_smtp_connection_options import CreateConnectorSmtpConnectionOptions
from mailslurp_client.models.create_connector_sync_settings_options import CreateConnectorSyncSettingsOptions
from mailslurp_client.models.create_connector_with_options import CreateConnectorWithOptions
from mailslurp_client.models.create_contact_options import CreateContactOptions
from mailslurp_client.models.create_deliverability_simulation_job_options import CreateDeliverabilitySimulationJobOptions
from mailslurp_client.models.create_deliverability_test_options import CreateDeliverabilityTestOptions
from mailslurp_client.models.create_device_preview_feedback_options import CreateDevicePreviewFeedbackOptions
from mailslurp_client.models.create_device_preview_options import CreateDevicePreviewOptions
from mailslurp_client.models.create_device_preview_run_result import CreateDevicePreviewRunResult
from mailslurp_client.models.create_domain_monitor_alert_sink_options import CreateDomainMonitorAlertSinkOptions
from mailslurp_client.models.create_domain_monitor_options import CreateDomainMonitorOptions
from mailslurp_client.models.create_domain_options import CreateDomainOptions
from mailslurp_client.models.create_email_audit_options import CreateEmailAuditOptions
from mailslurp_client.models.create_emergency_address_options import CreateEmergencyAddressOptions
from mailslurp_client.models.create_group_options import CreateGroupOptions
from mailslurp_client.models.create_inbox_dto import CreateInboxDto
from mailslurp_client.models.create_inbox_forwarder_options import CreateInboxForwarderOptions
from mailslurp_client.models.create_inbox_replier_options import CreateInboxReplierOptions
from mailslurp_client.models.create_inbox_retention_policy_for_account_options import CreateInboxRetentionPolicyForAccountOptions
from mailslurp_client.models.create_phone_number_options import CreatePhoneNumberOptions
from mailslurp_client.models.create_phone_pool_options import CreatePhonePoolOptions
from mailslurp_client.models.create_phone_provisioning_job_item_options import CreatePhoneProvisioningJobItemOptions
from mailslurp_client.models.create_phone_provisioning_job_options import CreatePhoneProvisioningJobOptions
from mailslurp_client.models.create_portal_options import CreatePortalOptions
from mailslurp_client.models.create_portal_user_options import CreatePortalUserOptions
from mailslurp_client.models.create_ruleset_options import CreateRulesetOptions
from mailslurp_client.models.create_template_options import CreateTemplateOptions
from mailslurp_client.models.create_totp_device_base32_secret_key_options import CreateTotpDeviceBase32SecretKeyOptions
from mailslurp_client.models.create_totp_device_custom_options import CreateTotpDeviceCustomOptions
from mailslurp_client.models.create_totp_device_otp_auth_url_options import CreateTotpDeviceOtpAuthUrlOptions
from mailslurp_client.models.create_tracking_pixel_options import CreateTrackingPixelOptions
from mailslurp_client.models.create_webhook_options import CreateWebhookOptions
from mailslurp_client.models.dns_lookup_options import DNSLookupOptions
from mailslurp_client.models.dns_lookup_result import DNSLookupResult
from mailslurp_client.models.dns_lookup_results import DNSLookupResults
from mailslurp_client.models.dns_lookups_options import DNSLookupsOptions
from mailslurp_client.models.delete_device_preview_run_result import DeleteDevicePreviewRunResult
from mailslurp_client.models.delete_result import DeleteResult
from mailslurp_client.models.deliverability_analytics_run_dto import DeliverabilityAnalyticsRunDto
from mailslurp_client.models.deliverability_analytics_series_dto import DeliverabilityAnalyticsSeriesDto
from mailslurp_client.models.deliverability_analytics_series_point_dto import DeliverabilityAnalyticsSeriesPointDto
from mailslurp_client.models.deliverability_analytics_summary_dto import DeliverabilityAnalyticsSummaryDto
from mailslurp_client.models.deliverability_entity_result_dto import DeliverabilityEntityResultDto
from mailslurp_client.models.deliverability_entity_result_page_dto import DeliverabilityEntityResultPageDto
from mailslurp_client.models.deliverability_expectation import DeliverabilityExpectation
from mailslurp_client.models.deliverability_expectation_result_dto import DeliverabilityExpectationResultDto
from mailslurp_client.models.deliverability_failure_entity_hotspot_dto import DeliverabilityFailureEntityHotspotDto
from mailslurp_client.models.deliverability_failure_hotspots_dto import DeliverabilityFailureHotspotsDto
from mailslurp_client.models.deliverability_failure_phone_dimension_hotspot_dto import DeliverabilityFailurePhoneDimensionHotspotDto
from mailslurp_client.models.deliverability_poll_status_result_dto import DeliverabilityPollStatusResultDto
from mailslurp_client.models.deliverability_selector_options import DeliverabilitySelectorOptions
from mailslurp_client.models.deliverability_simulation_email_options import DeliverabilitySimulationEmailOptions
from mailslurp_client.models.deliverability_simulation_job_config_dto import DeliverabilitySimulationJobConfigDto
from mailslurp_client.models.deliverability_simulation_job_dto import DeliverabilitySimulationJobDto
from mailslurp_client.models.deliverability_simulation_job_error_summary_dto import DeliverabilitySimulationJobErrorSummaryDto
from mailslurp_client.models.deliverability_simulation_job_event_dto import DeliverabilitySimulationJobEventDto
from mailslurp_client.models.deliverability_simulation_job_event_page_dto import DeliverabilitySimulationJobEventPageDto
from mailslurp_client.models.deliverability_simulation_job_top_error_dto import DeliverabilitySimulationJobTopErrorDto
from mailslurp_client.models.deliverability_simulation_sms_options import DeliverabilitySimulationSmsOptions
from mailslurp_client.models.deliverability_test_dto import DeliverabilityTestDto
from mailslurp_client.models.deliverability_test_page_dto import DeliverabilityTestPageDto
from mailslurp_client.models.delivery_status_dto import DeliveryStatusDto
from mailslurp_client.models.describe_domain_options import DescribeDomainOptions
from mailslurp_client.models.describe_mail_server_domain_result import DescribeMailServerDomainResult
from mailslurp_client.models.device_preview_feedback_dto import DevicePreviewFeedbackDto
from mailslurp_client.models.device_preview_feedback_list_dto import DevicePreviewFeedbackListDto
from mailslurp_client.models.device_preview_provider_progress_dto import DevicePreviewProviderProgressDto
from mailslurp_client.models.device_preview_run_dto import DevicePreviewRunDto
from mailslurp_client.models.device_preview_run_results_dto import DevicePreviewRunResultsDto
from mailslurp_client.models.device_preview_screenshot_dto import DevicePreviewScreenshotDto
from mailslurp_client.models.device_preview_target_dto import DevicePreviewTargetDto
from mailslurp_client.models.dmarc_report_metadata import DmarcReportMetadata
from mailslurp_client.models.dmarc_report_source_summary import DmarcReportSourceSummary
from mailslurp_client.models.dns_propagation_resolver_result import DnsPropagationResolverResult
from mailslurp_client.models.domain_dto import DomainDto
from mailslurp_client.models.domain_group import DomainGroup
from mailslurp_client.models.domain_groups_dto import DomainGroupsDto
from mailslurp_client.models.domain_information import DomainInformation
from mailslurp_client.models.domain_issues_dto import DomainIssuesDto
from mailslurp_client.models.domain_monitor_alert_sink_dto import DomainMonitorAlertSinkDto
from mailslurp_client.models.domain_monitor_dto import DomainMonitorDto
from mailslurp_client.models.domain_monitor_insights_dto import DomainMonitorInsightsDto
from mailslurp_client.models.domain_monitor_run_comparison_dto import DomainMonitorRunComparisonDto
from mailslurp_client.models.domain_monitor_run_dto import DomainMonitorRunDto
from mailslurp_client.models.domain_monitor_run_due_result import DomainMonitorRunDueResult
from mailslurp_client.models.domain_monitor_run_now_result import DomainMonitorRunNowResult
from mailslurp_client.models.domain_monitor_series_dto import DomainMonitorSeriesDto
from mailslurp_client.models.domain_monitor_series_point_dto import DomainMonitorSeriesPointDto
from mailslurp_client.models.domain_monitor_summary_dto import DomainMonitorSummaryDto
from mailslurp_client.models.domain_name_record import DomainNameRecord
from mailslurp_client.models.domain_preview import DomainPreview
from mailslurp_client.models.domain_region_group import DomainRegionGroup
from mailslurp_client.models.domain_region_groups_dto import DomainRegionGroupsDto
from mailslurp_client.models.domain_region_information import DomainRegionInformation
from mailslurp_client.models.download_attachment_dto import DownloadAttachmentDto
from mailslurp_client.models.email import Email
from mailslurp_client.models.email_analysis import EmailAnalysis
from mailslurp_client.models.email_audit_analysis_result import EmailAuditAnalysisResult
from mailslurp_client.models.email_audit_comparison_dto import EmailAuditComparisonDto
from mailslurp_client.models.email_audit_dto import EmailAuditDto
from mailslurp_client.models.email_audit_spelling_issue import EmailAuditSpellingIssue
from mailslurp_client.models.email_audit_url_issue import EmailAuditUrlIssue
from mailslurp_client.models.email_available_result import EmailAvailableResult
from mailslurp_client.models.email_blacklist_ip_result import EmailBlacklistIpResult
from mailslurp_client.models.email_blacklist_listing_result import EmailBlacklistListingResult
from mailslurp_client.models.email_content_match_result import EmailContentMatchResult
from mailslurp_client.models.email_content_part_result import EmailContentPartResult
from mailslurp_client.models.email_feature_category_name import EmailFeatureCategoryName
from mailslurp_client.models.email_feature_family_name import EmailFeatureFamilyName
from mailslurp_client.models.email_feature_family_statistics import EmailFeatureFamilyStatistics
from mailslurp_client.models.email_feature_names import EmailFeatureNames
from mailslurp_client.models.email_feature_overview import EmailFeatureOverview
from mailslurp_client.models.email_feature_platform_name import EmailFeaturePlatformName
from mailslurp_client.models.email_feature_platform_statistics import EmailFeaturePlatformStatistics
from mailslurp_client.models.email_feature_support_flags import EmailFeatureSupportFlags
from mailslurp_client.models.email_feature_support_result import EmailFeatureSupportResult
from mailslurp_client.models.email_feature_support_status_percentage import EmailFeatureSupportStatusPercentage
from mailslurp_client.models.email_feature_version_statistics import EmailFeatureVersionStatistics
from mailslurp_client.models.email_header_analysis_summary import EmailHeaderAnalysisSummary
from mailslurp_client.models.email_header_received_hop import EmailHeaderReceivedHop
from mailslurp_client.models.email_html_dto import EmailHtmlDto
from mailslurp_client.models.email_intelligence_list_result import EmailIntelligenceListResult
from mailslurp_client.models.email_intelligence_options import EmailIntelligenceOptions
from mailslurp_client.models.email_intelligence_result_dto import EmailIntelligenceResultDto
from mailslurp_client.models.email_intelligence_score_breakdown_dto import EmailIntelligenceScoreBreakdownDto
from mailslurp_client.models.email_intelligence_signals_dto import EmailIntelligenceSignalsDto
from mailslurp_client.models.email_intelligence_tests_options import EmailIntelligenceTestsOptions
from mailslurp_client.models.email_links_result import EmailLinksResult
from mailslurp_client.models.email_preview import EmailPreview
from mailslurp_client.models.email_preview_urls import EmailPreviewUrls
from mailslurp_client.models.email_projection import EmailProjection
from mailslurp_client.models.email_recipients import EmailRecipients
from mailslurp_client.models.email_recipients_projection import EmailRecipientsProjection
from mailslurp_client.models.email_screenshot_result import EmailScreenshotResult
from mailslurp_client.models.email_signature import EmailSignature
from mailslurp_client.models.email_signature_parse_result import EmailSignatureParseResult
from mailslurp_client.models.email_text_lines_result import EmailTextLinesResult
from mailslurp_client.models.email_thread_dto import EmailThreadDto
from mailslurp_client.models.email_thread_item import EmailThreadItem
from mailslurp_client.models.email_thread_items_dto import EmailThreadItemsDto
from mailslurp_client.models.email_thread_projection import EmailThreadProjection
from mailslurp_client.models.email_validation_request_dto import EmailValidationRequestDto
from mailslurp_client.models.email_verification_result import EmailVerificationResult
from mailslurp_client.models.emergency_address import EmergencyAddress
from mailslurp_client.models.emergency_address_dto import EmergencyAddressDto
from mailslurp_client.models.empty_response_dto import EmptyResponseDto
from mailslurp_client.models.entity_automation_item_projection import EntityAutomationItemProjection
from mailslurp_client.models.entity_event_item_projection import EntityEventItemProjection
from mailslurp_client.models.entity_favourite_item_projection import EntityFavouriteItemProjection
from mailslurp_client.models.expiration_defaults import ExpirationDefaults
from mailslurp_client.models.expired_inbox_dto import ExpiredInboxDto
from mailslurp_client.models.expired_inbox_record_projection import ExpiredInboxRecordProjection
from mailslurp_client.models.export_link import ExportLink
from mailslurp_client.models.export_options import ExportOptions
from mailslurp_client.models.export_transformer_options import ExportTransformerOptions
from mailslurp_client.models.export_transformer_response import ExportTransformerResponse
from mailslurp_client.models.export_transformer_result_job_dto import ExportTransformerResultJobDto
from mailslurp_client.models.extract_attachment_text_options import ExtractAttachmentTextOptions
from mailslurp_client.models.extract_attachment_text_result import ExtractAttachmentTextResult
from mailslurp_client.models.extract_codes_options import ExtractCodesOptions
from mailslurp_client.models.extract_codes_result import ExtractCodesResult
from mailslurp_client.models.fake_email_dto import FakeEmailDto
from mailslurp_client.models.fake_email_preview import FakeEmailPreview
from mailslurp_client.models.fake_email_result import FakeEmailResult
from mailslurp_client.models.filter_bounced_recipients_options import FilterBouncedRecipientsOptions
from mailslurp_client.models.filter_bounced_recipients_result import FilterBouncedRecipientsResult
from mailslurp_client.models.flush_expired_inboxes_result import FlushExpiredInboxesResult
from mailslurp_client.models.forward_email_options import ForwardEmailOptions
from mailslurp_client.models.generate_bimi_record_options import GenerateBimiRecordOptions
from mailslurp_client.models.generate_bimi_record_results import GenerateBimiRecordResults
from mailslurp_client.models.generate_dmarc_record_options import GenerateDmarcRecordOptions
from mailslurp_client.models.generate_dmarc_record_results import GenerateDmarcRecordResults
from mailslurp_client.models.generate_mta_sts_record_options import GenerateMtaStsRecordOptions
from mailslurp_client.models.generate_mta_sts_record_results import GenerateMtaStsRecordResults
from mailslurp_client.models.generate_spf_record_options import GenerateSpfRecordOptions
from mailslurp_client.models.generate_spf_record_results import GenerateSpfRecordResults
from mailslurp_client.models.generate_structured_content_attachment_options import GenerateStructuredContentAttachmentOptions
from mailslurp_client.models.generate_structured_content_email_options import GenerateStructuredContentEmailOptions
from mailslurp_client.models.generate_structured_content_sms_options import GenerateStructuredContentSmsOptions
from mailslurp_client.models.generate_tls_reporting_record_options import GenerateTlsReportingRecordOptions
from mailslurp_client.models.generate_tls_reporting_record_results import GenerateTlsReportingRecordResults
from mailslurp_client.models.get_email_screenshot_options import GetEmailScreenshotOptions
from mailslurp_client.models.get_or_create_phone_pool_options import GetOrCreatePhonePoolOptions
from mailslurp_client.models.gravatar_url import GravatarUrl
from mailslurp_client.models.group_contacts_dto import GroupContactsDto
from mailslurp_client.models.group_dto import GroupDto
from mailslurp_client.models.group_projection import GroupProjection
from mailslurp_client.models.guest_portal_dto import GuestPortalDto
from mailslurp_client.models.guest_portal_user_create_dto import GuestPortalUserCreateDto
from mailslurp_client.models.guest_portal_user_dto import GuestPortalUserDto
from mailslurp_client.models.guest_portal_user_projection import GuestPortalUserProjection
from mailslurp_client.models.html_validation_result import HTMLValidationResult
from mailslurp_client.models.ip_address_result import IPAddressResult
from mailslurp_client.models.image_issue import ImageIssue
from mailslurp_client.models.imap_access_details import ImapAccessDetails
from mailslurp_client.models.imap_email_projection import ImapEmailProjection
from mailslurp_client.models.imap_flag_operation_options import ImapFlagOperationOptions
from mailslurp_client.models.imap_mailbox_status import ImapMailboxStatus
from mailslurp_client.models.imap_server_fetch_item import ImapServerFetchItem
from mailslurp_client.models.imap_server_fetch_result import ImapServerFetchResult
from mailslurp_client.models.imap_server_get_result import ImapServerGetResult
from mailslurp_client.models.imap_server_list_options import ImapServerListOptions
from mailslurp_client.models.imap_server_list_result import ImapServerListResult
from mailslurp_client.models.imap_server_mailbox_result import ImapServerMailboxResult
from mailslurp_client.models.imap_server_search_options import ImapServerSearchOptions
from mailslurp_client.models.imap_server_search_result import ImapServerSearchResult
from mailslurp_client.models.imap_server_status_options import ImapServerStatusOptions
from mailslurp_client.models.imap_server_status_result import ImapServerStatusResult
from mailslurp_client.models.imap_smtp_access_details import ImapSmtpAccessDetails
from mailslurp_client.models.imap_smtp_access_servers import ImapSmtpAccessServers
from mailslurp_client.models.imap_update_flags_options import ImapUpdateFlagsOptions
from mailslurp_client.models.import_email_options import ImportEmailOptions
from mailslurp_client.models.inbox_automation_match_option import InboxAutomationMatchOption
from mailslurp_client.models.inbox_automation_match_options import InboxAutomationMatchOptions
from mailslurp_client.models.inbox_by_email_address_result import InboxByEmailAddressResult
from mailslurp_client.models.inbox_by_name_result import InboxByNameResult
from mailslurp_client.models.inbox_dto import InboxDto
from mailslurp_client.models.inbox_exists_dto import InboxExistsDto
from mailslurp_client.models.inbox_forwarder_dto import InboxForwarderDto
from mailslurp_client.models.inbox_forwarder_event_dto import InboxForwarderEventDto
from mailslurp_client.models.inbox_forwarder_event_projection import InboxForwarderEventProjection
from mailslurp_client.models.inbox_forwarder_test_options import InboxForwarderTestOptions
from mailslurp_client.models.inbox_forwarder_test_result import InboxForwarderTestResult
from mailslurp_client.models.inbox_id_item import InboxIdItem
from mailslurp_client.models.inbox_ids_result import InboxIdsResult
from mailslurp_client.models.inbox_preview import InboxPreview
from mailslurp_client.models.inbox_replier_dto import InboxReplierDto
from mailslurp_client.models.inbox_replier_event_projection import InboxReplierEventProjection
from mailslurp_client.models.inbox_retention_policy_dto import InboxRetentionPolicyDto
from mailslurp_client.models.inbox_retention_policy_optional_dto import InboxRetentionPolicyOptionalDto
from mailslurp_client.models.inbox_ruleset_test_result import InboxRulesetTestResult
from mailslurp_client.models.inline_object import InlineObject
from mailslurp_client.models.inline_object1 import InlineObject1
from mailslurp_client.models.inline_object2 import InlineObject2
from mailslurp_client.models.invoke_transformer_options import InvokeTransformerOptions
from mailslurp_client.models.json_schema_dto import JSONSchemaDto
from mailslurp_client.models.link_issue import LinkIssue
from mailslurp_client.models.list_unsubscribe_recipient_projection import ListUnsubscribeRecipientProjection
from mailslurp_client.models.lookup_bimi_domain_options import LookupBimiDomainOptions
from mailslurp_client.models.lookup_bimi_domain_results import LookupBimiDomainResults
from mailslurp_client.models.lookup_dkim_domain_options import LookupDkimDomainOptions
from mailslurp_client.models.lookup_dkim_domain_results import LookupDkimDomainResults
from mailslurp_client.models.lookup_dmarc_domain_options import LookupDmarcDomainOptions
from mailslurp_client.models.lookup_dmarc_domain_results import LookupDmarcDomainResults
from mailslurp_client.models.lookup_mta_sts_domain_options import LookupMtaStsDomainOptions
from mailslurp_client.models.lookup_mta_sts_domain_results import LookupMtaStsDomainResults
from mailslurp_client.models.lookup_mx_records_options import LookupMxRecordsOptions
from mailslurp_client.models.lookup_mx_records_results import LookupMxRecordsResults
from mailslurp_client.models.lookup_ptr_options import LookupPtrOptions
from mailslurp_client.models.lookup_ptr_results import LookupPtrResults
from mailslurp_client.models.lookup_spf_domain_options import LookupSpfDomainOptions
from mailslurp_client.models.lookup_spf_domain_results import LookupSpfDomainResults
from mailslurp_client.models.lookup_tls_reporting_domain_options import LookupTlsReportingDomainOptions
from mailslurp_client.models.lookup_tls_reporting_domain_results import LookupTlsReportingDomainResults
from mailslurp_client.models.match_option import MatchOption
from mailslurp_client.models.match_options import MatchOptions
from mailslurp_client.models.missed_email_dto import MissedEmailDto
from mailslurp_client.models.missed_email_projection import MissedEmailProjection
from mailslurp_client.models.missed_sms_dto import MissedSmsDto
from mailslurp_client.models.missed_sms_projection import MissedSmsProjection
from mailslurp_client.models.name_server_record import NameServerRecord
from mailslurp_client.models.new_fake_email_address_result import NewFakeEmailAddressResult
from mailslurp_client.models.opt_in_consent_options import OptInConsentOptions
from mailslurp_client.models.opt_in_consent_send_result import OptInConsentSendResult
from mailslurp_client.models.opt_in_identity_projection import OptInIdentityProjection
from mailslurp_client.models.opt_in_sending_consent_dto import OptInSendingConsentDto
from mailslurp_client.models.optional_connector_dto import OptionalConnectorDto
from mailslurp_client.models.optional_connector_imap_connection_dto import OptionalConnectorImapConnectionDto
from mailslurp_client.models.optional_connector_smtp_connection_dto import OptionalConnectorSmtpConnectionDto
from mailslurp_client.models.optional_connector_sync_settings_dto import OptionalConnectorSyncSettingsDto
from mailslurp_client.models.organization_inbox_projection import OrganizationInboxProjection
from mailslurp_client.models.page_ai_transform_mapping_projection import PageAITransformMappingProjection
from mailslurp_client.models.page_ai_transform_projection import PageAITransformProjection
from mailslurp_client.models.page_ai_transform_result_projection import PageAITransformResultProjection
from mailslurp_client.models.page_alias import PageAlias
from mailslurp_client.models.page_alias_thread_projection import PageAliasThreadProjection
from mailslurp_client.models.page_attachment_entity import PageAttachmentEntity
from mailslurp_client.models.page_bounced_email import PageBouncedEmail
from mailslurp_client.models.page_bounced_recipients import PageBouncedRecipients
from mailslurp_client.models.page_complaint import PageComplaint
from mailslurp_client.models.page_connector import PageConnector
from mailslurp_client.models.page_connector_events import PageConnectorEvents
from mailslurp_client.models.page_contact_projection import PageContactProjection
from mailslurp_client.models.page_delivery_status import PageDeliveryStatus
from mailslurp_client.models.page_device_preview_run_projection import PageDevicePreviewRunProjection
from mailslurp_client.models.page_email_preview import PageEmailPreview
from mailslurp_client.models.page_email_projection import PageEmailProjection
from mailslurp_client.models.page_email_thread_projection import PageEmailThreadProjection
from mailslurp_client.models.page_email_validation_request import PageEmailValidationRequest
from mailslurp_client.models.page_entity_automation_items import PageEntityAutomationItems
from mailslurp_client.models.page_entity_event_items import PageEntityEventItems
from mailslurp_client.models.page_entity_favourite_items import PageEntityFavouriteItems
from mailslurp_client.models.page_expired_inbox_record_projection import PageExpiredInboxRecordProjection
from mailslurp_client.models.page_group_projection import PageGroupProjection
from mailslurp_client.models.page_guest_portal_users import PageGuestPortalUsers
from mailslurp_client.models.page_inbox_forwarder_dto import PageInboxForwarderDto
from mailslurp_client.models.page_inbox_forwarder_events import PageInboxForwarderEvents
from mailslurp_client.models.page_inbox_projection import PageInboxProjection
from mailslurp_client.models.page_inbox_replier_dto import PageInboxReplierDto
from mailslurp_client.models.page_inbox_replier_events import PageInboxReplierEvents
from mailslurp_client.models.page_inbox_tags import PageInboxTags
from mailslurp_client.models.page_list_unsubscribe_recipients import PageListUnsubscribeRecipients
from mailslurp_client.models.page_missed_email_projection import PageMissedEmailProjection
from mailslurp_client.models.page_missed_sms_projection import PageMissedSmsProjection
from mailslurp_client.models.page_opt_in_identity_projection import PageOptInIdentityProjection
from mailslurp_client.models.page_organization_inbox_projection import PageOrganizationInboxProjection
from mailslurp_client.models.page_phone_message_thread_item_projection import PagePhoneMessageThreadItemProjection
from mailslurp_client.models.page_phone_message_thread_projection import PagePhoneMessageThreadProjection
from mailslurp_client.models.page_phone_number_projection import PagePhoneNumberProjection
from mailslurp_client.models.page_phone_number_release_projection import PagePhoneNumberReleaseProjection
from mailslurp_client.models.page_plus_address_projection import PagePlusAddressProjection
from mailslurp_client.models.page_reputation_items import PageReputationItems
from mailslurp_client.models.page_ruleset_dto import PageRulesetDto
from mailslurp_client.models.page_scheduled_jobs import PageScheduledJobs
from mailslurp_client.models.page_sent_email_projection import PageSentEmailProjection
from mailslurp_client.models.page_sent_email_with_queue_projection import PageSentEmailWithQueueProjection
from mailslurp_client.models.page_sent_sms_projection import PageSentSmsProjection
from mailslurp_client.models.page_sms_projection import PageSmsProjection
from mailslurp_client.models.page_table_data import PageTableData
from mailslurp_client.models.page_template_projection import PageTemplateProjection
from mailslurp_client.models.page_tracking_pixel_projection import PageTrackingPixelProjection
from mailslurp_client.models.page_unknown_missed_email_projection import PageUnknownMissedEmailProjection
from mailslurp_client.models.page_webhook_endpoint_projection import PageWebhookEndpointProjection
from mailslurp_client.models.page_webhook_projection import PageWebhookProjection
from mailslurp_client.models.page_webhook_result import PageWebhookResult
from mailslurp_client.models.pageable_object import PageableObject
from mailslurp_client.models.pagination import Pagination
from mailslurp_client.models.phone_message_thread_item_projection import PhoneMessageThreadItemProjection
from mailslurp_client.models.phone_message_thread_projection import PhoneMessageThreadProjection
from mailslurp_client.models.phone_number_dto import PhoneNumberDto
from mailslurp_client.models.phone_number_line_type_intelligence_dto import PhoneNumberLineTypeIntelligenceDto
from mailslurp_client.models.phone_number_line_type_lookup_dto import PhoneNumberLineTypeLookupDto
from mailslurp_client.models.phone_number_projection import PhoneNumberProjection
from mailslurp_client.models.phone_number_release_projection import PhoneNumberReleaseProjection
from mailslurp_client.models.phone_number_tags_options import PhoneNumberTagsOptions
from mailslurp_client.models.phone_number_validation_dto import PhoneNumberValidationDto
from mailslurp_client.models.phone_plan_availability import PhonePlanAvailability
from mailslurp_client.models.phone_plan_availability_item import PhonePlanAvailabilityItem
from mailslurp_client.models.phone_plan_dto import PhonePlanDto
from mailslurp_client.models.phone_pool_detail_dto import PhonePoolDetailDto
from mailslurp_client.models.phone_pool_dto import PhonePoolDto
from mailslurp_client.models.phone_pool_lease_dto import PhonePoolLeaseDto
from mailslurp_client.models.phone_pool_member_dto import PhonePoolMemberDto
from mailslurp_client.models.phone_provider_capabilities_result import PhoneProviderCapabilitiesResult
from mailslurp_client.models.phone_provisioning_job_dto import PhoneProvisioningJobDto
from mailslurp_client.models.phone_provisioning_job_item_dto import PhoneProvisioningJobItemDto
from mailslurp_client.models.phone_sms_prepaid_credit_dto import PhoneSmsPrepaidCreditDto
from mailslurp_client.models.phone_sms_prepaid_credits_dto import PhoneSmsPrepaidCreditsDto
from mailslurp_client.models.phone_summary_country_dto import PhoneSummaryCountryDto
from mailslurp_client.models.phone_summary_dto import PhoneSummaryDto
from mailslurp_client.models.plan_summary_dto import PlanSummaryDto
from mailslurp_client.models.plus_address_dto import PlusAddressDto
from mailslurp_client.models.plus_address_projection import PlusAddressProjection
from mailslurp_client.models.provider_settings import ProviderSettings
from mailslurp_client.models.raw_email_json import RawEmailJson
from mailslurp_client.models.recipient import Recipient
from mailslurp_client.models.recipient_projection import RecipientProjection
from mailslurp_client.models.reply_for_sms import ReplyForSms
from mailslurp_client.models.reply_to_alias_email_options import ReplyToAliasEmailOptions
from mailslurp_client.models.reply_to_email_options import ReplyToEmailOptions
from mailslurp_client.models.reputation_item_projection import ReputationItemProjection
from mailslurp_client.models.ruleset_dto import RulesetDto
from mailslurp_client.models.ruleset_test_options import RulesetTestOptions
from mailslurp_client.models.scheduled_job import ScheduledJob
from mailslurp_client.models.scheduled_job_dto import ScheduledJobDto
from mailslurp_client.models.search_available_phone_numbers_options import SearchAvailablePhoneNumbersOptions
from mailslurp_client.models.search_emails_options import SearchEmailsOptions
from mailslurp_client.models.search_inboxes_options import SearchInboxesOptions
from mailslurp_client.models.send_email_body_part import SendEmailBodyPart
from mailslurp_client.models.send_email_options import SendEmailOptions
from mailslurp_client.models.send_opt_in_consent_email_options import SendOptInConsentEmailOptions
from mailslurp_client.models.send_smtp_envelope_options import SendSMTPEnvelopeOptions
from mailslurp_client.models.send_with_queue_result import SendWithQueueResult
from mailslurp_client.models.sender import Sender
from mailslurp_client.models.sender_projection import SenderProjection
from mailslurp_client.models.sent_email_dto import SentEmailDto
from mailslurp_client.models.sent_email_projection import SentEmailProjection
from mailslurp_client.models.sent_sms_dto import SentSmsDto
from mailslurp_client.models.sent_sms_projection import SentSmsProjection
from mailslurp_client.models.server_endpoints import ServerEndpoints
from mailslurp_client.models.set_inbox_favourited_options import SetInboxFavouritedOptions
from mailslurp_client.models.set_phone_favourited_options import SetPhoneFavouritedOptions
from mailslurp_client.models.simple_send_email_options import SimpleSendEmailOptions
from mailslurp_client.models.sms_dto import SmsDto
from mailslurp_client.models.sms_match_option import SmsMatchOption
from mailslurp_client.models.sms_preview import SmsPreview
from mailslurp_client.models.sms_projection import SmsProjection
from mailslurp_client.models.sms_reply_options import SmsReplyOptions
from mailslurp_client.models.sms_send_options import SmsSendOptions
from mailslurp_client.models.smtp_access_details import SmtpAccessDetails
from mailslurp_client.models.smtp_auth_diagnostic_result import SmtpAuthDiagnosticResult
from mailslurp_client.models.smtp_diagnostic_step import SmtpDiagnosticStep
from mailslurp_client.models.smtp_tls_diagnostic_result import SmtpTlsDiagnosticResult
from mailslurp_client.models.sort_object import SortObject
from mailslurp_client.models.spelling_issue import SpellingIssue
from mailslurp_client.models.spf_mechanism_result import SpfMechanismResult
from mailslurp_client.models.structured_content_result_dto import StructuredContentResultDto
from mailslurp_client.models.structured_output_schema import StructuredOutputSchema
from mailslurp_client.models.structured_output_schema_validation import StructuredOutputSchemaValidation
from mailslurp_client.models.template_dto import TemplateDto
from mailslurp_client.models.template_preview import TemplatePreview
from mailslurp_client.models.template_projection import TemplateProjection
from mailslurp_client.models.template_variable import TemplateVariable
from mailslurp_client.models.tenant_reputation_finding_dto import TenantReputationFindingDto
from mailslurp_client.models.tenant_reputation_findings_dto import TenantReputationFindingsDto
from mailslurp_client.models.tenant_reputation_status_row_dto import TenantReputationStatusRowDto
from mailslurp_client.models.tenant_reputation_status_summary_dto import TenantReputationStatusSummaryDto
from mailslurp_client.models.test_inbox_ruleset_sending_options import TestInboxRulesetSendingOptions
from mailslurp_client.models.test_new_inbox_forwarder_options import TestNewInboxForwarderOptions
from mailslurp_client.models.test_new_inbox_ruleset_options import TestNewInboxRulesetOptions
from mailslurp_client.models.test_phone_number_options import TestPhoneNumberOptions
from mailslurp_client.models.test_ruleset_receiving_options import TestRulesetReceivingOptions
from mailslurp_client.models.test_ruleset_receiving_result import TestRulesetReceivingResult
from mailslurp_client.models.test_ruleset_sending_result import TestRulesetSendingResult
from mailslurp_client.models.test_smtp_server_options import TestSmtpServerOptions
from mailslurp_client.models.test_smtp_server_results import TestSmtpServerResults
from mailslurp_client.models.totp_device_code_dto import TotpDeviceCodeDto
from mailslurp_client.models.totp_device_dto import TotpDeviceDto
from mailslurp_client.models.totp_device_optional_dto import TotpDeviceOptionalDto
from mailslurp_client.models.tracking_pixel_dto import TrackingPixelDto
from mailslurp_client.models.tracking_pixel_projection import TrackingPixelProjection
from mailslurp_client.models.unknown_missed_email_projection import UnknownMissedEmailProjection
from mailslurp_client.models.unread_count import UnreadCount
from mailslurp_client.models.unseen_error_count_dto import UnseenErrorCountDto
from mailslurp_client.models.update_alias_options import UpdateAliasOptions
from mailslurp_client.models.update_campaign_probe_options import UpdateCampaignProbeOptions
from mailslurp_client.models.update_deliverability_test_options import UpdateDeliverabilityTestOptions
from mailslurp_client.models.update_device_preview_feedback_options import UpdateDevicePreviewFeedbackOptions
from mailslurp_client.models.update_domain_monitor_options import UpdateDomainMonitorOptions
from mailslurp_client.models.update_domain_options import UpdateDomainOptions
from mailslurp_client.models.update_group_contacts import UpdateGroupContacts
from mailslurp_client.models.update_imap_access_options import UpdateImapAccessOptions
from mailslurp_client.models.update_inbox_options import UpdateInboxOptions
from mailslurp_client.models.update_inbox_replier_options import UpdateInboxReplierOptions
from mailslurp_client.models.update_phone_number_options import UpdatePhoneNumberOptions
from mailslurp_client.models.update_phone_pool_options import UpdatePhonePoolOptions
from mailslurp_client.models.update_smtp_access_options import UpdateSmtpAccessOptions
from mailslurp_client.models.upload_attachment_options import UploadAttachmentOptions
from mailslurp_client.models.user_info_dto import UserInfoDto
from mailslurp_client.models.validate_email_address_list_options import ValidateEmailAddressListOptions
from mailslurp_client.models.validate_email_address_list_result import ValidateEmailAddressListResult
from mailslurp_client.models.validate_phone_number_options import ValidatePhoneNumberOptions
from mailslurp_client.models.validation_dto import ValidationDto
from mailslurp_client.models.validation_message import ValidationMessage
from mailslurp_client.models.verify_email_address_options import VerifyEmailAddressOptions
from mailslurp_client.models.verify_webhook_signature_options import VerifyWebhookSignatureOptions
from mailslurp_client.models.verify_webhook_signature_results import VerifyWebhookSignatureResults
from mailslurp_client.models.wait_for_conditions import WaitForConditions
from mailslurp_client.models.wait_for_single_sms_options import WaitForSingleSmsOptions
from mailslurp_client.models.wait_for_sms_conditions import WaitForSmsConditions
from mailslurp_client.models.webhook_bounce_payload import WebhookBouncePayload
from mailslurp_client.models.webhook_bounce_recipient_payload import WebhookBounceRecipientPayload
from mailslurp_client.models.webhook_delivery_status_payload import WebhookDeliveryStatusPayload
from mailslurp_client.models.webhook_dto import WebhookDto
from mailslurp_client.models.webhook_email_opened_payload import WebhookEmailOpenedPayload
from mailslurp_client.models.webhook_email_read_payload import WebhookEmailReadPayload
from mailslurp_client.models.webhook_endpoint_projection import WebhookEndpointProjection
from mailslurp_client.models.webhook_header_name_value import WebhookHeaderNameValue
from mailslurp_client.models.webhook_headers import WebhookHeaders
from mailslurp_client.models.webhook_new_ai_transform_result_payload import WebhookNewAITransformResultPayload
from mailslurp_client.models.webhook_new_attachment_payload import WebhookNewAttachmentPayload
from mailslurp_client.models.webhook_new_contact_payload import WebhookNewContactPayload
from mailslurp_client.models.webhook_new_email_payload import WebhookNewEmailPayload
from mailslurp_client.models.webhook_new_sms_payload import WebhookNewSmsPayload
from mailslurp_client.models.webhook_projection import WebhookProjection
from mailslurp_client.models.webhook_redrive_all_result import WebhookRedriveAllResult
from mailslurp_client.models.webhook_redrive_result import WebhookRedriveResult
from mailslurp_client.models.webhook_result_dto import WebhookResultDto
from mailslurp_client.models.webhook_test_request import WebhookTestRequest
from mailslurp_client.models.webhook_test_response import WebhookTestResponse
from mailslurp_client.models.webhook_test_result import WebhookTestResult
