# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.ruleset_controller_api import RulesetControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestRulesetControllerApi(unittest.TestCase):
    """RulesetControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.ruleset_controller_api.RulesetControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_new_ruleset(self):
        """Test case for create_new_ruleset

        Create a ruleset  # noqa: E501
        """
        pass

    def test_delete_ruleset(self):
        """Test case for delete_ruleset

        Delete a ruleset  # noqa: E501
        """
        pass

    def test_delete_rulesets(self):
        """Test case for delete_rulesets

        Delete rulesets  # noqa: E501
        """
        pass

    def test_get_ruleset(self):
        """Test case for get_ruleset

        Get a ruleset  # noqa: E501
        """
        pass

    def test_get_rulesets(self):
        """Test case for get_rulesets

        List rulesets block and allow lists  # noqa: E501
        """
        pass

    def test_test_inbox_rulesets_for_inbox(self):
        """Test case for test_inbox_rulesets_for_inbox

        Test inbox rulesets for inbox  # noqa: E501
        """
        pass

    def test_test_new_ruleset(self):
        """Test case for test_new_ruleset

        Test new ruleset  # noqa: E501
        """
        pass

    def test_test_ruleset(self):
        """Test case for test_ruleset

        Test a ruleset  # noqa: E501
        """
        pass

    def test_test_ruleset_receiving(self):
        """Test case for test_ruleset_receiving

        Test receiving with rulesets  # noqa: E501
        """
        pass

    def test_test_ruleset_sending(self):
        """Test case for test_ruleset_sending

        Test sending with rulesets  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
