# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailHeaderReceivedHop(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_from': 'str',
        'by': 'str',
        'with_value': 'str',
        'timestamp': 'str',
        'delay_ms': 'int'
    }

    attribute_map = {
        '_from': 'from',
        'by': 'by',
        'with_value': 'withValue',
        'timestamp': 'timestamp',
        'delay_ms': 'delayMs'
    }

    def __init__(self, _from=None, by=None, with_value=None, timestamp=None, delay_ms=None, local_vars_configuration=None):  # noqa: E501
        """EmailHeaderReceivedHop - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.__from = None
        self._by = None
        self._with_value = None
        self._timestamp = None
        self._delay_ms = None
        self.discriminator = None

        if _from is not None:
            self._from = _from
        if by is not None:
            self.by = by
        if with_value is not None:
            self.with_value = with_value
        if timestamp is not None:
            self.timestamp = timestamp
        if delay_ms is not None:
            self.delay_ms = delay_ms

    @property
    def _from(self):
        """Gets the _from of this EmailHeaderReceivedHop.  # noqa: E501


        :return: The _from of this EmailHeaderReceivedHop.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmailHeaderReceivedHop.


        :param _from: The _from of this EmailHeaderReceivedHop.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def by(self):
        """Gets the by of this EmailHeaderReceivedHop.  # noqa: E501


        :return: The by of this EmailHeaderReceivedHop.  # noqa: E501
        :rtype: str
        """
        return self._by

    @by.setter
    def by(self, by):
        """Sets the by of this EmailHeaderReceivedHop.


        :param by: The by of this EmailHeaderReceivedHop.  # noqa: E501
        :type: str
        """

        self._by = by

    @property
    def with_value(self):
        """Gets the with_value of this EmailHeaderReceivedHop.  # noqa: E501


        :return: The with_value of this EmailHeaderReceivedHop.  # noqa: E501
        :rtype: str
        """
        return self._with_value

    @with_value.setter
    def with_value(self, with_value):
        """Sets the with_value of this EmailHeaderReceivedHop.


        :param with_value: The with_value of this EmailHeaderReceivedHop.  # noqa: E501
        :type: str
        """

        self._with_value = with_value

    @property
    def timestamp(self):
        """Gets the timestamp of this EmailHeaderReceivedHop.  # noqa: E501


        :return: The timestamp of this EmailHeaderReceivedHop.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this EmailHeaderReceivedHop.


        :param timestamp: The timestamp of this EmailHeaderReceivedHop.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def delay_ms(self):
        """Gets the delay_ms of this EmailHeaderReceivedHop.  # noqa: E501


        :return: The delay_ms of this EmailHeaderReceivedHop.  # noqa: E501
        :rtype: int
        """
        return self._delay_ms

    @delay_ms.setter
    def delay_ms(self, delay_ms):
        """Sets the delay_ms of this EmailHeaderReceivedHop.


        :param delay_ms: The delay_ms of this EmailHeaderReceivedHop.  # noqa: E501
        :type: int
        """

        self._delay_ms = delay_ms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailHeaderReceivedHop):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailHeaderReceivedHop):
            return True

        return self.to_dict() != other.to_dict()
