# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateDeliverabilitySimulationJobOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sender_inbox_id': 'str',
        'sender_phone_id': 'str',
        'email': 'DeliverabilitySimulationEmailOptions',
        'sms': 'DeliverabilitySimulationSmsOptions',
        'delay_ms': 'int',
        'batch_size': 'int',
        'sends_per_target': 'int'
    }

    attribute_map = {
        'sender_inbox_id': 'senderInboxId',
        'sender_phone_id': 'senderPhoneId',
        'email': 'email',
        'sms': 'sms',
        'delay_ms': 'delayMs',
        'batch_size': 'batchSize',
        'sends_per_target': 'sendsPerTarget'
    }

    def __init__(self, sender_inbox_id=None, sender_phone_id=None, email=None, sms=None, delay_ms=None, batch_size=None, sends_per_target=None, local_vars_configuration=None):  # noqa: E501
        """CreateDeliverabilitySimulationJobOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sender_inbox_id = None
        self._sender_phone_id = None
        self._email = None
        self._sms = None
        self._delay_ms = None
        self._batch_size = None
        self._sends_per_target = None
        self.discriminator = None

        self.sender_inbox_id = sender_inbox_id
        self.sender_phone_id = sender_phone_id
        self.email = email
        self.sms = sms
        self.delay_ms = delay_ms
        self.batch_size = batch_size
        self.sends_per_target = sends_per_target

    @property
    def sender_inbox_id(self):
        """Gets the sender_inbox_id of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501

        Sender inbox ID for INBOX scope tests  # noqa: E501

        :return: The sender_inbox_id of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: str
        """
        return self._sender_inbox_id

    @sender_inbox_id.setter
    def sender_inbox_id(self, sender_inbox_id):
        """Sets the sender_inbox_id of this CreateDeliverabilitySimulationJobOptions.

        Sender inbox ID for INBOX scope tests  # noqa: E501

        :param sender_inbox_id: The sender_inbox_id of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: str
        """

        self._sender_inbox_id = sender_inbox_id

    @property
    def sender_phone_id(self):
        """Gets the sender_phone_id of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501

        Sender phone ID for PHONE scope tests  # noqa: E501

        :return: The sender_phone_id of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: str
        """
        return self._sender_phone_id

    @sender_phone_id.setter
    def sender_phone_id(self, sender_phone_id):
        """Sets the sender_phone_id of this CreateDeliverabilitySimulationJobOptions.

        Sender phone ID for PHONE scope tests  # noqa: E501

        :param sender_phone_id: The sender_phone_id of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: str
        """

        self._sender_phone_id = sender_phone_id

    @property
    def email(self):
        """Gets the email of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501


        :return: The email of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: DeliverabilitySimulationEmailOptions
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CreateDeliverabilitySimulationJobOptions.


        :param email: The email of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: DeliverabilitySimulationEmailOptions
        """

        self._email = email

    @property
    def sms(self):
        """Gets the sms of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501


        :return: The sms of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: DeliverabilitySimulationSmsOptions
        """
        return self._sms

    @sms.setter
    def sms(self, sms):
        """Sets the sms of this CreateDeliverabilitySimulationJobOptions.


        :param sms: The sms of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: DeliverabilitySimulationSmsOptions
        """

        self._sms = sms

    @property
    def delay_ms(self):
        """Gets the delay_ms of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501

        Delay between individual sends in milliseconds  # noqa: E501

        :return: The delay_ms of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: int
        """
        return self._delay_ms

    @delay_ms.setter
    def delay_ms(self, delay_ms):
        """Sets the delay_ms of this CreateDeliverabilitySimulationJobOptions.

        Delay between individual sends in milliseconds  # noqa: E501

        :param delay_ms: The delay_ms of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                delay_ms is not None and delay_ms > 60000):  # noqa: E501
            raise ValueError("Invalid value for `delay_ms`, must be a value less than or equal to `60000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                delay_ms is not None and delay_ms < 50):  # noqa: E501
            raise ValueError("Invalid value for `delay_ms`, must be a value greater than or equal to `50`")  # noqa: E501

        self._delay_ms = delay_ms

    @property
    def batch_size(self):
        """Gets the batch_size of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501

        Maximum sends processed per scheduler batch  # noqa: E501

        :return: The batch_size of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: int
        """
        return self._batch_size

    @batch_size.setter
    def batch_size(self, batch_size):
        """Sets the batch_size of this CreateDeliverabilitySimulationJobOptions.

        Maximum sends processed per scheduler batch  # noqa: E501

        :param batch_size: The batch_size of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                batch_size is not None and batch_size > 50):  # noqa: E501
            raise ValueError("Invalid value for `batch_size`, must be a value less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                batch_size is not None and batch_size < 1):  # noqa: E501
            raise ValueError("Invalid value for `batch_size`, must be a value greater than or equal to `1`")  # noqa: E501

        self._batch_size = batch_size

    @property
    def sends_per_target(self):
        """Gets the sends_per_target of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501

        Optional fixed sends per target. If omitted this is derived from test expectations.  # noqa: E501

        :return: The sends_per_target of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :rtype: int
        """
        return self._sends_per_target

    @sends_per_target.setter
    def sends_per_target(self, sends_per_target):
        """Sets the sends_per_target of this CreateDeliverabilitySimulationJobOptions.

        Optional fixed sends per target. If omitted this is derived from test expectations.  # noqa: E501

        :param sends_per_target: The sends_per_target of this CreateDeliverabilitySimulationJobOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                sends_per_target is not None and sends_per_target > 50):  # noqa: E501
            raise ValueError("Invalid value for `sends_per_target`, must be a value less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                sends_per_target is not None and sends_per_target < 1):  # noqa: E501
            raise ValueError("Invalid value for `sends_per_target`, must be a value greater than or equal to `1`")  # noqa: E501

        self._sends_per_target = sends_per_target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDeliverabilitySimulationJobOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDeliverabilitySimulationJobOptions):
            return True

        return self.to_dict() != other.to_dict()
