# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.ai_controller_api import AIControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestAIControllerApi(unittest.TestCase):
    """AIControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.ai_controller_api.AIControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_transformer(self):
        """Test case for create_transformer

        Create a transformer for reuse in automations  # noqa: E501
        """
        pass

    def test_create_transformer_mappings(self):
        """Test case for create_transformer_mappings

        Create transformer mapping  # noqa: E501
        """
        pass

    def test_delete_all_transformer_mappings(self):
        """Test case for delete_all_transformer_mappings

        Delete all transformer mapping  # noqa: E501
        """
        pass

    def test_delete_transformer(self):
        """Test case for delete_transformer

        Delete a transformer  # noqa: E501
        """
        pass

    def test_delete_transformer_mapping(self):
        """Test case for delete_transformer_mapping

        Delete transformer mapping  # noqa: E501
        """
        pass

    def test_delete_transformers(self):
        """Test case for delete_transformers

        Delete all transformers  # noqa: E501
        """
        pass

    def test_export_transformer_results(self):
        """Test case for export_transformer_results

        Export transformer results  # noqa: E501
        """
        pass

    def test_generate_structured_content_from_attachment(self):
        """Test case for generate_structured_content_from_attachment

        Generate structured content for an attachment  # noqa: E501
        """
        pass

    def test_generate_structured_content_from_email(self):
        """Test case for generate_structured_content_from_email

        Generate structured content for an email  # noqa: E501
        """
        pass

    def test_generate_structured_content_from_sms(self):
        """Test case for generate_structured_content_from_sms

        Generate structured content for a TXT message  # noqa: E501
        """
        pass

    def test_get_export_transformer_results_job(self):
        """Test case for get_export_transformer_results_job

        Get export transformer results job  # noqa: E501
        """
        pass

    def test_get_transformer(self):
        """Test case for get_transformer

        Get a transformer  # noqa: E501
        """
        pass

    def test_get_transformer_mapping(self):
        """Test case for get_transformer_mapping

        Get transformer mapping  # noqa: E501
        """
        pass

    def test_get_transformer_mappings(self):
        """Test case for get_transformer_mappings

        Get transformer mappings  # noqa: E501
        """
        pass

    def test_get_transformer_result(self):
        """Test case for get_transformer_result

        Get transformer result  # noqa: E501
        """
        pass

    def test_get_transformer_results(self):
        """Test case for get_transformer_results

        Get transformer results  # noqa: E501
        """
        pass

    def test_get_transformer_results_table(self):
        """Test case for get_transformer_results_table

        Get transformer results table  # noqa: E501
        """
        pass

    def test_get_transformers(self):
        """Test case for get_transformers

        List transformers  # noqa: E501
        """
        pass

    def test_invoke_transformer(self):
        """Test case for invoke_transformer

        Invoke a transformer  # noqa: E501
        """
        pass

    def test_test_transformer_mapping_match(self):
        """Test case for test_transformer_mapping_match

        Test transformer mapping match result  # noqa: E501
        """
        pass

    def test_validate_structured_output_schema(self):
        """Test case for validate_structured_output_schema

        Validate structured content schema  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
