# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.campaign_probe_controller_api import CampaignProbeControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestCampaignProbeControllerApi(unittest.TestCase):
    """CampaignProbeControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.campaign_probe_controller_api.CampaignProbeControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_compare_campaign_probe_runs(self):
        """Test case for compare_campaign_probe_runs

        Compare two campaign probe runs  # noqa: E501
        """
        pass

    def test_create_campaign_probe(self):
        """Test case for create_campaign_probe

        Create campaign probe  # noqa: E501
        """
        pass

    def test_delete_campaign_probe(self):
        """Test case for delete_campaign_probe

        Delete campaign probe  # noqa: E501
        """
        pass

    def test_get_campaign_probe(self):
        """Test case for get_campaign_probe

        Get campaign probe  # noqa: E501
        """
        pass

    def test_get_campaign_probe_insights(self):
        """Test case for get_campaign_probe_insights

        Get campaign probe insights  # noqa: E501
        """
        pass

    def test_get_campaign_probe_run(self):
        """Test case for get_campaign_probe_run

        Get campaign probe run  # noqa: E501
        """
        pass

    def test_get_campaign_probe_runs(self):
        """Test case for get_campaign_probe_runs

        List campaign probe runs  # noqa: E501
        """
        pass

    def test_get_campaign_probe_series(self):
        """Test case for get_campaign_probe_series

        Get campaign probe trend series  # noqa: E501
        """
        pass

    def test_get_campaign_probes(self):
        """Test case for get_campaign_probes

        List campaign probes  # noqa: E501
        """
        pass

    def test_run_campaign_probe_now(self):
        """Test case for run_campaign_probe_now

        Run campaign probe now  # noqa: E501
        """
        pass

    def test_run_due_campaign_probes(self):
        """Test case for run_due_campaign_probes

        Run due campaign probes for user  # noqa: E501
        """
        pass

    def test_update_campaign_probe(self):
        """Test case for update_campaign_probe

        Update campaign probe  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
