# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExportTransformerOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ai_transform_id': 'str',
        'ai_mapping_id': 'str',
        'flatten_arrays': 'bool',
        'since': 'datetime',
        'before': 'datetime',
        'format': 'str',
        'inbox_id': 'str',
        'phone_id': 'str',
        'email_id': 'str',
        'sms_id': 'str',
        'attachment_id': 'str',
        'include_meta_data': 'bool',
        'delimiter': 'str',
        'array_separator': 'str',
        'include_meta_data_columns': 'list[str]'
    }

    attribute_map = {
        'ai_transform_id': 'aiTransformId',
        'ai_mapping_id': 'aiMappingId',
        'flatten_arrays': 'flattenArrays',
        'since': 'since',
        'before': 'before',
        'format': 'format',
        'inbox_id': 'inboxId',
        'phone_id': 'phoneId',
        'email_id': 'emailId',
        'sms_id': 'smsId',
        'attachment_id': 'attachmentId',
        'include_meta_data': 'includeMetaData',
        'delimiter': 'delimiter',
        'array_separator': 'arraySeparator',
        'include_meta_data_columns': 'includeMetaDataColumns'
    }

    def __init__(self, ai_transform_id=None, ai_mapping_id=None, flatten_arrays=None, since=None, before=None, format=None, inbox_id=None, phone_id=None, email_id=None, sms_id=None, attachment_id=None, include_meta_data=None, delimiter=None, array_separator=None, include_meta_data_columns=None, local_vars_configuration=None):  # noqa: E501
        """ExportTransformerOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ai_transform_id = None
        self._ai_mapping_id = None
        self._flatten_arrays = None
        self._since = None
        self._before = None
        self._format = None
        self._inbox_id = None
        self._phone_id = None
        self._email_id = None
        self._sms_id = None
        self._attachment_id = None
        self._include_meta_data = None
        self._delimiter = None
        self._array_separator = None
        self._include_meta_data_columns = None
        self.discriminator = None

        self.ai_transform_id = ai_transform_id
        self.ai_mapping_id = ai_mapping_id
        self.flatten_arrays = flatten_arrays
        self.since = since
        self.before = before
        self.format = format
        self.inbox_id = inbox_id
        self.phone_id = phone_id
        self.email_id = email_id
        self.sms_id = sms_id
        self.attachment_id = attachment_id
        self.include_meta_data = include_meta_data
        self.delimiter = delimiter
        self.array_separator = array_separator
        self.include_meta_data_columns = include_meta_data_columns

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this ExportTransformerOptions.  # noqa: E501


        :return: The ai_transform_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this ExportTransformerOptions.


        :param ai_transform_id: The ai_transform_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._ai_transform_id = ai_transform_id

    @property
    def ai_mapping_id(self):
        """Gets the ai_mapping_id of this ExportTransformerOptions.  # noqa: E501


        :return: The ai_mapping_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_mapping_id

    @ai_mapping_id.setter
    def ai_mapping_id(self, ai_mapping_id):
        """Sets the ai_mapping_id of this ExportTransformerOptions.


        :param ai_mapping_id: The ai_mapping_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._ai_mapping_id = ai_mapping_id

    @property
    def flatten_arrays(self):
        """Gets the flatten_arrays of this ExportTransformerOptions.  # noqa: E501


        :return: The flatten_arrays of this ExportTransformerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._flatten_arrays

    @flatten_arrays.setter
    def flatten_arrays(self, flatten_arrays):
        """Sets the flatten_arrays of this ExportTransformerOptions.


        :param flatten_arrays: The flatten_arrays of this ExportTransformerOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and flatten_arrays is None:  # noqa: E501
            raise ValueError("Invalid value for `flatten_arrays`, must not be `None`")  # noqa: E501

        self._flatten_arrays = flatten_arrays

    @property
    def since(self):
        """Gets the since of this ExportTransformerOptions.  # noqa: E501


        :return: The since of this ExportTransformerOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this ExportTransformerOptions.


        :param since: The since of this ExportTransformerOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this ExportTransformerOptions.  # noqa: E501


        :return: The before of this ExportTransformerOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this ExportTransformerOptions.


        :param before: The before of this ExportTransformerOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def format(self):
        """Gets the format of this ExportTransformerOptions.  # noqa: E501


        :return: The format of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this ExportTransformerOptions.


        :param format: The format of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and format is None:  # noqa: E501
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501
        allowed_values = ["CSV", "EXCEL", "XML", "JSON"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and format not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                .format(format, allowed_values)
            )

        self._format = format

    @property
    def inbox_id(self):
        """Gets the inbox_id of this ExportTransformerOptions.  # noqa: E501


        :return: The inbox_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this ExportTransformerOptions.


        :param inbox_id: The inbox_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def phone_id(self):
        """Gets the phone_id of this ExportTransformerOptions.  # noqa: E501


        :return: The phone_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_id

    @phone_id.setter
    def phone_id(self, phone_id):
        """Sets the phone_id of this ExportTransformerOptions.


        :param phone_id: The phone_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._phone_id = phone_id

    @property
    def email_id(self):
        """Gets the email_id of this ExportTransformerOptions.  # noqa: E501


        :return: The email_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this ExportTransformerOptions.


        :param email_id: The email_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def sms_id(self):
        """Gets the sms_id of this ExportTransformerOptions.  # noqa: E501


        :return: The sms_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._sms_id

    @sms_id.setter
    def sms_id(self, sms_id):
        """Sets the sms_id of this ExportTransformerOptions.


        :param sms_id: The sms_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._sms_id = sms_id

    @property
    def attachment_id(self):
        """Gets the attachment_id of this ExportTransformerOptions.  # noqa: E501


        :return: The attachment_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this ExportTransformerOptions.


        :param attachment_id: The attachment_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def include_meta_data(self):
        """Gets the include_meta_data of this ExportTransformerOptions.  # noqa: E501


        :return: The include_meta_data of this ExportTransformerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_meta_data

    @include_meta_data.setter
    def include_meta_data(self, include_meta_data):
        """Sets the include_meta_data of this ExportTransformerOptions.


        :param include_meta_data: The include_meta_data of this ExportTransformerOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and include_meta_data is None:  # noqa: E501
            raise ValueError("Invalid value for `include_meta_data`, must not be `None`")  # noqa: E501

        self._include_meta_data = include_meta_data

    @property
    def delimiter(self):
        """Gets the delimiter of this ExportTransformerOptions.  # noqa: E501


        :return: The delimiter of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """Sets the delimiter of this ExportTransformerOptions.


        :param delimiter: The delimiter of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._delimiter = delimiter

    @property
    def array_separator(self):
        """Gets the array_separator of this ExportTransformerOptions.  # noqa: E501


        :return: The array_separator of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._array_separator

    @array_separator.setter
    def array_separator(self, array_separator):
        """Sets the array_separator of this ExportTransformerOptions.


        :param array_separator: The array_separator of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._array_separator = array_separator

    @property
    def include_meta_data_columns(self):
        """Gets the include_meta_data_columns of this ExportTransformerOptions.  # noqa: E501


        :return: The include_meta_data_columns of this ExportTransformerOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._include_meta_data_columns

    @include_meta_data_columns.setter
    def include_meta_data_columns(self, include_meta_data_columns):
        """Sets the include_meta_data_columns of this ExportTransformerOptions.


        :param include_meta_data_columns: The include_meta_data_columns of this ExportTransformerOptions.  # noqa: E501
        :type: list[str]
        """

        self._include_meta_data_columns = include_meta_data_columns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExportTransformerOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExportTransformerOptions):
            return True

        return self.to_dict() != other.to_dict()
