# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateDmarcRecordOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'version': 'str',
        'policy': 'str',
        'subdomain_policy': 'str',
        'report_email_address': 'list[str]',
        'forensic_email_address': 'list[str]',
        'percentage': 'int',
        'report_format': 'str',
        'seconds_between_reports': 'int',
        'adkim': 'str',
        'aspf': 'str',
        'fo': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'version': 'version',
        'policy': 'policy',
        'subdomain_policy': 'subdomainPolicy',
        'report_email_address': 'reportEmailAddress',
        'forensic_email_address': 'forensicEmailAddress',
        'percentage': 'percentage',
        'report_format': 'reportFormat',
        'seconds_between_reports': 'secondsBetweenReports',
        'adkim': 'adkim',
        'aspf': 'aspf',
        'fo': 'fo'
    }

    def __init__(self, domain=None, version=None, policy=None, subdomain_policy=None, report_email_address=None, forensic_email_address=None, percentage=None, report_format=None, seconds_between_reports=None, adkim=None, aspf=None, fo=None, local_vars_configuration=None):  # noqa: E501
        """GenerateDmarcRecordOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._version = None
        self._policy = None
        self._subdomain_policy = None
        self._report_email_address = None
        self._forensic_email_address = None
        self._percentage = None
        self._report_format = None
        self._seconds_between_reports = None
        self._adkim = None
        self._aspf = None
        self._fo = None
        self.discriminator = None

        self.domain = domain
        self.version = version
        self.policy = policy
        if subdomain_policy is not None:
            self.subdomain_policy = subdomain_policy
        if report_email_address is not None:
            self.report_email_address = report_email_address
        if forensic_email_address is not None:
            self.forensic_email_address = forensic_email_address
        if percentage is not None:
            self.percentage = percentage
        if report_format is not None:
            self.report_format = report_format
        if seconds_between_reports is not None:
            self.seconds_between_reports = seconds_between_reports
        if adkim is not None:
            self.adkim = adkim
        if aspf is not None:
            self.aspf = aspf
        if fo is not None:
            self.fo = fo

    @property
    def domain(self):
        """Gets the domain of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The domain of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this GenerateDmarcRecordOptions.


        :param domain: The domain of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def version(self):
        """Gets the version of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The version of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this GenerateDmarcRecordOptions.


        :param version: The version of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501
        allowed_values = ["DMARC1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and version not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `version` ({0}), must be one of {1}"  # noqa: E501
                .format(version, allowed_values)
            )

        self._version = version

    @property
    def policy(self):
        """Gets the policy of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this GenerateDmarcRecordOptions.


        :param policy: The policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and policy is None:  # noqa: E501
            raise ValueError("Invalid value for `policy`, must not be `None`")  # noqa: E501
        allowed_values = ["NONE", "QUARANTINE", "REJECT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and policy not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `policy` ({0}), must be one of {1}"  # noqa: E501
                .format(policy, allowed_values)
            )

        self._policy = policy

    @property
    def subdomain_policy(self):
        """Gets the subdomain_policy of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The subdomain_policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._subdomain_policy

    @subdomain_policy.setter
    def subdomain_policy(self, subdomain_policy):
        """Sets the subdomain_policy of this GenerateDmarcRecordOptions.


        :param subdomain_policy: The subdomain_policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "QUARANTINE", "REJECT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and subdomain_policy not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `subdomain_policy` ({0}), must be one of {1}"  # noqa: E501
                .format(subdomain_policy, allowed_values)
            )

        self._subdomain_policy = subdomain_policy

    @property
    def report_email_address(self):
        """Gets the report_email_address of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The report_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._report_email_address

    @report_email_address.setter
    def report_email_address(self, report_email_address):
        """Sets the report_email_address of this GenerateDmarcRecordOptions.


        :param report_email_address: The report_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._report_email_address = report_email_address

    @property
    def forensic_email_address(self):
        """Gets the forensic_email_address of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The forensic_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._forensic_email_address

    @forensic_email_address.setter
    def forensic_email_address(self, forensic_email_address):
        """Sets the forensic_email_address of this GenerateDmarcRecordOptions.


        :param forensic_email_address: The forensic_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._forensic_email_address = forensic_email_address

    @property
    def percentage(self):
        """Gets the percentage of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The percentage of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this GenerateDmarcRecordOptions.


        :param percentage: The percentage of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                percentage is not None and percentage > 100):  # noqa: E501
            raise ValueError("Invalid value for `percentage`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                percentage is not None and percentage < 1):  # noqa: E501
            raise ValueError("Invalid value for `percentage`, must be a value greater than or equal to `1`")  # noqa: E501

        self._percentage = percentage

    @property
    def report_format(self):
        """Gets the report_format of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The report_format of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._report_format

    @report_format.setter
    def report_format(self, report_format):
        """Sets the report_format of this GenerateDmarcRecordOptions.


        :param report_format: The report_format of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["AFRF"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and report_format not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `report_format` ({0}), must be one of {1}"  # noqa: E501
                .format(report_format, allowed_values)
            )

        self._report_format = report_format

    @property
    def seconds_between_reports(self):
        """Gets the seconds_between_reports of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The seconds_between_reports of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: int
        """
        return self._seconds_between_reports

    @seconds_between_reports.setter
    def seconds_between_reports(self, seconds_between_reports):
        """Sets the seconds_between_reports of this GenerateDmarcRecordOptions.


        :param seconds_between_reports: The seconds_between_reports of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: int
        """

        self._seconds_between_reports = seconds_between_reports

    @property
    def adkim(self):
        """Gets the adkim of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The adkim of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._adkim

    @adkim.setter
    def adkim(self, adkim):
        """Sets the adkim of this GenerateDmarcRecordOptions.


        :param adkim: The adkim of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["STRICT", "RELAXED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and adkim not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `adkim` ({0}), must be one of {1}"  # noqa: E501
                .format(adkim, allowed_values)
            )

        self._adkim = adkim

    @property
    def aspf(self):
        """Gets the aspf of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The aspf of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._aspf

    @aspf.setter
    def aspf(self, aspf):
        """Sets the aspf of this GenerateDmarcRecordOptions.


        :param aspf: The aspf of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["STRICT", "RELAXED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and aspf not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `aspf` ({0}), must be one of {1}"  # noqa: E501
                .format(aspf, allowed_values)
            )

        self._aspf = aspf

    @property
    def fo(self):
        """Gets the fo of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The fo of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._fo

    @fo.setter
    def fo(self, fo):
        """Sets the fo of this GenerateDmarcRecordOptions.


        :param fo: The fo of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["FO_0", "FO_1", "FO_D", "FO_S"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and fo not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `fo` ({0}), must be one of {1}"  # noqa: E501
                .format(fo, allowed_values)
            )

        self._fo = fo

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateDmarcRecordOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateDmarcRecordOptions):
            return True

        return self.to_dict() != other.to_dict()
