# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SendOptInConsentEmailOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'template_html': 'str',
        'subject': 'str',
        'sender_inbox': 'str'
    }

    attribute_map = {
        'template_html': 'templateHtml',
        'subject': 'subject',
        'sender_inbox': 'senderInbox'
    }

    def __init__(self, template_html=None, subject=None, sender_inbox=None, local_vars_configuration=None):  # noqa: E501
        """SendOptInConsentEmailOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._template_html = None
        self._subject = None
        self._sender_inbox = None
        self.discriminator = None

        self.template_html = template_html
        self.subject = subject
        if sender_inbox is not None:
            self.sender_inbox = sender_inbox

    @property
    def template_html(self):
        """Gets the template_html of this SendOptInConsentEmailOptions.  # noqa: E501


        :return: The template_html of this SendOptInConsentEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._template_html

    @template_html.setter
    def template_html(self, template_html):
        """Sets the template_html of this SendOptInConsentEmailOptions.


        :param template_html: The template_html of this SendOptInConsentEmailOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and template_html is None:  # noqa: E501
            raise ValueError("Invalid value for `template_html`, must not be `None`")  # noqa: E501

        self._template_html = template_html

    @property
    def subject(self):
        """Gets the subject of this SendOptInConsentEmailOptions.  # noqa: E501


        :return: The subject of this SendOptInConsentEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this SendOptInConsentEmailOptions.


        :param subject: The subject of this SendOptInConsentEmailOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and subject is None:  # noqa: E501
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def sender_inbox(self):
        """Gets the sender_inbox of this SendOptInConsentEmailOptions.  # noqa: E501


        :return: The sender_inbox of this SendOptInConsentEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._sender_inbox

    @sender_inbox.setter
    def sender_inbox(self, sender_inbox):
        """Sets the sender_inbox of this SendOptInConsentEmailOptions.


        :param sender_inbox: The sender_inbox of this SendOptInConsentEmailOptions.  # noqa: E501
        :type: str
        """

        self._sender_inbox = sender_inbox

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendOptInConsentEmailOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendOptInConsentEmailOptions):
            return True

        return self.to_dict() != other.to_dict()
