# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySimulationEmailOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'from_override': 'str',
        'subject': 'str',
        'body_template': 'str'
    }

    attribute_map = {
        'from_override': 'fromOverride',
        'subject': 'subject',
        'body_template': 'bodyTemplate'
    }

    def __init__(self, from_override=None, subject=None, body_template=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySimulationEmailOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._from_override = None
        self._subject = None
        self._body_template = None
        self.discriminator = None

        self.from_override = from_override
        self.subject = subject
        self.body_template = body_template

    @property
    def from_override(self):
        """Gets the from_override of this DeliverabilitySimulationEmailOptions.  # noqa: E501

        Optional from override for each sent email  # noqa: E501

        :return: The from_override of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._from_override

    @from_override.setter
    def from_override(self, from_override):
        """Sets the from_override of this DeliverabilitySimulationEmailOptions.

        Optional from override for each sent email  # noqa: E501

        :param from_override: The from_override of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :type: str
        """

        self._from_override = from_override

    @property
    def subject(self):
        """Gets the subject of this DeliverabilitySimulationEmailOptions.  # noqa: E501

        Optional email subject fallback used when template subject is omitted  # noqa: E501

        :return: The subject of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DeliverabilitySimulationEmailOptions.

        Optional email subject fallback used when template subject is omitted  # noqa: E501

        :param subject: The subject of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def body_template(self):
        """Gets the body_template of this DeliverabilitySimulationEmailOptions.  # noqa: E501

        Optional email body template. Supports {{targetLabel}}, {{sendIndex}}, {{attempt}}.  # noqa: E501

        :return: The body_template of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._body_template

    @body_template.setter
    def body_template(self, body_template):
        """Sets the body_template of this DeliverabilitySimulationEmailOptions.

        Optional email body template. Supports {{targetLabel}}, {{sendIndex}}, {{attempt}}.  # noqa: E501

        :param body_template: The body_template of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :type: str
        """

        self._body_template = body_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySimulationEmailOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySimulationEmailOptions):
            return True

        return self.to_dict() != other.to_dict()
