# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhonePoolMemberDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'pool_id': 'str',
        'phone_number_id': 'str',
        'phone_number': 'str',
        'phone_country': 'str',
        'phone_name': 'str',
        'created_at': 'datetime',
        'active_lease': 'PhonePoolLeaseDto'
    }

    attribute_map = {
        'id': 'id',
        'pool_id': 'poolId',
        'phone_number_id': 'phoneNumberId',
        'phone_number': 'phoneNumber',
        'phone_country': 'phoneCountry',
        'phone_name': 'phoneName',
        'created_at': 'createdAt',
        'active_lease': 'activeLease'
    }

    def __init__(self, id=None, pool_id=None, phone_number_id=None, phone_number=None, phone_country=None, phone_name=None, created_at=None, active_lease=None, local_vars_configuration=None):  # noqa: E501
        """PhonePoolMemberDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._pool_id = None
        self._phone_number_id = None
        self._phone_number = None
        self._phone_country = None
        self._phone_name = None
        self._created_at = None
        self._active_lease = None
        self.discriminator = None

        self.id = id
        self.pool_id = pool_id
        self.phone_number_id = phone_number_id
        self.phone_number = phone_number
        self.phone_country = phone_country
        if phone_name is not None:
            self.phone_name = phone_name
        self.created_at = created_at
        if active_lease is not None:
            self.active_lease = active_lease

    @property
    def id(self):
        """Gets the id of this PhonePoolMemberDto.  # noqa: E501


        :return: The id of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhonePoolMemberDto.


        :param id: The id of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def pool_id(self):
        """Gets the pool_id of this PhonePoolMemberDto.  # noqa: E501


        :return: The pool_id of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._pool_id

    @pool_id.setter
    def pool_id(self, pool_id):
        """Sets the pool_id of this PhonePoolMemberDto.


        :param pool_id: The pool_id of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pool_id is None:  # noqa: E501
            raise ValueError("Invalid value for `pool_id`, must not be `None`")  # noqa: E501

        self._pool_id = pool_id

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_number_id of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this PhonePoolMemberDto.


        :param phone_number_id: The phone_number_id of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number_id is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number_id`, must not be `None`")  # noqa: E501

        self._phone_number_id = phone_number_id

    @property
    def phone_number(self):
        """Gets the phone_number of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_number of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhonePoolMemberDto.


        :param phone_number: The phone_number of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_country(self):
        """Gets the phone_country of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_country of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhonePoolMemberDto.


        :param phone_country: The phone_country of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_name(self):
        """Gets the phone_name of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_name of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_name

    @phone_name.setter
    def phone_name(self, phone_name):
        """Sets the phone_name of this PhonePoolMemberDto.


        :param phone_name: The phone_name of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """

        self._phone_name = phone_name

    @property
    def created_at(self):
        """Gets the created_at of this PhonePoolMemberDto.  # noqa: E501


        :return: The created_at of this PhonePoolMemberDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhonePoolMemberDto.


        :param created_at: The created_at of this PhonePoolMemberDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def active_lease(self):
        """Gets the active_lease of this PhonePoolMemberDto.  # noqa: E501


        :return: The active_lease of this PhonePoolMemberDto.  # noqa: E501
        :rtype: PhonePoolLeaseDto
        """
        return self._active_lease

    @active_lease.setter
    def active_lease(self, active_lease):
        """Sets the active_lease of this PhonePoolMemberDto.


        :param active_lease: The active_lease of this PhonePoolMemberDto.  # noqa: E501
        :type: PhonePoolLeaseDto
        """

        self._active_lease = active_lease

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhonePoolMemberDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhonePoolMemberDto):
            return True

        return self.to_dict() != other.to_dict()
