# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TestSmtpServerOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host': 'str',
        'port': 'int',
        'use_start_tls': 'bool',
        'username': 'str',
        'password': 'str',
        '_from': 'str',
        'to': 'str',
        'captcha_token': 'str'
    }

    attribute_map = {
        'host': 'host',
        'port': 'port',
        'use_start_tls': 'useStartTls',
        'username': 'username',
        'password': 'password',
        '_from': 'from',
        'to': 'to',
        'captcha_token': 'captchaToken'
    }

    def __init__(self, host=None, port=None, use_start_tls=None, username=None, password=None, _from=None, to=None, captcha_token=None, local_vars_configuration=None):  # noqa: E501
        """TestSmtpServerOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._host = None
        self._port = None
        self._use_start_tls = None
        self._username = None
        self._password = None
        self.__from = None
        self._to = None
        self._captcha_token = None
        self.discriminator = None

        self.host = host
        self.port = port
        self.use_start_tls = use_start_tls
        self.username = username
        self.password = password
        self._from = _from
        self.to = to
        self.captcha_token = captcha_token

    @property
    def host(self):
        """Gets the host of this TestSmtpServerOptions.  # noqa: E501

        SMTP host name or IP address  # noqa: E501

        :return: The host of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this TestSmtpServerOptions.

        SMTP host name or IP address  # noqa: E501

        :param host: The host of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                host is not None and len(host) < 1):
            raise ValueError("Invalid value for `host`, length must be greater than or equal to `1`")  # noqa: E501

        self._host = host

    @property
    def port(self):
        """Gets the port of this TestSmtpServerOptions.  # noqa: E501


        :return: The port of this TestSmtpServerOptions.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this TestSmtpServerOptions.


        :param port: The port of this TestSmtpServerOptions.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port is not None and port > 65535):  # noqa: E501
            raise ValueError("Invalid value for `port`, must be a value less than or equal to `65535`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port is not None and port < 1):  # noqa: E501
            raise ValueError("Invalid value for `port`, must be a value greater than or equal to `1`")  # noqa: E501

        self._port = port

    @property
    def use_start_tls(self):
        """Gets the use_start_tls of this TestSmtpServerOptions.  # noqa: E501


        :return: The use_start_tls of this TestSmtpServerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._use_start_tls

    @use_start_tls.setter
    def use_start_tls(self, use_start_tls):
        """Sets the use_start_tls of this TestSmtpServerOptions.


        :param use_start_tls: The use_start_tls of this TestSmtpServerOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and use_start_tls is None:  # noqa: E501
            raise ValueError("Invalid value for `use_start_tls`, must not be `None`")  # noqa: E501

        self._use_start_tls = use_start_tls

    @property
    def username(self):
        """Gets the username of this TestSmtpServerOptions.  # noqa: E501


        :return: The username of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this TestSmtpServerOptions.


        :param username: The username of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this TestSmtpServerOptions.  # noqa: E501


        :return: The password of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this TestSmtpServerOptions.


        :param password: The password of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def _from(self):
        """Gets the _from of this TestSmtpServerOptions.  # noqa: E501


        :return: The _from of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this TestSmtpServerOptions.


        :param _from: The _from of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this TestSmtpServerOptions.  # noqa: E501


        :return: The to of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this TestSmtpServerOptions.


        :param to: The to of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def captcha_token(self):
        """Gets the captcha_token of this TestSmtpServerOptions.  # noqa: E501


        :return: The captcha_token of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._captcha_token

    @captcha_token.setter
    def captcha_token(self, captcha_token):
        """Sets the captcha_token of this TestSmtpServerOptions.


        :param captcha_token: The captcha_token of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._captcha_token = captcha_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestSmtpServerOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TestSmtpServerOptions):
            return True

        return self.to_dict() != other.to_dict()
