# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityEntityResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entity_id': 'str',
        'entity_label': 'str',
        'matched': 'bool',
        'matched_expectation_count': 'int',
        'total_expectation_count': 'int',
        'phone_country': 'str',
        'phone_variant': 'str',
        'evaluated_at': 'datetime',
        'expectation_results': 'list[DeliverabilityExpectationResultDto]'
    }

    attribute_map = {
        'entity_id': 'entityId',
        'entity_label': 'entityLabel',
        'matched': 'matched',
        'matched_expectation_count': 'matchedExpectationCount',
        'total_expectation_count': 'totalExpectationCount',
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'evaluated_at': 'evaluatedAt',
        'expectation_results': 'expectationResults'
    }

    def __init__(self, entity_id=None, entity_label=None, matched=None, matched_expectation_count=None, total_expectation_count=None, phone_country=None, phone_variant=None, evaluated_at=None, expectation_results=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityEntityResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._entity_id = None
        self._entity_label = None
        self._matched = None
        self._matched_expectation_count = None
        self._total_expectation_count = None
        self._phone_country = None
        self._phone_variant = None
        self._evaluated_at = None
        self._expectation_results = None
        self.discriminator = None

        self.entity_id = entity_id
        self.entity_label = entity_label
        self.matched = matched
        self.matched_expectation_count = matched_expectation_count
        self.total_expectation_count = total_expectation_count
        self.phone_country = phone_country
        self.phone_variant = phone_variant
        self.evaluated_at = evaluated_at
        self.expectation_results = expectation_results

    @property
    def entity_id(self):
        """Gets the entity_id of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The entity_id of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this DeliverabilityEntityResultDto.


        :param entity_id: The entity_id of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_id is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_id`, must not be `None`")  # noqa: E501

        self._entity_id = entity_id

    @property
    def entity_label(self):
        """Gets the entity_label of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The entity_label of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_label

    @entity_label.setter
    def entity_label(self, entity_label):
        """Sets the entity_label of this DeliverabilityEntityResultDto.


        :param entity_label: The entity_label of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_label is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_label`, must not be `None`")  # noqa: E501

        self._entity_label = entity_label

    @property
    def matched(self):
        """Gets the matched of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The matched of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: bool
        """
        return self._matched

    @matched.setter
    def matched(self, matched):
        """Sets the matched of this DeliverabilityEntityResultDto.


        :param matched: The matched of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and matched is None:  # noqa: E501
            raise ValueError("Invalid value for `matched`, must not be `None`")  # noqa: E501

        self._matched = matched

    @property
    def matched_expectation_count(self):
        """Gets the matched_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The matched_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: int
        """
        return self._matched_expectation_count

    @matched_expectation_count.setter
    def matched_expectation_count(self, matched_expectation_count):
        """Sets the matched_expectation_count of this DeliverabilityEntityResultDto.


        :param matched_expectation_count: The matched_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and matched_expectation_count is None:  # noqa: E501
            raise ValueError("Invalid value for `matched_expectation_count`, must not be `None`")  # noqa: E501

        self._matched_expectation_count = matched_expectation_count

    @property
    def total_expectation_count(self):
        """Gets the total_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The total_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: int
        """
        return self._total_expectation_count

    @total_expectation_count.setter
    def total_expectation_count(self, total_expectation_count):
        """Sets the total_expectation_count of this DeliverabilityEntityResultDto.


        :param total_expectation_count: The total_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_expectation_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_expectation_count`, must not be `None`")  # noqa: E501

        self._total_expectation_count = total_expectation_count

    @property
    def phone_country(self):
        """Gets the phone_country of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The phone_country of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this DeliverabilityEntityResultDto.


        :param phone_country: The phone_country of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The phone_variant of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this DeliverabilityEntityResultDto.


        :param phone_variant: The phone_variant of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def evaluated_at(self):
        """Gets the evaluated_at of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The evaluated_at of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: datetime
        """
        return self._evaluated_at

    @evaluated_at.setter
    def evaluated_at(self, evaluated_at):
        """Sets the evaluated_at of this DeliverabilityEntityResultDto.


        :param evaluated_at: The evaluated_at of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: datetime
        """

        self._evaluated_at = evaluated_at

    @property
    def expectation_results(self):
        """Gets the expectation_results of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The expectation_results of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: list[DeliverabilityExpectationResultDto]
        """
        return self._expectation_results

    @expectation_results.setter
    def expectation_results(self, expectation_results):
        """Sets the expectation_results of this DeliverabilityEntityResultDto.


        :param expectation_results: The expectation_results of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: list[DeliverabilityExpectationResultDto]
        """
        if self.local_vars_configuration.client_side_validation and expectation_results is None:  # noqa: E501
            raise ValueError("Invalid value for `expectation_results`, must not be `None`")  # noqa: E501

        self._expectation_results = expectation_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityEntityResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityEntityResultDto):
            return True

        return self.to_dict() != other.to_dict()
