# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImportEmailOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'raw_email_base64': 'str',
        'external_id': 'str',
        'run_pipeline': 'bool',
        'override_message_id': 'bool'
    }

    attribute_map = {
        'raw_email_base64': 'rawEmailBase64',
        'external_id': 'externalId',
        'run_pipeline': 'runPipeline',
        'override_message_id': 'overrideMessageId'
    }

    def __init__(self, raw_email_base64=None, external_id=None, run_pipeline=False, override_message_id=True, local_vars_configuration=None):  # noqa: E501
        """ImportEmailOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._raw_email_base64 = None
        self._external_id = None
        self._run_pipeline = None
        self._override_message_id = None
        self.discriminator = None

        self.raw_email_base64 = raw_email_base64
        self.external_id = external_id
        self.run_pipeline = run_pipeline
        self.override_message_id = override_message_id

    @property
    def raw_email_base64(self):
        """Gets the raw_email_base64 of this ImportEmailOptions.  # noqa: E501

        Base64 encoded RFC822/MIME email contents. This should be the full raw email including headers and body, such as the bytes from an `.eml` file.  # noqa: E501

        :return: The raw_email_base64 of this ImportEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._raw_email_base64

    @raw_email_base64.setter
    def raw_email_base64(self, raw_email_base64):
        """Sets the raw_email_base64 of this ImportEmailOptions.

        Base64 encoded RFC822/MIME email contents. This should be the full raw email including headers and body, such as the bytes from an `.eml` file.  # noqa: E501

        :param raw_email_base64: The raw_email_base64 of this ImportEmailOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and raw_email_base64 is None:  # noqa: E501
            raise ValueError("Invalid value for `raw_email_base64`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                raw_email_base64 is not None and len(raw_email_base64) < 1):
            raise ValueError("Invalid value for `raw_email_base64`, length must be greater than or equal to `1`")  # noqa: E501

        self._raw_email_base64 = raw_email_base64

    @property
    def external_id(self):
        """Gets the external_id of this ImportEmailOptions.  # noqa: E501

        Optional external identifier for the imported email source. Useful for correlating imports back to another system.  # noqa: E501

        :return: The external_id of this ImportEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ImportEmailOptions.

        Optional external identifier for the imported email source. Useful for correlating imports back to another system.  # noqa: E501

        :param external_id: The external_id of this ImportEmailOptions.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def run_pipeline(self):
        """Gets the run_pipeline of this ImportEmailOptions.  # noqa: E501

        When true the normal inbound receive pipeline runs after persistence, including automations, webhooks, transformers, forwarders, repliers, and related fanout. When false the email is stored only.  # noqa: E501

        :return: The run_pipeline of this ImportEmailOptions.  # noqa: E501
        :rtype: bool
        """
        return self._run_pipeline

    @run_pipeline.setter
    def run_pipeline(self, run_pipeline):
        """Sets the run_pipeline of this ImportEmailOptions.

        When true the normal inbound receive pipeline runs after persistence, including automations, webhooks, transformers, forwarders, repliers, and related fanout. When false the email is stored only.  # noqa: E501

        :param run_pipeline: The run_pipeline of this ImportEmailOptions.  # noqa: E501
        :type: bool
        """

        self._run_pipeline = run_pipeline

    @property
    def override_message_id(self):
        """Gets the override_message_id of this ImportEmailOptions.  # noqa: E501

        When true MailSlurp rewrites the MIME `Message-ID` header before storing and parsing the email so imported messages do not collide with existing message identities.  # noqa: E501

        :return: The override_message_id of this ImportEmailOptions.  # noqa: E501
        :rtype: bool
        """
        return self._override_message_id

    @override_message_id.setter
    def override_message_id(self, override_message_id):
        """Sets the override_message_id of this ImportEmailOptions.

        When true MailSlurp rewrites the MIME `Message-ID` header before storing and parsing the email so imported messages do not collide with existing message identities.  # noqa: E501

        :param override_message_id: The override_message_id of this ImportEmailOptions.  # noqa: E501
        :type: bool
        """

        self._override_message_id = override_message_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportEmailOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportEmailOptions):
            return True

        return self.to_dict() != other.to_dict()
