# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorRunDueResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'trigger_source': 'str',
        'run_count': 'int',
        'requested_max_runs': 'int',
        'executed_at': 'datetime'
    }

    attribute_map = {
        'trigger_source': 'triggerSource',
        'run_count': 'runCount',
        'requested_max_runs': 'requestedMaxRuns',
        'executed_at': 'executedAt'
    }

    def __init__(self, trigger_source=None, run_count=None, requested_max_runs=None, executed_at=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorRunDueResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._trigger_source = None
        self._run_count = None
        self._requested_max_runs = None
        self._executed_at = None
        self.discriminator = None

        self.trigger_source = trigger_source
        self.run_count = run_count
        self.requested_max_runs = requested_max_runs
        self.executed_at = executed_at

    @property
    def trigger_source(self):
        """Gets the trigger_source of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The trigger_source of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: str
        """
        return self._trigger_source

    @trigger_source.setter
    def trigger_source(self, trigger_source):
        """Sets the trigger_source of this DomainMonitorRunDueResult.


        :param trigger_source: The trigger_source of this DomainMonitorRunDueResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trigger_source is None:  # noqa: E501
            raise ValueError("Invalid value for `trigger_source`, must not be `None`")  # noqa: E501
        allowed_values = ["API", "USER_SCHEDULE", "CRON", "SCHEDULER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and trigger_source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `trigger_source` ({0}), must be one of {1}"  # noqa: E501
                .format(trigger_source, allowed_values)
            )

        self._trigger_source = trigger_source

    @property
    def run_count(self):
        """Gets the run_count of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The run_count of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this DomainMonitorRunDueResult.


        :param run_count: The run_count of this DomainMonitorRunDueResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `run_count`, must not be `None`")  # noqa: E501

        self._run_count = run_count

    @property
    def requested_max_runs(self):
        """Gets the requested_max_runs of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The requested_max_runs of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: int
        """
        return self._requested_max_runs

    @requested_max_runs.setter
    def requested_max_runs(self, requested_max_runs):
        """Sets the requested_max_runs of this DomainMonitorRunDueResult.


        :param requested_max_runs: The requested_max_runs of this DomainMonitorRunDueResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and requested_max_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `requested_max_runs`, must not be `None`")  # noqa: E501

        self._requested_max_runs = requested_max_runs

    @property
    def executed_at(self):
        """Gets the executed_at of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The executed_at of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: datetime
        """
        return self._executed_at

    @executed_at.setter
    def executed_at(self, executed_at):
        """Sets the executed_at of this DomainMonitorRunDueResult.


        :param executed_at: The executed_at of this DomainMonitorRunDueResult.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and executed_at is None:  # noqa: E501
            raise ValueError("Invalid value for `executed_at`, must not be `None`")  # noqa: E501

        self._executed_at = executed_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorRunDueResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorRunDueResult):
            return True

        return self.to_dict() != other.to_dict()
