# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailHeaderAnalysisSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'spf': 'str',
        'dkim': 'str',
        'dmarc': 'str',
        'from_domain': 'str',
        'return_path_domain': 'str'
    }

    attribute_map = {
        'spf': 'spf',
        'dkim': 'dkim',
        'dmarc': 'dmarc',
        'from_domain': 'fromDomain',
        'return_path_domain': 'returnPathDomain'
    }

    def __init__(self, spf=None, dkim=None, dmarc=None, from_domain=None, return_path_domain=None, local_vars_configuration=None):  # noqa: E501
        """EmailHeaderAnalysisSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._spf = None
        self._dkim = None
        self._dmarc = None
        self._from_domain = None
        self._return_path_domain = None
        self.discriminator = None

        if spf is not None:
            self.spf = spf
        if dkim is not None:
            self.dkim = dkim
        if dmarc is not None:
            self.dmarc = dmarc
        if from_domain is not None:
            self.from_domain = from_domain
        if return_path_domain is not None:
            self.return_path_domain = return_path_domain

    @property
    def spf(self):
        """Gets the spf of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The spf of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._spf

    @spf.setter
    def spf(self, spf):
        """Sets the spf of this EmailHeaderAnalysisSummary.


        :param spf: The spf of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._spf = spf

    @property
    def dkim(self):
        """Gets the dkim of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The dkim of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._dkim

    @dkim.setter
    def dkim(self, dkim):
        """Sets the dkim of this EmailHeaderAnalysisSummary.


        :param dkim: The dkim of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._dkim = dkim

    @property
    def dmarc(self):
        """Gets the dmarc of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The dmarc of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._dmarc

    @dmarc.setter
    def dmarc(self, dmarc):
        """Sets the dmarc of this EmailHeaderAnalysisSummary.


        :param dmarc: The dmarc of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._dmarc = dmarc

    @property
    def from_domain(self):
        """Gets the from_domain of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The from_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._from_domain

    @from_domain.setter
    def from_domain(self, from_domain):
        """Sets the from_domain of this EmailHeaderAnalysisSummary.


        :param from_domain: The from_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._from_domain = from_domain

    @property
    def return_path_domain(self):
        """Gets the return_path_domain of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The return_path_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._return_path_domain

    @return_path_domain.setter
    def return_path_domain(self, return_path_domain):
        """Sets the return_path_domain of this EmailHeaderAnalysisSummary.


        :param return_path_domain: The return_path_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._return_path_domain = return_path_domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailHeaderAnalysisSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailHeaderAnalysisSummary):
            return True

        return self.to_dict() != other.to_dict()
