# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneSummaryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_country_summaries': 'list[PhoneSummaryCountryDto]',
        'has_phone_numbers': 'bool',
        'has_missing_plans': 'bool',
        'total_phones': 'int',
        'plans': 'list[PlanSummaryDto]'
    }

    attribute_map = {
        'phone_country_summaries': 'phoneCountrySummaries',
        'has_phone_numbers': 'hasPhoneNumbers',
        'has_missing_plans': 'hasMissingPlans',
        'total_phones': 'totalPhones',
        'plans': 'plans'
    }

    def __init__(self, phone_country_summaries=None, has_phone_numbers=None, has_missing_plans=None, total_phones=None, plans=None, local_vars_configuration=None):  # noqa: E501
        """PhoneSummaryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_country_summaries = None
        self._has_phone_numbers = None
        self._has_missing_plans = None
        self._total_phones = None
        self._plans = None
        self.discriminator = None

        self.phone_country_summaries = phone_country_summaries
        self.has_phone_numbers = has_phone_numbers
        self.has_missing_plans = has_missing_plans
        self.total_phones = total_phones
        self.plans = plans

    @property
    def phone_country_summaries(self):
        """Gets the phone_country_summaries of this PhoneSummaryDto.  # noqa: E501


        :return: The phone_country_summaries of this PhoneSummaryDto.  # noqa: E501
        :rtype: list[PhoneSummaryCountryDto]
        """
        return self._phone_country_summaries

    @phone_country_summaries.setter
    def phone_country_summaries(self, phone_country_summaries):
        """Sets the phone_country_summaries of this PhoneSummaryDto.


        :param phone_country_summaries: The phone_country_summaries of this PhoneSummaryDto.  # noqa: E501
        :type: list[PhoneSummaryCountryDto]
        """
        if self.local_vars_configuration.client_side_validation and phone_country_summaries is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country_summaries`, must not be `None`")  # noqa: E501

        self._phone_country_summaries = phone_country_summaries

    @property
    def has_phone_numbers(self):
        """Gets the has_phone_numbers of this PhoneSummaryDto.  # noqa: E501


        :return: The has_phone_numbers of this PhoneSummaryDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_phone_numbers

    @has_phone_numbers.setter
    def has_phone_numbers(self, has_phone_numbers):
        """Sets the has_phone_numbers of this PhoneSummaryDto.


        :param has_phone_numbers: The has_phone_numbers of this PhoneSummaryDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and has_phone_numbers is None:  # noqa: E501
            raise ValueError("Invalid value for `has_phone_numbers`, must not be `None`")  # noqa: E501

        self._has_phone_numbers = has_phone_numbers

    @property
    def has_missing_plans(self):
        """Gets the has_missing_plans of this PhoneSummaryDto.  # noqa: E501


        :return: The has_missing_plans of this PhoneSummaryDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_missing_plans

    @has_missing_plans.setter
    def has_missing_plans(self, has_missing_plans):
        """Sets the has_missing_plans of this PhoneSummaryDto.


        :param has_missing_plans: The has_missing_plans of this PhoneSummaryDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and has_missing_plans is None:  # noqa: E501
            raise ValueError("Invalid value for `has_missing_plans`, must not be `None`")  # noqa: E501

        self._has_missing_plans = has_missing_plans

    @property
    def total_phones(self):
        """Gets the total_phones of this PhoneSummaryDto.  # noqa: E501


        :return: The total_phones of this PhoneSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._total_phones

    @total_phones.setter
    def total_phones(self, total_phones):
        """Sets the total_phones of this PhoneSummaryDto.


        :param total_phones: The total_phones of this PhoneSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_phones is None:  # noqa: E501
            raise ValueError("Invalid value for `total_phones`, must not be `None`")  # noqa: E501

        self._total_phones = total_phones

    @property
    def plans(self):
        """Gets the plans of this PhoneSummaryDto.  # noqa: E501


        :return: The plans of this PhoneSummaryDto.  # noqa: E501
        :rtype: list[PlanSummaryDto]
        """
        return self._plans

    @plans.setter
    def plans(self, plans):
        """Sets the plans of this PhoneSummaryDto.


        :param plans: The plans of this PhoneSummaryDto.  # noqa: E501
        :type: list[PlanSummaryDto]
        """
        if self.local_vars_configuration.client_side_validation and plans is None:  # noqa: E501
            raise ValueError("Invalid value for `plans`, must not be `None`")  # noqa: E501

        self._plans = plans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneSummaryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneSummaryDto):
            return True

        return self.to_dict() != other.to_dict()
