# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckCampaignProbeResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'checked_links': 'int',
        'checked_images': 'int',
        'link_issue_count': 'int',
        'image_issue_count': 'int',
        'compatibility_warning_count': 'int',
        'compatibility_not_supported_count': 'int',
        'compatibility_unknown_count': 'int',
        'html_error_count': 'int',
        'html_warning_count': 'int',
        'html_info_count': 'int',
        'attachment_mention_issue_count': 'int',
        'insights': 'list[str]',
        'error_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'checked_links': 'checkedLinks',
        'checked_images': 'checkedImages',
        'link_issue_count': 'linkIssueCount',
        'image_issue_count': 'imageIssueCount',
        'compatibility_warning_count': 'compatibilityWarningCount',
        'compatibility_not_supported_count': 'compatibilityNotSupportedCount',
        'compatibility_unknown_count': 'compatibilityUnknownCount',
        'html_error_count': 'htmlErrorCount',
        'html_warning_count': 'htmlWarningCount',
        'html_info_count': 'htmlInfoCount',
        'attachment_mention_issue_count': 'attachmentMentionIssueCount',
        'insights': 'insights',
        'error_message': 'errorMessage'
    }

    def __init__(self, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, checked_links=None, checked_images=None, link_issue_count=None, image_issue_count=None, compatibility_warning_count=None, compatibility_not_supported_count=None, compatibility_unknown_count=None, html_error_count=None, html_warning_count=None, html_info_count=None, attachment_mention_issue_count=None, insights=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """CheckCampaignProbeResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._checked_links = None
        self._checked_images = None
        self._link_issue_count = None
        self._image_issue_count = None
        self._compatibility_warning_count = None
        self._compatibility_not_supported_count = None
        self._compatibility_unknown_count = None
        self._html_error_count = None
        self._html_warning_count = None
        self._html_info_count = None
        self._attachment_mention_issue_count = None
        self._insights = None
        self._error_message = None
        self.discriminator = None

        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.checked_links = checked_links
        self.checked_images = checked_images
        self.link_issue_count = link_issue_count
        self.image_issue_count = image_issue_count
        self.compatibility_warning_count = compatibility_warning_count
        self.compatibility_not_supported_count = compatibility_not_supported_count
        self.compatibility_unknown_count = compatibility_unknown_count
        self.html_error_count = html_error_count
        self.html_warning_count = html_warning_count
        self.html_info_count = html_info_count
        self.attachment_mention_issue_count = attachment_mention_issue_count
        self.insights = insights
        self.error_message = error_message

    @property
    def status(self):
        """Gets the status of this CheckCampaignProbeResults.  # noqa: E501


        :return: The status of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckCampaignProbeResults.


        :param status: The status of this CheckCampaignProbeResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this CheckCampaignProbeResults.  # noqa: E501


        :return: The health_score of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CheckCampaignProbeResults.


        :param health_score: The health_score of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CheckCampaignProbeResults.  # noqa: E501


        :return: The total_checks of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CheckCampaignProbeResults.


        :param total_checks: The total_checks of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CheckCampaignProbeResults.  # noqa: E501


        :return: The passing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CheckCampaignProbeResults.


        :param passing_checks: The passing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CheckCampaignProbeResults.  # noqa: E501


        :return: The failing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CheckCampaignProbeResults.


        :param failing_checks: The failing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def checked_links(self):
        """Gets the checked_links of this CheckCampaignProbeResults.  # noqa: E501


        :return: The checked_links of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._checked_links

    @checked_links.setter
    def checked_links(self, checked_links):
        """Sets the checked_links of this CheckCampaignProbeResults.


        :param checked_links: The checked_links of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_links is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_links`, must not be `None`")  # noqa: E501

        self._checked_links = checked_links

    @property
    def checked_images(self):
        """Gets the checked_images of this CheckCampaignProbeResults.  # noqa: E501


        :return: The checked_images of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._checked_images

    @checked_images.setter
    def checked_images(self, checked_images):
        """Sets the checked_images of this CheckCampaignProbeResults.


        :param checked_images: The checked_images of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_images is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_images`, must not be `None`")  # noqa: E501

        self._checked_images = checked_images

    @property
    def link_issue_count(self):
        """Gets the link_issue_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The link_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_count

    @link_issue_count.setter
    def link_issue_count(self, link_issue_count):
        """Sets the link_issue_count of this CheckCampaignProbeResults.


        :param link_issue_count: The link_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_count`, must not be `None`")  # noqa: E501

        self._link_issue_count = link_issue_count

    @property
    def image_issue_count(self):
        """Gets the image_issue_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The image_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_count

    @image_issue_count.setter
    def image_issue_count(self, image_issue_count):
        """Sets the image_issue_count of this CheckCampaignProbeResults.


        :param image_issue_count: The image_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_count`, must not be `None`")  # noqa: E501

        self._image_issue_count = image_issue_count

    @property
    def compatibility_warning_count(self):
        """Gets the compatibility_warning_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The compatibility_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_count

    @compatibility_warning_count.setter
    def compatibility_warning_count(self, compatibility_warning_count):
        """Sets the compatibility_warning_count of this CheckCampaignProbeResults.


        :param compatibility_warning_count: The compatibility_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_count`, must not be `None`")  # noqa: E501

        self._compatibility_warning_count = compatibility_warning_count

    @property
    def compatibility_not_supported_count(self):
        """Gets the compatibility_not_supported_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The compatibility_not_supported_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_count

    @compatibility_not_supported_count.setter
    def compatibility_not_supported_count(self, compatibility_not_supported_count):
        """Sets the compatibility_not_supported_count of this CheckCampaignProbeResults.


        :param compatibility_not_supported_count: The compatibility_not_supported_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_count`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_count = compatibility_not_supported_count

    @property
    def compatibility_unknown_count(self):
        """Gets the compatibility_unknown_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The compatibility_unknown_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_unknown_count

    @compatibility_unknown_count.setter
    def compatibility_unknown_count(self, compatibility_unknown_count):
        """Sets the compatibility_unknown_count of this CheckCampaignProbeResults.


        :param compatibility_unknown_count: The compatibility_unknown_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_unknown_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_unknown_count`, must not be `None`")  # noqa: E501

        self._compatibility_unknown_count = compatibility_unknown_count

    @property
    def html_error_count(self):
        """Gets the html_error_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The html_error_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._html_error_count

    @html_error_count.setter
    def html_error_count(self, html_error_count):
        """Sets the html_error_count of this CheckCampaignProbeResults.


        :param html_error_count: The html_error_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_count`, must not be `None`")  # noqa: E501

        self._html_error_count = html_error_count

    @property
    def html_warning_count(self):
        """Gets the html_warning_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The html_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_count

    @html_warning_count.setter
    def html_warning_count(self, html_warning_count):
        """Sets the html_warning_count of this CheckCampaignProbeResults.


        :param html_warning_count: The html_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_count`, must not be `None`")  # noqa: E501

        self._html_warning_count = html_warning_count

    @property
    def html_info_count(self):
        """Gets the html_info_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The html_info_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._html_info_count

    @html_info_count.setter
    def html_info_count(self, html_info_count):
        """Sets the html_info_count of this CheckCampaignProbeResults.


        :param html_info_count: The html_info_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_info_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_info_count`, must not be `None`")  # noqa: E501

        self._html_info_count = html_info_count

    @property
    def attachment_mention_issue_count(self):
        """Gets the attachment_mention_issue_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The attachment_mention_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_count

    @attachment_mention_issue_count.setter
    def attachment_mention_issue_count(self, attachment_mention_issue_count):
        """Sets the attachment_mention_issue_count of this CheckCampaignProbeResults.


        :param attachment_mention_issue_count: The attachment_mention_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_count`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_count = attachment_mention_issue_count

    @property
    def insights(self):
        """Gets the insights of this CheckCampaignProbeResults.  # noqa: E501


        :return: The insights of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CheckCampaignProbeResults.


        :param insights: The insights of this CheckCampaignProbeResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this CheckCampaignProbeResults.  # noqa: E501


        :return: The error_message of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this CheckCampaignProbeResults.


        :param error_message: The error_message of this CheckCampaignProbeResults.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckCampaignProbeResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckCampaignProbeResults):
            return True

        return self.to_dict() != other.to_dict()
