# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExtractAttachmentTextResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'present': 'bool',
        'text': 'str',
        'method_used': 'str',
        'content_type': 'str',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'present': 'present',
        'text': 'text',
        'method_used': 'methodUsed',
        'content_type': 'contentType',
        'warnings': 'warnings'
    }

    def __init__(self, present=None, text=None, method_used=None, content_type=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """ExtractAttachmentTextResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._present = None
        self._text = None
        self._method_used = None
        self._content_type = None
        self._warnings = None
        self.discriminator = None

        self.present = present
        self.text = text
        self.method_used = method_used
        self.content_type = content_type
        self.warnings = warnings

    @property
    def present(self):
        """Gets the present of this ExtractAttachmentTextResult.  # noqa: E501

        True if extracted text is present  # noqa: E501

        :return: The present of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: bool
        """
        return self._present

    @present.setter
    def present(self, present):
        """Sets the present of this ExtractAttachmentTextResult.

        True if extracted text is present  # noqa: E501

        :param present: The present of this ExtractAttachmentTextResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and present is None:  # noqa: E501
            raise ValueError("Invalid value for `present`, must not be `None`")  # noqa: E501

        self._present = present

    @property
    def text(self):
        """Gets the text of this ExtractAttachmentTextResult.  # noqa: E501

        Extracted text when present  # noqa: E501

        :return: The text of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this ExtractAttachmentTextResult.

        Extracted text when present  # noqa: E501

        :param text: The text of this ExtractAttachmentTextResult.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def method_used(self):
        """Gets the method_used of this ExtractAttachmentTextResult.  # noqa: E501

        Method for extracting text from attachments.  # noqa: E501

        :return: The method_used of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: str
        """
        return self._method_used

    @method_used.setter
    def method_used(self, method_used):
        """Sets the method_used of this ExtractAttachmentTextResult.

        Method for extracting text from attachments.  # noqa: E501

        :param method_used: The method_used of this ExtractAttachmentTextResult.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"AUTO", "NATIVE", "OCR", "LLM", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method_used not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method_used` ({0}), must be one of {1}"  # noqa: E501
                .format(method_used, allowed_values)
            )

        self._method_used = method_used

    @property
    def content_type(self):
        """Gets the content_type of this ExtractAttachmentTextResult.  # noqa: E501

        Detected attachment content type  # noqa: E501

        :return: The content_type of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this ExtractAttachmentTextResult.

        Detected attachment content type  # noqa: E501

        :param content_type: The content_type of this ExtractAttachmentTextResult.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def warnings(self):
        """Gets the warnings of this ExtractAttachmentTextResult.  # noqa: E501

        Warnings or fallback notes  # noqa: E501

        :return: The warnings of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this ExtractAttachmentTextResult.

        Warnings or fallback notes  # noqa: E501

        :param warnings: The warnings of this ExtractAttachmentTextResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractAttachmentTextResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExtractAttachmentTextResult):
            return True

        return self.to_dict() != other.to_dict()
