# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImapSmtpAccessServers(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'imap_server': 'ServerEndpoints',
        'secure_imap_server': 'ServerEndpoints',
        'smtp_server': 'ServerEndpoints',
        'secure_smtp_server': 'ServerEndpoints'
    }

    attribute_map = {
        'imap_server': 'imapServer',
        'secure_imap_server': 'secureImapServer',
        'smtp_server': 'smtpServer',
        'secure_smtp_server': 'secureSmtpServer'
    }

    def __init__(self, imap_server=None, secure_imap_server=None, smtp_server=None, secure_smtp_server=None, local_vars_configuration=None):  # noqa: E501
        """ImapSmtpAccessServers - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._imap_server = None
        self._secure_imap_server = None
        self._smtp_server = None
        self._secure_smtp_server = None
        self.discriminator = None

        self.imap_server = imap_server
        self.secure_imap_server = secure_imap_server
        self.smtp_server = smtp_server
        self.secure_smtp_server = secure_smtp_server

    @property
    def imap_server(self):
        """Gets the imap_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._imap_server

    @imap_server.setter
    def imap_server(self, imap_server):
        """Sets the imap_server of this ImapSmtpAccessServers.


        :param imap_server: The imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and imap_server is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_server`, must not be `None`")  # noqa: E501

        self._imap_server = imap_server

    @property
    def secure_imap_server(self):
        """Gets the secure_imap_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The secure_imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._secure_imap_server

    @secure_imap_server.setter
    def secure_imap_server(self, secure_imap_server):
        """Sets the secure_imap_server of this ImapSmtpAccessServers.


        :param secure_imap_server: The secure_imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and secure_imap_server is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_imap_server`, must not be `None`")  # noqa: E501

        self._secure_imap_server = secure_imap_server

    @property
    def smtp_server(self):
        """Gets the smtp_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._smtp_server

    @smtp_server.setter
    def smtp_server(self, smtp_server):
        """Sets the smtp_server of this ImapSmtpAccessServers.


        :param smtp_server: The smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and smtp_server is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_server`, must not be `None`")  # noqa: E501

        self._smtp_server = smtp_server

    @property
    def secure_smtp_server(self):
        """Gets the secure_smtp_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The secure_smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._secure_smtp_server

    @secure_smtp_server.setter
    def secure_smtp_server(self, secure_smtp_server):
        """Sets the secure_smtp_server of this ImapSmtpAccessServers.


        :param secure_smtp_server: The secure_smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and secure_smtp_server is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_smtp_server`, must not be `None`")  # noqa: E501

        self._secure_smtp_server = secure_smtp_server

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImapSmtpAccessServers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImapSmtpAccessServers):
            return True

        return self.to_dict() != other.to_dict()
