# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeSeriesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'probe_id': 'str',
        'since': 'datetime',
        'before': 'datetime',
        'bucket': 'str',
        'points': 'list[CampaignProbeSeriesPointDto]'
    }

    attribute_map = {
        'probe_id': 'probeId',
        'since': 'since',
        'before': 'before',
        'bucket': 'bucket',
        'points': 'points'
    }

    def __init__(self, probe_id=None, since=None, before=None, bucket=None, points=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeSeriesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._probe_id = None
        self._since = None
        self._before = None
        self._bucket = None
        self._points = None
        self.discriminator = None

        self.probe_id = probe_id
        self.since = since
        self.before = before
        self.bucket = bucket
        self.points = points

    @property
    def probe_id(self):
        """Gets the probe_id of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The probe_id of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this CampaignProbeSeriesDto.


        :param probe_id: The probe_id of this CampaignProbeSeriesDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and probe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `probe_id`, must not be `None`")  # noqa: E501

        self._probe_id = probe_id

    @property
    def since(self):
        """Gets the since of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The since of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this CampaignProbeSeriesDto.


        :param since: The since of this CampaignProbeSeriesDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The before of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this CampaignProbeSeriesDto.


        :param before: The before of this CampaignProbeSeriesDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def bucket(self):
        """Gets the bucket of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The bucket of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this CampaignProbeSeriesDto.


        :param bucket: The bucket of this CampaignProbeSeriesDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bucket is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501
        allowed_values = ["HOUR", "DAY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and bucket not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `bucket` ({0}), must be one of {1}"  # noqa: E501
                .format(bucket, allowed_values)
            )

        self._bucket = bucket

    @property
    def points(self):
        """Gets the points of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The points of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: list[CampaignProbeSeriesPointDto]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this CampaignProbeSeriesDto.


        :param points: The points of this CampaignProbeSeriesDto.  # noqa: E501
        :type: list[CampaignProbeSeriesPointDto]
        """
        if self.local_vars_configuration.client_side_validation and points is None:  # noqa: E501
            raise ValueError("Invalid value for `points`, must not be `None`")  # noqa: E501

        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeSeriesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeSeriesDto):
            return True

        return self.to_dict() != other.to_dict()
