# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateDomainMonitorAlertSinkOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'target': 'str',
        'severity_threshold': 'str',
        'enabled': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'target': 'target',
        'severity_threshold': 'severityThreshold',
        'enabled': 'enabled'
    }

    def __init__(self, type=None, target=None, severity_threshold=None, enabled=None, local_vars_configuration=None):  # noqa: E501
        """CreateDomainMonitorAlertSinkOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._target = None
        self._severity_threshold = None
        self._enabled = None
        self.discriminator = None

        self.type = type
        self.target = target
        if severity_threshold is not None:
            self.severity_threshold = severity_threshold
        if enabled is not None:
            self.enabled = enabled

    @property
    def type(self):
        """Gets the type of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The type of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateDomainMonitorAlertSinkOptions.


        :param type: The type of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL", "WEBHOOK", "SLACK", "TEAMS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def target(self):
        """Gets the target of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The target of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this CreateDomainMonitorAlertSinkOptions.


        :param target: The target of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target is None:  # noqa: E501
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                target is not None and len(target) < 1):
            raise ValueError("Invalid value for `target`, length must be greater than or equal to `1`")  # noqa: E501

        self._target = target

    @property
    def severity_threshold(self):
        """Gets the severity_threshold of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The severity_threshold of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: str
        """
        return self._severity_threshold

    @severity_threshold.setter
    def severity_threshold(self, severity_threshold):
        """Sets the severity_threshold of this CreateDomainMonitorAlertSinkOptions.


        :param severity_threshold: The severity_threshold of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and severity_threshold not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `severity_threshold` ({0}), must be one of {1}"  # noqa: E501
                .format(severity_threshold, allowed_values)
            )

        self._severity_threshold = severity_threshold

    @property
    def enabled(self):
        """Gets the enabled of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The enabled of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateDomainMonitorAlertSinkOptions.


        :param enabled: The enabled of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDomainMonitorAlertSinkOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDomainMonitorAlertSinkOptions):
            return True

        return self.to_dict() != other.to_dict()
