# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.mfa_controller_api import MFAControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestMFAControllerApi(unittest.TestCase):
    """MFAControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.mfa_controller_api.MFAControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_totp_device_for_base32_secret_key(self):
        """Test case for create_totp_device_for_base32_secret_key

        Create a TOTP device from an base32 secret key  # noqa: E501
        """
        pass

    def test_create_totp_device_for_custom(self):
        """Test case for create_totp_device_for_custom

        Create a TOTP device from custom options  # noqa: E501
        """
        pass

    def test_create_totp_device_for_otp_auth_url(self):
        """Test case for create_totp_device_for_otp_auth_url

        Create a TOTP device from an OTP Auth URL  # noqa: E501
        """
        pass

    def test_get_totp_device(self):
        """Test case for get_totp_device

        Get a TOTP device by ID  # noqa: E501
        """
        pass

    def test_get_totp_device_by(self):
        """Test case for get_totp_device_by

        Get a TOTP device by username, issuer, or name. Returns empty if not found.  # noqa: E501
        """
        pass

    def test_get_totp_device_code(self):
        """Test case for get_totp_device_code

        Get a TOTP device code by device ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
