# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneProviderCapabilitiesResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'provider_label': 'str',
        'phone_country': 'str',
        'supported_variants': 'list[str]',
        'warning': 'str'
    }

    attribute_map = {
        'provider_label': 'providerLabel',
        'phone_country': 'phoneCountry',
        'supported_variants': 'supportedVariants',
        'warning': 'warning'
    }

    def __init__(self, provider_label=None, phone_country=None, supported_variants=None, warning=None, local_vars_configuration=None):  # noqa: E501
        """PhoneProviderCapabilitiesResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._provider_label = None
        self._phone_country = None
        self._supported_variants = None
        self._warning = None
        self.discriminator = None

        self.provider_label = provider_label
        self.phone_country = phone_country
        self.supported_variants = supported_variants
        if warning is not None:
            self.warning = warning

    @property
    def provider_label(self):
        """Gets the provider_label of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The provider_label of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: str
        """
        return self._provider_label

    @provider_label.setter
    def provider_label(self, provider_label):
        """Sets the provider_label of this PhoneProviderCapabilitiesResult.


        :param provider_label: The provider_label of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and provider_label is None:  # noqa: E501
            raise ValueError("Invalid value for `provider_label`, must not be `None`")  # noqa: E501

        self._provider_label = provider_label

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The phone_country of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneProviderCapabilitiesResult.


        :param phone_country: The phone_country of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def supported_variants(self):
        """Gets the supported_variants of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The supported_variants of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_variants

    @supported_variants.setter
    def supported_variants(self, supported_variants):
        """Sets the supported_variants of this PhoneProviderCapabilitiesResult.


        :param supported_variants: The supported_variants of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and supported_variants is None:  # noqa: E501
            raise ValueError("Invalid value for `supported_variants`, must not be `None`")  # noqa: E501

        self._supported_variants = supported_variants

    @property
    def warning(self):
        """Gets the warning of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The warning of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this PhoneProviderCapabilitiesResult.


        :param warning: The warning of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: str
        """

        self._warning = warning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneProviderCapabilitiesResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneProviderCapabilitiesResult):
            return True

        return self.to_dict() != other.to_dict()
