# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AuditLogEventDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tenant_id': 'str',
        'dt': 'str',
        'event_id': 'str',
        'event_ts': 'datetime',
        'action': 'str',
        'user_id': 'str',
        'actor_user_id': 'str',
        'target_user_id': 'str',
        'resource_type': 'str',
        'resource_id': 'str',
        'outcome': 'str',
        'request_id': 'str',
        'ip_address': 'str',
        'metadata_json': 'str'
    }

    attribute_map = {
        'tenant_id': 'tenantId',
        'dt': 'dt',
        'event_id': 'eventId',
        'event_ts': 'eventTs',
        'action': 'action',
        'user_id': 'userId',
        'actor_user_id': 'actorUserId',
        'target_user_id': 'targetUserId',
        'resource_type': 'resourceType',
        'resource_id': 'resourceId',
        'outcome': 'outcome',
        'request_id': 'requestId',
        'ip_address': 'ipAddress',
        'metadata_json': 'metadataJson'
    }

    def __init__(self, tenant_id=None, dt=None, event_id=None, event_ts=None, action=None, user_id=None, actor_user_id=None, target_user_id=None, resource_type=None, resource_id=None, outcome=None, request_id=None, ip_address=None, metadata_json=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogEventDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._tenant_id = None
        self._dt = None
        self._event_id = None
        self._event_ts = None
        self._action = None
        self._user_id = None
        self._actor_user_id = None
        self._target_user_id = None
        self._resource_type = None
        self._resource_id = None
        self._outcome = None
        self._request_id = None
        self._ip_address = None
        self._metadata_json = None
        self.discriminator = None

        self.tenant_id = tenant_id
        if dt is not None:
            self.dt = dt
        self.event_id = event_id
        self.event_ts = event_ts
        self.action = action
        if user_id is not None:
            self.user_id = user_id
        if actor_user_id is not None:
            self.actor_user_id = actor_user_id
        if target_user_id is not None:
            self.target_user_id = target_user_id
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_id is not None:
            self.resource_id = resource_id
        if outcome is not None:
            self.outcome = outcome
        if request_id is not None:
            self.request_id = request_id
        if ip_address is not None:
            self.ip_address = ip_address
        if metadata_json is not None:
            self.metadata_json = metadata_json

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AuditLogEventDto.  # noqa: E501


        :return: The tenant_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AuditLogEventDto.


        :param tenant_id: The tenant_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tenant_id is None:  # noqa: E501
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def dt(self):
        """Gets the dt of this AuditLogEventDto.  # noqa: E501


        :return: The dt of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._dt

    @dt.setter
    def dt(self, dt):
        """Sets the dt of this AuditLogEventDto.


        :param dt: The dt of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._dt = dt

    @property
    def event_id(self):
        """Gets the event_id of this AuditLogEventDto.  # noqa: E501


        :return: The event_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this AuditLogEventDto.


        :param event_id: The event_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def event_ts(self):
        """Gets the event_ts of this AuditLogEventDto.  # noqa: E501


        :return: The event_ts of this AuditLogEventDto.  # noqa: E501
        :rtype: datetime
        """
        return self._event_ts

    @event_ts.setter
    def event_ts(self, event_ts):
        """Sets the event_ts of this AuditLogEventDto.


        :param event_ts: The event_ts of this AuditLogEventDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and event_ts is None:  # noqa: E501
            raise ValueError("Invalid value for `event_ts`, must not be `None`")  # noqa: E501

        self._event_ts = event_ts

    @property
    def action(self):
        """Gets the action of this AuditLogEventDto.  # noqa: E501


        :return: The action of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this AuditLogEventDto.


        :param action: The action of this AuditLogEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action is None:  # noqa: E501
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501

        self._action = action

    @property
    def user_id(self):
        """Gets the user_id of this AuditLogEventDto.  # noqa: E501


        :return: The user_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AuditLogEventDto.


        :param user_id: The user_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def actor_user_id(self):
        """Gets the actor_user_id of this AuditLogEventDto.  # noqa: E501


        :return: The actor_user_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._actor_user_id

    @actor_user_id.setter
    def actor_user_id(self, actor_user_id):
        """Sets the actor_user_id of this AuditLogEventDto.


        :param actor_user_id: The actor_user_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._actor_user_id = actor_user_id

    @property
    def target_user_id(self):
        """Gets the target_user_id of this AuditLogEventDto.  # noqa: E501


        :return: The target_user_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._target_user_id

    @target_user_id.setter
    def target_user_id(self, target_user_id):
        """Sets the target_user_id of this AuditLogEventDto.


        :param target_user_id: The target_user_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._target_user_id = target_user_id

    @property
    def resource_type(self):
        """Gets the resource_type of this AuditLogEventDto.  # noqa: E501


        :return: The resource_type of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AuditLogEventDto.


        :param resource_type: The resource_type of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def resource_id(self):
        """Gets the resource_id of this AuditLogEventDto.  # noqa: E501


        :return: The resource_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this AuditLogEventDto.


        :param resource_id: The resource_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def outcome(self):
        """Gets the outcome of this AuditLogEventDto.  # noqa: E501


        :return: The outcome of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._outcome

    @outcome.setter
    def outcome(self, outcome):
        """Sets the outcome of this AuditLogEventDto.


        :param outcome: The outcome of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._outcome = outcome

    @property
    def request_id(self):
        """Gets the request_id of this AuditLogEventDto.  # noqa: E501


        :return: The request_id of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AuditLogEventDto.


        :param request_id: The request_id of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def ip_address(self):
        """Gets the ip_address of this AuditLogEventDto.  # noqa: E501


        :return: The ip_address of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this AuditLogEventDto.


        :param ip_address: The ip_address of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def metadata_json(self):
        """Gets the metadata_json of this AuditLogEventDto.  # noqa: E501


        :return: The metadata_json of this AuditLogEventDto.  # noqa: E501
        :rtype: str
        """
        return self._metadata_json

    @metadata_json.setter
    def metadata_json(self, metadata_json):
        """Sets the metadata_json of this AuditLogEventDto.


        :param metadata_json: The metadata_json of this AuditLogEventDto.  # noqa: E501
        :type: str
        """

        self._metadata_json = metadata_json

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogEventDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogEventDto):
            return True

        return self.to_dict() != other.to_dict()
