# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityFailureHotspotsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'since': 'datetime',
        'before': 'datetime',
        'scope': 'str',
        'entity_hotspots': 'list[DeliverabilityFailureEntityHotspotDto]',
        'phone_dimension_hotspots': 'list[DeliverabilityFailurePhoneDimensionHotspotDto]'
    }

    attribute_map = {
        'since': 'since',
        'before': 'before',
        'scope': 'scope',
        'entity_hotspots': 'entityHotspots',
        'phone_dimension_hotspots': 'phoneDimensionHotspots'
    }

    def __init__(self, since=None, before=None, scope=None, entity_hotspots=None, phone_dimension_hotspots=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityFailureHotspotsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._since = None
        self._before = None
        self._scope = None
        self._entity_hotspots = None
        self._phone_dimension_hotspots = None
        self.discriminator = None

        self.since = since
        self.before = before
        self.scope = scope
        self.entity_hotspots = entity_hotspots
        self.phone_dimension_hotspots = phone_dimension_hotspots

    @property
    def since(self):
        """Gets the since of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The since of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this DeliverabilityFailureHotspotsDto.


        :param since: The since of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The before of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this DeliverabilityFailureHotspotsDto.


        :param before: The before of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def scope(self):
        """Gets the scope of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The scope of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this DeliverabilityFailureHotspotsDto.


        :param scope: The scope of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def entity_hotspots(self):
        """Gets the entity_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The entity_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: list[DeliverabilityFailureEntityHotspotDto]
        """
        return self._entity_hotspots

    @entity_hotspots.setter
    def entity_hotspots(self, entity_hotspots):
        """Sets the entity_hotspots of this DeliverabilityFailureHotspotsDto.


        :param entity_hotspots: The entity_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: list[DeliverabilityFailureEntityHotspotDto]
        """
        if self.local_vars_configuration.client_side_validation and entity_hotspots is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_hotspots`, must not be `None`")  # noqa: E501

        self._entity_hotspots = entity_hotspots

    @property
    def phone_dimension_hotspots(self):
        """Gets the phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: list[DeliverabilityFailurePhoneDimensionHotspotDto]
        """
        return self._phone_dimension_hotspots

    @phone_dimension_hotspots.setter
    def phone_dimension_hotspots(self, phone_dimension_hotspots):
        """Sets the phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.


        :param phone_dimension_hotspots: The phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: list[DeliverabilityFailurePhoneDimensionHotspotDto]
        """
        if self.local_vars_configuration.client_side_validation and phone_dimension_hotspots is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_dimension_hotspots`, must not be `None`")  # noqa: E501

        self._phone_dimension_hotspots = phone_dimension_hotspots

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityFailureHotspotsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityFailureHotspotsDto):
            return True

        return self.to_dict() != other.to_dict()
