# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'input': 'str',
        'total_score': 'int',
        'score_breakdown': 'EmailIntelligenceScoreBreakdownDto',
        'signals': 'EmailIntelligenceSignalsDto'
    }

    attribute_map = {
        'input': 'input',
        'total_score': 'totalScore',
        'score_breakdown': 'scoreBreakdown',
        'signals': 'signals'
    }

    def __init__(self, input=None, total_score=None, score_breakdown=None, signals=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._input = None
        self._total_score = None
        self._score_breakdown = None
        self._signals = None
        self.discriminator = None

        self.input = input
        self.total_score = total_score
        self.score_breakdown = score_breakdown
        self.signals = signals

    @property
    def input(self):
        """Gets the input of this EmailIntelligenceResultDto.  # noqa: E501

        Original input value before normalization.  # noqa: E501

        :return: The input of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this EmailIntelligenceResultDto.

        Original input value before normalization.  # noqa: E501

        :param input: The input of this EmailIntelligenceResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and input is None:  # noqa: E501
            raise ValueError("Invalid value for `input`, must not be `None`")  # noqa: E501

        self._input = input

    @property
    def total_score(self):
        """Gets the total_score of this EmailIntelligenceResultDto.  # noqa: E501

        Score from 0 to 100 where higher is better.  # noqa: E501

        :return: The total_score of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: int
        """
        return self._total_score

    @total_score.setter
    def total_score(self, total_score):
        """Sets the total_score of this EmailIntelligenceResultDto.

        Score from 0 to 100 where higher is better.  # noqa: E501

        :param total_score: The total_score of this EmailIntelligenceResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_score is None:  # noqa: E501
            raise ValueError("Invalid value for `total_score`, must not be `None`")  # noqa: E501

        self._total_score = total_score

    @property
    def score_breakdown(self):
        """Gets the score_breakdown of this EmailIntelligenceResultDto.  # noqa: E501


        :return: The score_breakdown of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: EmailIntelligenceScoreBreakdownDto
        """
        return self._score_breakdown

    @score_breakdown.setter
    def score_breakdown(self, score_breakdown):
        """Sets the score_breakdown of this EmailIntelligenceResultDto.


        :param score_breakdown: The score_breakdown of this EmailIntelligenceResultDto.  # noqa: E501
        :type: EmailIntelligenceScoreBreakdownDto
        """
        if self.local_vars_configuration.client_side_validation and score_breakdown is None:  # noqa: E501
            raise ValueError("Invalid value for `score_breakdown`, must not be `None`")  # noqa: E501

        self._score_breakdown = score_breakdown

    @property
    def signals(self):
        """Gets the signals of this EmailIntelligenceResultDto.  # noqa: E501


        :return: The signals of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: EmailIntelligenceSignalsDto
        """
        return self._signals

    @signals.setter
    def signals(self, signals):
        """Sets the signals of this EmailIntelligenceResultDto.


        :param signals: The signals of this EmailIntelligenceResultDto.  # noqa: E501
        :type: EmailIntelligenceSignalsDto
        """
        if self.local_vars_configuration.client_side_validation and signals is None:  # noqa: E501
            raise ValueError("Invalid value for `signals`, must not be `None`")  # noqa: E501

        self._signals = signals

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceResultDto):
            return True

        return self.to_dict() != other.to_dict()
