# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceSignalsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'normalized_target': 'str',
        'email_address': 'str',
        'domain': 'str',
        'local_part': 'str',
        'random_local_part': 'bool',
        'local_part_entropy': 'float',
        'free_email_provider': 'bool',
        'has_https_website': 'bool',
        'dns_a_record_present': 'bool',
        'dns_mx_record_present': 'bool',
        'soa_record_present': 'bool',
        'domain_age_hint_days': 'int',
        'never_bounce_safe_to_send': 'bool',
        'notes': 'list[str]'
    }

    attribute_map = {
        'normalized_target': 'normalizedTarget',
        'email_address': 'emailAddress',
        'domain': 'domain',
        'local_part': 'localPart',
        'random_local_part': 'randomLocalPart',
        'local_part_entropy': 'localPartEntropy',
        'free_email_provider': 'freeEmailProvider',
        'has_https_website': 'hasHttpsWebsite',
        'dns_a_record_present': 'dnsARecordPresent',
        'dns_mx_record_present': 'dnsMxRecordPresent',
        'soa_record_present': 'soaRecordPresent',
        'domain_age_hint_days': 'domainAgeHintDays',
        'never_bounce_safe_to_send': 'neverBounceSafeToSend',
        'notes': 'notes'
    }

    def __init__(self, normalized_target=None, email_address=None, domain=None, local_part=None, random_local_part=None, local_part_entropy=None, free_email_provider=None, has_https_website=None, dns_a_record_present=None, dns_mx_record_present=None, soa_record_present=None, domain_age_hint_days=None, never_bounce_safe_to_send=None, notes=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceSignalsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._normalized_target = None
        self._email_address = None
        self._domain = None
        self._local_part = None
        self._random_local_part = None
        self._local_part_entropy = None
        self._free_email_provider = None
        self._has_https_website = None
        self._dns_a_record_present = None
        self._dns_mx_record_present = None
        self._soa_record_present = None
        self._domain_age_hint_days = None
        self._never_bounce_safe_to_send = None
        self._notes = None
        self.discriminator = None

        self.normalized_target = normalized_target
        self.email_address = email_address
        self.domain = domain
        self.local_part = local_part
        self.random_local_part = random_local_part
        self.local_part_entropy = local_part_entropy
        self.free_email_provider = free_email_provider
        self.has_https_website = has_https_website
        self.dns_a_record_present = dns_a_record_present
        self.dns_mx_record_present = dns_mx_record_present
        self.soa_record_present = soa_record_present
        self.domain_age_hint_days = domain_age_hint_days
        self.never_bounce_safe_to_send = never_bounce_safe_to_send
        self.notes = notes

    @property
    def normalized_target(self):
        """Gets the normalized_target of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The normalized_target of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._normalized_target

    @normalized_target.setter
    def normalized_target(self, normalized_target):
        """Sets the normalized_target of this EmailIntelligenceSignalsDto.


        :param normalized_target: The normalized_target of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and normalized_target is None:  # noqa: E501
            raise ValueError("Invalid value for `normalized_target`, must not be `None`")  # noqa: E501

        self._normalized_target = normalized_target

    @property
    def email_address(self):
        """Gets the email_address of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The email_address of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this EmailIntelligenceSignalsDto.


        :param email_address: The email_address of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def domain(self):
        """Gets the domain of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The domain of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this EmailIntelligenceSignalsDto.


        :param domain: The domain of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def local_part(self):
        """Gets the local_part of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._local_part

    @local_part.setter
    def local_part(self, local_part):
        """Sets the local_part of this EmailIntelligenceSignalsDto.


        :param local_part: The local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """

        self._local_part = local_part

    @property
    def random_local_part(self):
        """Gets the random_local_part of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The random_local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._random_local_part

    @random_local_part.setter
    def random_local_part(self, random_local_part):
        """Sets the random_local_part of this EmailIntelligenceSignalsDto.


        :param random_local_part: The random_local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._random_local_part = random_local_part

    @property
    def local_part_entropy(self):
        """Gets the local_part_entropy of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The local_part_entropy of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: float
        """
        return self._local_part_entropy

    @local_part_entropy.setter
    def local_part_entropy(self, local_part_entropy):
        """Sets the local_part_entropy of this EmailIntelligenceSignalsDto.


        :param local_part_entropy: The local_part_entropy of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: float
        """

        self._local_part_entropy = local_part_entropy

    @property
    def free_email_provider(self):
        """Gets the free_email_provider of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The free_email_provider of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._free_email_provider

    @free_email_provider.setter
    def free_email_provider(self, free_email_provider):
        """Sets the free_email_provider of this EmailIntelligenceSignalsDto.


        :param free_email_provider: The free_email_provider of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._free_email_provider = free_email_provider

    @property
    def has_https_website(self):
        """Gets the has_https_website of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The has_https_website of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_https_website

    @has_https_website.setter
    def has_https_website(self, has_https_website):
        """Sets the has_https_website of this EmailIntelligenceSignalsDto.


        :param has_https_website: The has_https_website of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._has_https_website = has_https_website

    @property
    def dns_a_record_present(self):
        """Gets the dns_a_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The dns_a_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._dns_a_record_present

    @dns_a_record_present.setter
    def dns_a_record_present(self, dns_a_record_present):
        """Sets the dns_a_record_present of this EmailIntelligenceSignalsDto.


        :param dns_a_record_present: The dns_a_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._dns_a_record_present = dns_a_record_present

    @property
    def dns_mx_record_present(self):
        """Gets the dns_mx_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The dns_mx_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._dns_mx_record_present

    @dns_mx_record_present.setter
    def dns_mx_record_present(self, dns_mx_record_present):
        """Sets the dns_mx_record_present of this EmailIntelligenceSignalsDto.


        :param dns_mx_record_present: The dns_mx_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._dns_mx_record_present = dns_mx_record_present

    @property
    def soa_record_present(self):
        """Gets the soa_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The soa_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._soa_record_present

    @soa_record_present.setter
    def soa_record_present(self, soa_record_present):
        """Sets the soa_record_present of this EmailIntelligenceSignalsDto.


        :param soa_record_present: The soa_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._soa_record_present = soa_record_present

    @property
    def domain_age_hint_days(self):
        """Gets the domain_age_hint_days of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The domain_age_hint_days of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: int
        """
        return self._domain_age_hint_days

    @domain_age_hint_days.setter
    def domain_age_hint_days(self, domain_age_hint_days):
        """Sets the domain_age_hint_days of this EmailIntelligenceSignalsDto.


        :param domain_age_hint_days: The domain_age_hint_days of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: int
        """

        self._domain_age_hint_days = domain_age_hint_days

    @property
    def never_bounce_safe_to_send(self):
        """Gets the never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._never_bounce_safe_to_send

    @never_bounce_safe_to_send.setter
    def never_bounce_safe_to_send(self, never_bounce_safe_to_send):
        """Sets the never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.


        :param never_bounce_safe_to_send: The never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._never_bounce_safe_to_send = never_bounce_safe_to_send

    @property
    def notes(self):
        """Gets the notes of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The notes of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this EmailIntelligenceSignalsDto.


        :param notes: The notes of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and notes is None:  # noqa: E501
            raise ValueError("Invalid value for `notes`, must not be `None`")  # noqa: E501

        self._notes = notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceSignalsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceSignalsDto):
            return True

        return self.to_dict() != other.to_dict()
