# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.imap_controller_api import ImapControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestImapControllerApi(unittest.TestCase):
    """ImapControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.imap_controller_api.ImapControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_imap_server_fetch(self):
        """Test case for imap_server_fetch

        Fetch message in an inbox  # noqa: E501
        """
        pass

    def test_imap_server_get(self):
        """Test case for imap_server_get

        Get a message by email ID  # noqa: E501
        """
        pass

    def test_imap_server_list(self):
        """Test case for imap_server_list

        List messages in an inbox  # noqa: E501
        """
        pass

    def test_imap_server_mailbox(self):
        """Test case for imap_server_mailbox

        Create a new mailbox if possible  # noqa: E501
        """
        pass

    def test_imap_server_search(self):
        """Test case for imap_server_search

        Search messages in an inbox  # noqa: E501
        """
        pass

    def test_imap_server_status(self):
        """Test case for imap_server_status

        Get status for mailbox  # noqa: E501
        """
        pass

    def test_imap_server_update_flags(self):
        """Test case for imap_server_update_flags

        """
        pass


if __name__ == '__main__':
    unittest.main()
