# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.tools_controller_api import ToolsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestToolsControllerApi(unittest.TestCase):
    """ToolsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.tools_controller_api.ToolsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_analyze_dmarc_report(self):
        """Test case for analyze_dmarc_report

        Parse and summarize a DMARC aggregate XML report  # noqa: E501
        """
        pass

    def test_analyze_email_headers(self):
        """Test case for analyze_email_headers

        Analyze email headers for auth results and delivery path  # noqa: E501
        """
        pass

    def test_check_campaign_probe(self):
        """Test case for check_campaign_probe

        Run a one-shot free campaign probe preflight check  # noqa: E501
        """
        pass

    def test_check_dns_propagation(self):
        """Test case for check_dns_propagation

        Check DNS propagation for a host and record type across configured resolvers  # noqa: E501
        """
        pass

    def test_check_domain_monitor(self):
        """Test case for check_domain_monitor

        Run a one-shot free domain monitor posture check  # noqa: E501
        """
        pass

    def test_check_email_audit(self):
        """Test case for check_email_audit

        Run a one-shot free email audit across links, images, HTML, and client support  # noqa: E501
        """
        pass

    def test_check_email_auth_stack(self):
        """Test case for check_email_auth_stack

        Run a one-shot combined SPF, DKIM, DMARC, BIMI, MX, MTA-STS, and TLS-RPT check  # noqa: E501
        """
        pass

    def test_check_email_blacklist(self):
        """Test case for check_email_blacklist

        Check whether a domain or IP appears on configured DNS blacklists  # noqa: E501
        """
        pass

    def test_check_email_features_client_support(self):
        """Test case for check_email_features_client_support

        Check email client support for email HTML and CSS features  # noqa: E501
        """
        pass

    def test_create_new_fake_email_address(self):
        """Test case for create_new_fake_email_address

        Create a new email address using the fake email domains  # noqa: E501
        """
        pass

    def test_delete_new_fake_email_address(self):
        """Test case for delete_new_fake_email_address

        Delete a fake email address using the fake email domains  # noqa: E501
        """
        pass

    def test_generate_bimi_record(self):
        """Test case for generate_bimi_record

        Create a BIMI record policy  # noqa: E501
        """
        pass

    def test_generate_dmarc_record(self):
        """Test case for generate_dmarc_record

        Create a DMARC record policy  # noqa: E501
        """
        pass

    def test_generate_mta_sts_record(self):
        """Test case for generate_mta_sts_record

        Create a TLS reporting record policy  # noqa: E501
        """
        pass

    def test_generate_spf_record(self):
        """Test case for generate_spf_record

        Create an SPF record  # noqa: E501
        """
        pass

    def test_generate_tls_reporting_record(self):
        """Test case for generate_tls_reporting_record

        Create a TLS reporting record policy  # noqa: E501
        """
        pass

    def test_get_fake_email_by_email_address(self):
        """Test case for get_fake_email_by_email_address

        """
        pass

    def test_get_fake_email_by_id(self):
        """Test case for get_fake_email_by_id

        Get a fake email by its ID  # noqa: E501
        """
        pass

    def test_get_fake_email_raw(self):
        """Test case for get_fake_email_raw

        Get raw fake email content  # noqa: E501
        """
        pass

    def test_get_fake_emails_for_address(self):
        """Test case for get_fake_emails_for_address

        Get fake emails for an address  # noqa: E501
        """
        pass

    def test_lookup_bimi_domain(self):
        """Test case for lookup_bimi_domain

        Lookup a BIMI record policy  # noqa: E501
        """
        pass

    def test_lookup_dkim_domain(self):
        """Test case for lookup_dkim_domain

        Lookup and validate a DKIM record  # noqa: E501
        """
        pass

    def test_lookup_dmarc_domain(self):
        """Test case for lookup_dmarc_domain

        Lookup a DMARC record policy  # noqa: E501
        """
        pass

    def test_lookup_mta_sts_domain(self):
        """Test case for lookup_mta_sts_domain

        Lookup a MTA-STS domain policy  # noqa: E501
        """
        pass

    def test_lookup_mx_record(self):
        """Test case for lookup_mx_record

        Lookup a MX records for a domain  # noqa: E501
        """
        pass

    def test_lookup_ptr(self):
        """Test case for lookup_ptr

        Lookup PTR records for an IP address  # noqa: E501
        """
        pass

    def test_lookup_spf_domain(self):
        """Test case for lookup_spf_domain

        Lookup and validate an SPF record  # noqa: E501
        """
        pass

    def test_lookup_tls_reporting_domain(self):
        """Test case for lookup_tls_reporting_domain

        Lookup a TLS reporting domain policy  # noqa: E501
        """
        pass

    def test_test_smtp_server(self):
        """Test case for test_smtp_server

        Run a conservative SMTP connectivity, TLS, and AUTH diagnostic  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
