# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityExpectation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'min_count': 'int',
        '_from': 'str',
        'to': 'str',
        'subject': 'str'
    }

    attribute_map = {
        'name': 'name',
        'min_count': 'minCount',
        '_from': 'from',
        'to': 'to',
        'subject': 'subject'
    }

    def __init__(self, name=None, min_count=None, _from=None, to=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityExpectation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._min_count = None
        self.__from = None
        self._to = None
        self._subject = None
        self.discriminator = None

        self.name = name
        self.min_count = min_count
        self._from = _from
        self.to = to
        self.subject = subject

    @property
    def name(self):
        """Gets the name of this DeliverabilityExpectation.  # noqa: E501

        Optional label for this expectation  # noqa: E501

        :return: The name of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeliverabilityExpectation.

        Optional label for this expectation  # noqa: E501

        :param name: The name of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def min_count(self):
        """Gets the min_count of this DeliverabilityExpectation.  # noqa: E501

        Minimum number of matching messages required for this expectation to pass  # noqa: E501

        :return: The min_count of this DeliverabilityExpectation.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this DeliverabilityExpectation.

        Minimum number of matching messages required for this expectation to pass  # noqa: E501

        :param min_count: The min_count of this DeliverabilityExpectation.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and min_count is None:  # noqa: E501
            raise ValueError("Invalid value for `min_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                min_count is not None and min_count < 1):  # noqa: E501
            raise ValueError("Invalid value for `min_count`, must be a value greater than or equal to `1`")  # noqa: E501

        self._min_count = min_count

    @property
    def _from(self):
        """Gets the _from of this DeliverabilityExpectation.  # noqa: E501

        Optional sender filter. Matching is case-insensitive contains against inbound sender/from values.  # noqa: E501

        :return: The _from of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this DeliverabilityExpectation.

        Optional sender filter. Matching is case-insensitive contains against inbound sender/from values.  # noqa: E501

        :param _from: The _from of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this DeliverabilityExpectation.  # noqa: E501

        Optional recipient filter. Matching is case-insensitive contains against recipient/to values.  # noqa: E501

        :return: The to of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this DeliverabilityExpectation.

        Optional recipient filter. Matching is case-insensitive contains against recipient/to values.  # noqa: E501

        :param to: The to of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def subject(self):
        """Gets the subject of this DeliverabilityExpectation.  # noqa: E501

        Optional subject filter for INBOX scope tests. Ignored for PHONE scope tests.  # noqa: E501

        :return: The subject of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DeliverabilityExpectation.

        Optional subject filter for INBOX scope tests. Ignored for PHONE scope tests.  # noqa: E501

        :param subject: The subject of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityExpectation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityExpectation):
            return True

        return self.to_dict() != other.to_dict()
