# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySelectorOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'pattern': 'str',
        'phone_country': 'str',
        'entity_ids': 'list[str]',
        'exclude_entity_ids': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'pattern': 'pattern',
        'phone_country': 'phoneCountry',
        'entity_ids': 'entityIds',
        'exclude_entity_ids': 'excludeEntityIds'
    }

    def __init__(self, type=None, pattern=None, phone_country=None, entity_ids=None, exclude_entity_ids=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySelectorOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._pattern = None
        self._phone_country = None
        self._entity_ids = None
        self._exclude_entity_ids = None
        self.discriminator = None

        self.type = type
        self.pattern = pattern
        self.phone_country = phone_country
        self.entity_ids = entity_ids
        self.exclude_entity_ids = exclude_entity_ids

    @property
    def type(self):
        """Gets the type of this DeliverabilitySelectorOptions.  # noqa: E501

        Selection mode  # noqa: E501

        :return: The type of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeliverabilitySelectorOptions.

        Selection mode  # noqa: E501

        :param type: The type of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["ALL", "PATTERN", "EXPLICIT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def pattern(self):
        """Gets the pattern of this DeliverabilitySelectorOptions.  # noqa: E501

        Wildcard pattern for PATTERN selection. Supports '*' and '?' wildcards. If no wildcard is present the value is treated as a case-insensitive contains match.  # noqa: E501

        :return: The pattern of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this DeliverabilitySelectorOptions.

        Wildcard pattern for PATTERN selection. Supports '*' and '?' wildcards. If no wildcard is present the value is treated as a case-insensitive contains match.  # noqa: E501

        :param pattern: The pattern of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def phone_country(self):
        """Gets the phone_country of this DeliverabilitySelectorOptions.  # noqa: E501

        Optional phone-country filter for PHONE scope selection (e.g. ALL phones in US). Must be null for INBOX scope.  # noqa: E501

        :return: The phone_country of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this DeliverabilitySelectorOptions.

        Optional phone-country filter for PHONE scope selection (e.g. ALL phones in US). Must be null for INBOX scope.  # noqa: E501

        :param phone_country: The phone_country of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def entity_ids(self):
        """Gets the entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501

        Explicit entity IDs for EXPLICIT selection  # noqa: E501

        :return: The entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._entity_ids

    @entity_ids.setter
    def entity_ids(self, entity_ids):
        """Sets the entity_ids of this DeliverabilitySelectorOptions.

        Explicit entity IDs for EXPLICIT selection  # noqa: E501

        :param entity_ids: The entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: list[str]
        """

        self._entity_ids = entity_ids

    @property
    def exclude_entity_ids(self):
        """Gets the exclude_entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501

        Optional entity IDs to exclude from the resolved selection (applies after ALL/PATTERN/EXPLICIT selection).  # noqa: E501

        :return: The exclude_entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._exclude_entity_ids

    @exclude_entity_ids.setter
    def exclude_entity_ids(self, exclude_entity_ids):
        """Sets the exclude_entity_ids of this DeliverabilitySelectorOptions.

        Optional entity IDs to exclude from the resolved selection (applies after ALL/PATTERN/EXPLICIT selection).  # noqa: E501

        :param exclude_entity_ids: The exclude_entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: list[str]
        """

        self._exclude_entity_ids = exclude_entity_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySelectorOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySelectorOptions):
            return True

        return self.to_dict() != other.to_dict()
